import { PluginCombatantState } from '../types/event';
import { NetFieldsReverse } from '../types/net_fields';
import { NetParams } from '../types/net_props';
export type LogDefinition<K extends LogDefinitionName> = {
    type: LogDefinitions[K]['type'];
    name: K;
    source: 'FFXIV_ACT_Plugin' | 'OverlayPlugin';
    messageType: LogDefinitions[K]['messageType'];
    globalInclude?: boolean;
    lastInclude?: boolean;
    canAnonymize?: boolean;
    isUnknown?: boolean;
    firstUnknownField?: number;
    fields: LogDefinitions[K]['fields'];
    possibleRsvFields?: LogDefFieldIdx<K> | readonly LogDefFieldIdx<K>[];
    subFields?: LogDefSubFields<K>;
    playerIds?: PlayerIdMap<K>;
    possiblePlayerIds?: readonly LogDefFieldIdx<K>[];
    blankFields?: readonly LogDefFieldIdx<K>[];
    firstOptionalField: number | undefined;
    repeatingFields?: {
        startingIndex: number;
        label: string;
        names: readonly string[];
        sortKeys?: boolean;
        primaryKey: string;
        possibleKeys: readonly string[];
        keysToAnonymize?: K extends RepeatingFieldsTypes ? {
            [idField: string | number]: string | null;
        } : never;
    };
    analysisOptions?: AnalysisOptions<K>;
};
export type LogDefFieldIdx<K extends LogDefinitionName> = Extract<LogDefinitions[K]['fields'][keyof LogDefinitions[K]['fields']], number>;
type PlayerIdMap<K extends LogDefinitionName> = {
    [P in LogDefFieldIdx<K> as number]?: LogDefFieldIdx<K> | null;
};
export type LogDefFieldName<K extends LogDefinitionName> = Extract<keyof LogDefinitions[K]['fields'], string>;
type LogDefSubFields<K extends LogDefinitionName> = {
    [P in LogDefFieldName<K>]?: {
        [fieldValue: string]: {
            name: string;
            canAnonymize: boolean;
        };
    };
};
export type AnalysisOptions<K extends LogDefinitionName> = {
    include: 'never';
    filters?: undefined;
    combatantIdFields?: undefined;
} | {
    include: 'filter';
    filters: NetParams[K] | readonly NetParams[K][];
    combatantIdFields?: LogDefFieldIdx<K> | readonly LogDefFieldIdx<K>[];
} | {
    include: 'all';
    filters?: undefined;
    combatantIdFields?: LogDefFieldIdx<K> | readonly LogDefFieldIdx<K>[];
};
declare const latestLogDefinitions: {
    readonly GameLog: {
        readonly type: "00";
        readonly name: "GameLog";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ChatLog";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly code: 2;
            readonly name: 3;
            readonly line: 4;
        };
        readonly subFields: {
            readonly code: {
                readonly '0039': {
                    readonly name: "message";
                    readonly canAnonymize: true;
                };
                readonly '0038': {
                    readonly name: "echo";
                    readonly canAnonymize: true;
                };
                readonly '0044': {
                    readonly name: "dialog";
                    readonly canAnonymize: true;
                };
                readonly '0839': {
                    readonly name: "message";
                    readonly canAnonymize: true;
                };
            };
        };
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly code: readonly ["0044", "0839"];
            };
        };
    };
    readonly ChangeZone: {
        readonly type: "01";
        readonly name: "ChangeZone";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Territory";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
        };
        readonly lastInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly ChangedPlayer: {
        readonly type: "02";
        readonly name: "ChangedPlayer";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ChangePrimaryPlayer";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly lastInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly AddedCombatant: {
        readonly type: "03";
        readonly name: "AddedCombatant";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "AddCombatant";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly job: 4;
            readonly level: 5;
            readonly ownerId: 6;
            readonly worldId: 7;
            readonly world: 8;
            readonly npcNameId: 9;
            readonly npcBaseId: 10;
            readonly currentHp: 11;
            readonly hp: 12;
            readonly currentMp: 13;
            readonly mp: 14;
            readonly x: 17;
            readonly y: 18;
            readonly z: 19;
            readonly heading: 20;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly RemovedCombatant: {
        readonly type: "04";
        readonly name: "RemovedCombatant";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "RemoveCombatant";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly job: 4;
            readonly level: 5;
            readonly owner: 6;
            readonly world: 8;
            readonly npcNameId: 9;
            readonly npcBaseId: 10;
            readonly currentHp: 11;
            readonly hp: 12;
            readonly currentMp: 13;
            readonly mp: 14;
            readonly x: 17;
            readonly y: 18;
            readonly z: 19;
            readonly heading: 20;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly PartyList: {
        readonly type: "11";
        readonly name: "PartyList";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "PartyList";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly partyCount: 2;
            readonly id0: 3;
            readonly id1: 4;
            readonly id2: 5;
            readonly id3: 6;
            readonly id4: 7;
            readonly id5: 8;
            readonly id6: 9;
            readonly id7: 10;
            readonly id8: 11;
            readonly id9: 12;
            readonly id10: 13;
            readonly id11: 14;
            readonly id12: 15;
            readonly id13: 16;
            readonly id14: 17;
            readonly id15: 18;
            readonly id16: 19;
            readonly id17: 20;
            readonly id18: 21;
            readonly id19: 22;
            readonly id20: 23;
            readonly id21: 24;
            readonly id22: 25;
            readonly id23: 26;
        };
        readonly playerIds: {
            readonly 3: null;
            readonly 4: null;
            readonly 5: null;
            readonly 6: null;
            readonly 7: null;
            readonly 8: null;
            readonly 9: null;
            readonly 10: null;
            readonly 11: null;
            readonly 12: null;
            readonly 13: null;
            readonly 14: null;
            readonly 15: null;
            readonly 16: null;
            readonly 17: null;
            readonly 18: null;
            readonly 19: null;
            readonly 20: null;
            readonly 21: null;
            readonly 22: null;
            readonly 23: null;
            readonly 24: null;
            readonly 25: null;
            readonly 26: null;
        };
        readonly firstOptionalField: 3;
        readonly canAnonymize: true;
        readonly lastInclude: true;
    };
    readonly PlayerStats: {
        readonly type: "12";
        readonly name: "PlayerStats";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "PlayerStats";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly job: 2;
            readonly strength: 3;
            readonly dexterity: 4;
            readonly vitality: 5;
            readonly intelligence: 6;
            readonly mind: 7;
            readonly piety: 8;
            readonly attackPower: 9;
            readonly directHit: 10;
            readonly criticalHit: 11;
            readonly attackMagicPotency: 12;
            readonly healMagicPotency: 13;
            readonly determination: 14;
            readonly skillSpeed: 15;
            readonly spellSpeed: 16;
            readonly tenacity: 18;
            readonly localContentId: 19;
        };
        readonly canAnonymize: true;
        readonly lastInclude: true;
        readonly firstOptionalField: undefined;
    };
    readonly StartsUsing: {
        readonly type: "20";
        readonly name: "StartsUsing";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StartsCasting";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly ability: 5;
            readonly targetId: 6;
            readonly target: 7;
            readonly castTime: 8;
            readonly x: 9;
            readonly y: 10;
            readonly z: 11;
            readonly heading: 12;
        };
        readonly possibleRsvFields: 5;
        readonly blankFields: readonly [6];
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: 7;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: readonly [2, 6];
        };
    };
    readonly Ability: {
        readonly type: "21";
        readonly name: "Ability";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ActionEffect";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly ability: 5;
            readonly targetId: 6;
            readonly target: 7;
            readonly flags: 8;
            readonly damage: 9;
            readonly targetCurrentHp: 24;
            readonly targetMaxHp: 25;
            readonly targetCurrentMp: 26;
            readonly targetMaxMp: 27;
            readonly targetX: 30;
            readonly targetY: 31;
            readonly targetZ: 32;
            readonly targetHeading: 33;
            readonly currentHp: 34;
            readonly maxHp: 35;
            readonly currentMp: 36;
            readonly maxMp: 37;
            readonly x: 40;
            readonly y: 41;
            readonly z: 42;
            readonly heading: 43;
            readonly sequence: 44;
            readonly targetIndex: 45;
            readonly targetCount: 46;
            readonly ownerId: 47;
            readonly ownerName: 48;
            readonly effectDisplayType: 49;
            readonly actionId: 50;
            readonly actionAnimationId: 51;
            readonly animationLockTime: 52;
            readonly rotationHex: 53;
        };
        readonly possibleRsvFields: 5;
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: 7;
            readonly 47: 48;
        };
        readonly blankFields: readonly [6, 47, 48];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: readonly [2, 6];
        };
    };
    readonly NetworkAOEAbility: {
        readonly type: "22";
        readonly name: "NetworkAOEAbility";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "AOEActionEffect";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly ability: 5;
            readonly targetId: 6;
            readonly target: 7;
            readonly flags: 8;
            readonly damage: 9;
            readonly targetCurrentHp: 24;
            readonly targetMaxHp: 25;
            readonly targetCurrentMp: 26;
            readonly targetMaxMp: 27;
            readonly targetX: 30;
            readonly targetY: 31;
            readonly targetZ: 32;
            readonly targetHeading: 33;
            readonly currentHp: 34;
            readonly maxHp: 35;
            readonly currentMp: 36;
            readonly maxMp: 37;
            readonly x: 40;
            readonly y: 41;
            readonly z: 42;
            readonly heading: 43;
            readonly sequence: 44;
            readonly targetIndex: 45;
            readonly targetCount: 46;
            readonly ownerId: 47;
            readonly ownerName: 48;
            readonly effectDisplayType: 49;
            readonly actionId: 50;
            readonly actionAnimationId: 51;
            readonly animationLockTime: 52;
            readonly rotationHex: 53;
        };
        readonly possibleRsvFields: 5;
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: 7;
            readonly 47: 48;
        };
        readonly blankFields: readonly [6, 47, 48];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: readonly [2, 6];
        };
    };
    readonly NetworkCancelAbility: {
        readonly type: "23";
        readonly name: "NetworkCancelAbility";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "CancelAction";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly name: 5;
            readonly reason: 6;
        };
        readonly possibleRsvFields: 5;
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly NetworkDoT: {
        readonly type: "24";
        readonly name: "NetworkDoT";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "DoTHoT";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly which: 4;
            readonly effectId: 5;
            readonly damage: 6;
            readonly currentHp: 7;
            readonly maxHp: 8;
            readonly currentMp: 9;
            readonly maxMp: 10;
            readonly x: 13;
            readonly y: 14;
            readonly z: 15;
            readonly heading: 16;
            readonly sourceId: 17;
            readonly source: 18;
            readonly damageType: 19;
            readonly sourceCurrentHp: 20;
            readonly sourceMaxHp: 21;
            readonly sourceCurrentMp: 22;
            readonly sourceMaxMp: 23;
            readonly sourceX: 26;
            readonly sourceY: 27;
            readonly sourceZ: 28;
            readonly sourceHeading: 29;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 17: 18;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "1.{7}";
                readonly which: "DoT";
                readonly effectId: "0*?[1-9A-F][0-9A-F]*";
            };
            readonly combatantIdFields: readonly [2, 17];
        };
    };
    readonly WasDefeated: {
        readonly type: "25";
        readonly name: "WasDefeated";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Death";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly targetId: 2;
            readonly target: 3;
            readonly sourceId: 4;
            readonly source: 5;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly targetId: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly GainsEffect: {
        readonly type: "26";
        readonly name: "GainsEffect";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusAdd";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly effectId: 2;
            readonly effect: 3;
            readonly duration: 4;
            readonly sourceId: 5;
            readonly source: 6;
            readonly targetId: 7;
            readonly target: 8;
            readonly count: 9;
            readonly targetMaxHp: 10;
            readonly sourceMaxHp: 11;
        };
        readonly possibleRsvFields: 3;
        readonly playerIds: {
            readonly 5: 6;
            readonly 7: 8;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: readonly [{
                readonly sourceId: "[E4].{7}";
                readonly targetId: "1.{7}";
            }, {
                readonly sourceId: "[E4].{7}";
                readonly targetId: "4.{7}";
            }, {
                readonly effectId: readonly ["B9A", "808"];
            }];
            readonly combatantIdFields: readonly [5, 7];
        };
    };
    readonly HeadMarker: {
        readonly type: "27";
        readonly name: "HeadMarker";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "TargetIcon";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly targetId: 2;
            readonly target: 3;
            readonly id: 6;
            readonly data0: 7;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly possiblePlayerIds: readonly [7];
        readonly canAnonymize: true;
        readonly firstOptionalField: 7;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly NetworkRaidMarker: {
        readonly type: "28";
        readonly name: "NetworkRaidMarker";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "WaymarkMarker";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly operation: 2;
            readonly waymark: 3;
            readonly id: 4;
            readonly name: 5;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
        };
        readonly playerIds: {
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NetworkTargetMarker: {
        readonly type: "29";
        readonly name: "NetworkTargetMarker";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "SignMarker";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly operation: 2;
            readonly waymark: 3;
            readonly id: 4;
            readonly name: 5;
            readonly targetId: 6;
            readonly targetName: 7;
        };
        readonly playerIds: {
            readonly 4: 5;
            readonly 6: 7;
        };
        readonly firstOptionalField: undefined;
    };
    readonly LosesEffect: {
        readonly type: "30";
        readonly name: "LosesEffect";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusRemove";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly effectId: 2;
            readonly effect: 3;
            readonly sourceId: 5;
            readonly source: 6;
            readonly targetId: 7;
            readonly target: 8;
            readonly count: 9;
        };
        readonly possibleRsvFields: 3;
        readonly playerIds: {
            readonly 5: 6;
            readonly 7: 8;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: readonly [{
                readonly sourceId: "[E4].{7}";
                readonly targetId: "1.{7}";
            }, {
                readonly sourceId: "[E4].{7}";
                readonly targetId: "4.{7}";
            }, {
                readonly effectId: readonly ["B9A", "808"];
            }];
            readonly combatantIdFields: readonly [5, 7];
        };
    };
    readonly NetworkGauge: {
        readonly type: "31";
        readonly name: "NetworkGauge";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Gauge";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly data0: 3;
            readonly data1: 4;
            readonly data2: 5;
            readonly data3: 6;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly firstUnknownField: 3;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NetworkWorld: {
        readonly type: "32";
        readonly name: "NetworkWorld";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "World";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly isUnknown: true;
        readonly firstOptionalField: undefined;
    };
    readonly ActorControl: {
        readonly type: "33";
        readonly name: "ActorControl";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Director";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly instance: 2;
            readonly command: 3;
            readonly data0: 4;
            readonly data1: 5;
            readonly data2: 6;
            readonly data3: 7;
        };
        readonly possiblePlayerIds: readonly [4, 5, 6, 7];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly NameToggle: {
        readonly type: "34";
        readonly name: "NameToggle";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "NameToggle";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly targetId: 4;
            readonly targetName: 5;
            readonly toggle: 6;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly Tether: {
        readonly type: "35";
        readonly name: "Tether";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Tether";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly targetId: 4;
            readonly target: 5;
            readonly id: 8;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstUnknownField: 9;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: readonly [2, 4];
        };
    };
    readonly LimitBreak: {
        readonly type: "36";
        readonly name: "LimitBreak";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "LimitBreak";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly valueHex: 2;
            readonly bars: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NetworkEffectResult: {
        readonly type: "37";
        readonly name: "NetworkEffectResult";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "EffectResult";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly sequenceId: 4;
            readonly currentHp: 5;
            readonly maxHp: 6;
            readonly currentMp: 7;
            readonly maxMp: 8;
            readonly currentShield: 9;
            readonly x: 11;
            readonly y: 12;
            readonly z: 13;
            readonly heading: 14;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly firstUnknownField: 22;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly StatusEffect: {
        readonly type: "38";
        readonly name: "StatusEffect";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusList";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly targetId: 2;
            readonly target: 3;
            readonly jobLevelData: 4;
            readonly hp: 5;
            readonly maxHp: 6;
            readonly mp: 7;
            readonly maxMp: 8;
            readonly currentShield: 9;
            readonly x: 11;
            readonly y: 12;
            readonly z: 13;
            readonly heading: 14;
            readonly data0: 15;
            readonly data1: 16;
            readonly data2: 17;
            readonly data3: 18;
            readonly data4: 19;
            readonly data5: 20;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly firstUnknownField: 18;
        readonly canAnonymize: true;
        readonly firstOptionalField: 18;
    };
    readonly NetworkUpdateHP: {
        readonly type: "39";
        readonly name: "NetworkUpdateHP";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "UpdateHp";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly currentHp: 4;
            readonly maxHp: 5;
            readonly currentMp: 6;
            readonly maxMp: 7;
            readonly x: 10;
            readonly y: 11;
            readonly z: 12;
            readonly heading: 13;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly Map: {
        readonly type: "40";
        readonly name: "Map";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ChangeMap";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly regionName: 3;
            readonly placeName: 4;
            readonly placeNameSub: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly lastInclude: true;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly SystemLogMessage: {
        readonly type: "41";
        readonly name: "SystemLogMessage";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "SystemLogMessage";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly instance: 2;
            readonly id: 3;
            readonly param0: 4;
            readonly param1: 5;
            readonly param2: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly StatusList3: {
        readonly type: "42";
        readonly name: "StatusList3";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusList3";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: 4;
        readonly firstUnknownField: 4;
    };
    readonly ParserInfo: {
        readonly type: "249";
        readonly name: "ParserInfo";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Settings";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly ProcessInfo: {
        readonly type: "250";
        readonly name: "ProcessInfo";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Process";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly Debug: {
        readonly type: "251";
        readonly name: "Debug";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Debug";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: false;
        readonly firstOptionalField: undefined;
    };
    readonly PacketDump: {
        readonly type: "252";
        readonly name: "PacketDump";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "PacketDump";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly canAnonymize: false;
        readonly firstOptionalField: undefined;
    };
    readonly Version: {
        readonly type: "253";
        readonly name: "Version";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Version";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly Error: {
        readonly type: "254";
        readonly name: "Error";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Error";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly canAnonymize: false;
        readonly firstOptionalField: undefined;
    };
    readonly None: {
        readonly type: "[0-9]+";
        readonly name: "None";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "None";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly isUnknown: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly LineRegistration: {
        readonly type: "256";
        readonly name: "LineRegistration";
        readonly source: "OverlayPlugin";
        readonly messageType: "256";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly source: 3;
            readonly name: 4;
            readonly version: 5;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly MapEffect: {
        readonly type: "257";
        readonly name: "MapEffect";
        readonly source: "OverlayPlugin";
        readonly messageType: "257";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly instance: 2;
            readonly flags: 3;
            readonly location: 4;
            readonly data0: 5;
            readonly data1: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly FateDirector: {
        readonly type: "258";
        readonly name: "FateDirector";
        readonly source: "OverlayPlugin";
        readonly messageType: "258";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly category: 2;
            readonly fateId: 4;
            readonly progress: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly CEDirector: {
        readonly type: "259";
        readonly name: "CEDirector";
        readonly source: "OverlayPlugin";
        readonly messageType: "259";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly popTime: 2;
            readonly timeRemaining: 3;
            readonly ceKey: 5;
            readonly numPlayers: 6;
            readonly status: 7;
            readonly progress: 9;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly InCombat: {
        readonly type: "260";
        readonly name: "InCombat";
        readonly source: "OverlayPlugin";
        readonly messageType: "260";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly inACTCombat: 2;
            readonly inGameCombat: 3;
            readonly isACTChanged: 4;
            readonly isGameChanged: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly CombatantMemory: {
        readonly type: "261";
        readonly name: "CombatantMemory";
        readonly source: "OverlayPlugin";
        readonly messageType: "261";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly change: 2;
            readonly id: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: 5;
        readonly repeatingFields: {
            readonly startingIndex: 4;
            readonly label: "pair";
            readonly names: readonly ["key", "value"];
            readonly sortKeys: true;
            readonly primaryKey: "key";
            readonly possibleKeys: readonly (keyof PluginCombatantState)[];
            readonly keysToAnonymize: {
                readonly 3: "Name";
                readonly OwnerID: null;
                readonly TargetID: null;
                readonly PCTargetID: null;
                readonly NPCTargetID: null;
                readonly CastTargetID: null;
            };
        };
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: readonly [{
                readonly id: "4.{7}";
                readonly change: "Change";
                readonly pair: readonly [{
                    readonly key: "ModelStatus";
                    readonly value: ".*";
                }];
            }, {
                readonly id: "4.{7}";
                readonly change: "Change";
                readonly pair: readonly [{
                    readonly key: "WeaponId";
                    readonly value: ".*";
                }];
            }, {
                readonly id: "4.{7}";
                readonly change: "Change";
                readonly pair: readonly [{
                    readonly key: "TransformationId";
                    readonly value: ".*";
                }];
            }];
            readonly combatantIdFields: 3;
        };
    };
    readonly RSVData: {
        readonly type: "262";
        readonly name: "RSVData";
        readonly source: "OverlayPlugin";
        readonly messageType: "262";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly locale: 2;
            readonly key: 4;
            readonly value: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly StartsUsingExtra: {
        readonly type: "263";
        readonly name: "StartsUsingExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "263";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly id: 3;
            readonly x: 4;
            readonly y: 5;
            readonly z: 6;
            readonly heading: 7;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly AbilityExtra: {
        readonly type: "264";
        readonly name: "AbilityExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "264";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly id: 3;
            readonly globalEffectCounter: 4;
            readonly dataFlag: 5;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
            readonly heading: 9;
            readonly animationTargetId: 10;
        };
        readonly blankFields: readonly [6, 7, 8];
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly ContentFinderSettings: {
        readonly type: "265";
        readonly name: "ContentFinderSettings";
        readonly source: "OverlayPlugin";
        readonly messageType: "265";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly zoneId: 2;
            readonly zoneName: 3;
            readonly inContentFinderContent: 4;
            readonly unrestrictedParty: 5;
            readonly minimalItemLevel: 6;
            readonly silenceEcho: 7;
            readonly explorerMode: 8;
            readonly levelSync: 9;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NpcYell: {
        readonly type: "266";
        readonly name: "NpcYell";
        readonly source: "OverlayPlugin";
        readonly messageType: "266";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly npcId: 2;
            readonly npcNameId: 3;
            readonly npcYellId: 4;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly BattleTalk2: {
        readonly type: "267";
        readonly name: "BattleTalk2";
        readonly source: "OverlayPlugin";
        readonly messageType: "267";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly npcId: 2;
            readonly instance: 3;
            readonly npcNameId: 4;
            readonly instanceContentTextId: 5;
            readonly displayMs: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly Countdown: {
        readonly type: "268";
        readonly name: "Countdown";
        readonly source: "OverlayPlugin";
        readonly messageType: "268";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly worldId: 3;
            readonly countdownTime: 4;
            readonly result: 5;
            readonly name: 6;
        };
        readonly playerIds: {
            readonly 2: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly CountdownCancel: {
        readonly type: "269";
        readonly name: "CountdownCancel";
        readonly source: "OverlayPlugin";
        readonly messageType: "269";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly worldId: 3;
            readonly name: 4;
        };
        readonly playerIds: {
            readonly 2: 4;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly ActorMove: {
        readonly type: "270";
        readonly name: "ActorMove";
        readonly source: "OverlayPlugin";
        readonly messageType: "270";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly heading: 3;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly ActorSetPos: {
        readonly type: "271";
        readonly name: "ActorSetPos";
        readonly source: "OverlayPlugin";
        readonly messageType: "271";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly heading: 3;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly SpawnNpcExtra: {
        readonly type: "272";
        readonly name: "SpawnNpcExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "272";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly parentId: 3;
            readonly tetherId: 4;
            readonly animationState: 5;
        };
        readonly playerIds: {
            readonly 3: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: readonly [2, 3];
        };
    };
    readonly ActorControlExtra: {
        readonly type: "273";
        readonly name: "ActorControlExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "273";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly category: 3;
            readonly param1: 4;
            readonly param2: 5;
            readonly param3: 6;
            readonly param4: 7;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly possiblePlayerIds: readonly [4, 5, 6, 7];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly ActorControlSelfExtra: {
        readonly type: "274";
        readonly name: "ActorControlSelfExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "274";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly category: 3;
            readonly param1: 4;
            readonly param2: 5;
            readonly param3: 6;
            readonly param4: 7;
            readonly param5: 8;
            readonly param6: 9;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly possiblePlayerIds: readonly [4, 5, 6, 7, 8, 9];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
};
export declare const logDefinitionsVersions: {
    readonly latest: {
        readonly GameLog: {
            readonly type: "00";
            readonly name: "GameLog";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "ChatLog";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly code: 2;
                readonly name: 3;
                readonly line: 4;
            };
            readonly subFields: {
                readonly code: {
                    readonly '0039': {
                        readonly name: "message";
                        readonly canAnonymize: true;
                    };
                    readonly '0038': {
                        readonly name: "echo";
                        readonly canAnonymize: true;
                    };
                    readonly '0044': {
                        readonly name: "dialog";
                        readonly canAnonymize: true;
                    };
                    readonly '0839': {
                        readonly name: "message";
                        readonly canAnonymize: true;
                    };
                };
            };
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly code: readonly ["0044", "0839"];
                };
            };
        };
        readonly ChangeZone: {
            readonly type: "01";
            readonly name: "ChangeZone";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Territory";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
            };
            readonly lastInclude: true;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
            };
        };
        readonly ChangedPlayer: {
            readonly type: "02";
            readonly name: "ChangedPlayer";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "ChangePrimaryPlayer";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
            };
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly lastInclude: true;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly AddedCombatant: {
            readonly type: "03";
            readonly name: "AddedCombatant";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "AddCombatant";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
                readonly job: 4;
                readonly level: 5;
                readonly ownerId: 6;
                readonly worldId: 7;
                readonly world: 8;
                readonly npcNameId: 9;
                readonly npcBaseId: 10;
                readonly currentHp: 11;
                readonly hp: 12;
                readonly currentMp: 13;
                readonly mp: 14;
                readonly x: 17;
                readonly y: 18;
                readonly z: 19;
                readonly heading: 20;
            };
            readonly playerIds: {
                readonly 2: 3;
                readonly 6: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly id: "4.{7}";
                };
                readonly combatantIdFields: 2;
            };
        };
        readonly RemovedCombatant: {
            readonly type: "04";
            readonly name: "RemovedCombatant";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "RemoveCombatant";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
                readonly job: 4;
                readonly level: 5;
                readonly owner: 6;
                readonly world: 8;
                readonly npcNameId: 9;
                readonly npcBaseId: 10;
                readonly currentHp: 11;
                readonly hp: 12;
                readonly currentMp: 13;
                readonly mp: 14;
                readonly x: 17;
                readonly y: 18;
                readonly z: 19;
                readonly heading: 20;
            };
            readonly playerIds: {
                readonly 2: 3;
                readonly 6: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly id: "4.{7}";
                };
                readonly combatantIdFields: 2;
            };
        };
        readonly PartyList: {
            readonly type: "11";
            readonly name: "PartyList";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "PartyList";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly partyCount: 2;
                readonly id0: 3;
                readonly id1: 4;
                readonly id2: 5;
                readonly id3: 6;
                readonly id4: 7;
                readonly id5: 8;
                readonly id6: 9;
                readonly id7: 10;
                readonly id8: 11;
                readonly id9: 12;
                readonly id10: 13;
                readonly id11: 14;
                readonly id12: 15;
                readonly id13: 16;
                readonly id14: 17;
                readonly id15: 18;
                readonly id16: 19;
                readonly id17: 20;
                readonly id18: 21;
                readonly id19: 22;
                readonly id20: 23;
                readonly id21: 24;
                readonly id22: 25;
                readonly id23: 26;
            };
            readonly playerIds: {
                readonly 3: null;
                readonly 4: null;
                readonly 5: null;
                readonly 6: null;
                readonly 7: null;
                readonly 8: null;
                readonly 9: null;
                readonly 10: null;
                readonly 11: null;
                readonly 12: null;
                readonly 13: null;
                readonly 14: null;
                readonly 15: null;
                readonly 16: null;
                readonly 17: null;
                readonly 18: null;
                readonly 19: null;
                readonly 20: null;
                readonly 21: null;
                readonly 22: null;
                readonly 23: null;
                readonly 24: null;
                readonly 25: null;
                readonly 26: null;
            };
            readonly firstOptionalField: 3;
            readonly canAnonymize: true;
            readonly lastInclude: true;
        };
        readonly PlayerStats: {
            readonly type: "12";
            readonly name: "PlayerStats";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "PlayerStats";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly job: 2;
                readonly strength: 3;
                readonly dexterity: 4;
                readonly vitality: 5;
                readonly intelligence: 6;
                readonly mind: 7;
                readonly piety: 8;
                readonly attackPower: 9;
                readonly directHit: 10;
                readonly criticalHit: 11;
                readonly attackMagicPotency: 12;
                readonly healMagicPotency: 13;
                readonly determination: 14;
                readonly skillSpeed: 15;
                readonly spellSpeed: 16;
                readonly tenacity: 18;
                readonly localContentId: 19;
            };
            readonly canAnonymize: true;
            readonly lastInclude: true;
            readonly firstOptionalField: undefined;
        };
        readonly StartsUsing: {
            readonly type: "20";
            readonly name: "StartsUsing";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "StartsCasting";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly source: 3;
                readonly id: 4;
                readonly ability: 5;
                readonly targetId: 6;
                readonly target: 7;
                readonly castTime: 8;
                readonly x: 9;
                readonly y: 10;
                readonly z: 11;
                readonly heading: 12;
            };
            readonly possibleRsvFields: 5;
            readonly blankFields: readonly [6];
            readonly playerIds: {
                readonly 2: 3;
                readonly 6: 7;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly sourceId: "4.{7}";
                };
                readonly combatantIdFields: readonly [2, 6];
            };
        };
        readonly Ability: {
            readonly type: "21";
            readonly name: "Ability";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "ActionEffect";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly source: 3;
                readonly id: 4;
                readonly ability: 5;
                readonly targetId: 6;
                readonly target: 7;
                readonly flags: 8;
                readonly damage: 9;
                readonly targetCurrentHp: 24;
                readonly targetMaxHp: 25;
                readonly targetCurrentMp: 26;
                readonly targetMaxMp: 27;
                readonly targetX: 30;
                readonly targetY: 31;
                readonly targetZ: 32;
                readonly targetHeading: 33;
                readonly currentHp: 34;
                readonly maxHp: 35;
                readonly currentMp: 36;
                readonly maxMp: 37;
                readonly x: 40;
                readonly y: 41;
                readonly z: 42;
                readonly heading: 43;
                readonly sequence: 44;
                readonly targetIndex: 45;
                readonly targetCount: 46;
                readonly ownerId: 47;
                readonly ownerName: 48;
                readonly effectDisplayType: 49;
                readonly actionId: 50;
                readonly actionAnimationId: 51;
                readonly animationLockTime: 52;
                readonly rotationHex: 53;
            };
            readonly possibleRsvFields: 5;
            readonly playerIds: {
                readonly 2: 3;
                readonly 6: 7;
                readonly 47: 48;
            };
            readonly blankFields: readonly [6, 47, 48];
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly sourceId: "4.{7}";
                };
                readonly combatantIdFields: readonly [2, 6];
            };
        };
        readonly NetworkAOEAbility: {
            readonly type: "22";
            readonly name: "NetworkAOEAbility";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "AOEActionEffect";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly source: 3;
                readonly id: 4;
                readonly ability: 5;
                readonly targetId: 6;
                readonly target: 7;
                readonly flags: 8;
                readonly damage: 9;
                readonly targetCurrentHp: 24;
                readonly targetMaxHp: 25;
                readonly targetCurrentMp: 26;
                readonly targetMaxMp: 27;
                readonly targetX: 30;
                readonly targetY: 31;
                readonly targetZ: 32;
                readonly targetHeading: 33;
                readonly currentHp: 34;
                readonly maxHp: 35;
                readonly currentMp: 36;
                readonly maxMp: 37;
                readonly x: 40;
                readonly y: 41;
                readonly z: 42;
                readonly heading: 43;
                readonly sequence: 44;
                readonly targetIndex: 45;
                readonly targetCount: 46;
                readonly ownerId: 47;
                readonly ownerName: 48;
                readonly effectDisplayType: 49;
                readonly actionId: 50;
                readonly actionAnimationId: 51;
                readonly animationLockTime: 52;
                readonly rotationHex: 53;
            };
            readonly possibleRsvFields: 5;
            readonly playerIds: {
                readonly 2: 3;
                readonly 6: 7;
                readonly 47: 48;
            };
            readonly blankFields: readonly [6, 47, 48];
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly sourceId: "4.{7}";
                };
                readonly combatantIdFields: readonly [2, 6];
            };
        };
        readonly NetworkCancelAbility: {
            readonly type: "23";
            readonly name: "NetworkCancelAbility";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "CancelAction";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly source: 3;
                readonly id: 4;
                readonly name: 5;
                readonly reason: 6;
            };
            readonly possibleRsvFields: 5;
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly sourceId: "4.{7}";
                };
                readonly combatantIdFields: 2;
            };
        };
        readonly NetworkDoT: {
            readonly type: "24";
            readonly name: "NetworkDoT";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "DoTHoT";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
                readonly which: 4;
                readonly effectId: 5;
                readonly damage: 6;
                readonly currentHp: 7;
                readonly maxHp: 8;
                readonly currentMp: 9;
                readonly maxMp: 10;
                readonly x: 13;
                readonly y: 14;
                readonly z: 15;
                readonly heading: 16;
                readonly sourceId: 17;
                readonly source: 18;
                readonly damageType: 19;
                readonly sourceCurrentHp: 20;
                readonly sourceMaxHp: 21;
                readonly sourceCurrentMp: 22;
                readonly sourceMaxMp: 23;
                readonly sourceX: 26;
                readonly sourceY: 27;
                readonly sourceZ: 28;
                readonly sourceHeading: 29;
            };
            readonly playerIds: {
                readonly 2: 3;
                readonly 17: 18;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly id: "1.{7}";
                    readonly which: "DoT";
                    readonly effectId: "0*?[1-9A-F][0-9A-F]*";
                };
                readonly combatantIdFields: readonly [2, 17];
            };
        };
        readonly WasDefeated: {
            readonly type: "25";
            readonly name: "WasDefeated";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Death";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly targetId: 2;
                readonly target: 3;
                readonly sourceId: 4;
                readonly source: 5;
            };
            readonly playerIds: {
                readonly 2: 3;
                readonly 4: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly targetId: "4.{7}";
                };
                readonly combatantIdFields: 2;
            };
        };
        readonly GainsEffect: {
            readonly type: "26";
            readonly name: "GainsEffect";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "StatusAdd";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly effectId: 2;
                readonly effect: 3;
                readonly duration: 4;
                readonly sourceId: 5;
                readonly source: 6;
                readonly targetId: 7;
                readonly target: 8;
                readonly count: 9;
                readonly targetMaxHp: 10;
                readonly sourceMaxHp: 11;
            };
            readonly possibleRsvFields: 3;
            readonly playerIds: {
                readonly 5: 6;
                readonly 7: 8;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: readonly [{
                    readonly sourceId: "[E4].{7}";
                    readonly targetId: "1.{7}";
                }, {
                    readonly sourceId: "[E4].{7}";
                    readonly targetId: "4.{7}";
                }, {
                    readonly effectId: readonly ["B9A", "808"];
                }];
                readonly combatantIdFields: readonly [5, 7];
            };
        };
        readonly HeadMarker: {
            readonly type: "27";
            readonly name: "HeadMarker";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "TargetIcon";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly targetId: 2;
                readonly target: 3;
                readonly id: 6;
                readonly data0: 7;
            };
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly possiblePlayerIds: readonly [7];
            readonly canAnonymize: true;
            readonly firstOptionalField: 7;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: 2;
            };
        };
        readonly NetworkRaidMarker: {
            readonly type: "28";
            readonly name: "NetworkRaidMarker";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "WaymarkMarker";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly operation: 2;
                readonly waymark: 3;
                readonly id: 4;
                readonly name: 5;
                readonly x: 6;
                readonly y: 7;
                readonly z: 8;
            };
            readonly playerIds: {
                readonly 4: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly NetworkTargetMarker: {
            readonly type: "29";
            readonly name: "NetworkTargetMarker";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "SignMarker";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly operation: 2;
                readonly waymark: 3;
                readonly id: 4;
                readonly name: 5;
                readonly targetId: 6;
                readonly targetName: 7;
            };
            readonly playerIds: {
                readonly 4: 5;
                readonly 6: 7;
            };
            readonly firstOptionalField: undefined;
        };
        readonly LosesEffect: {
            readonly type: "30";
            readonly name: "LosesEffect";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "StatusRemove";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly effectId: 2;
                readonly effect: 3;
                readonly sourceId: 5;
                readonly source: 6;
                readonly targetId: 7;
                readonly target: 8;
                readonly count: 9;
            };
            readonly possibleRsvFields: 3;
            readonly playerIds: {
                readonly 5: 6;
                readonly 7: 8;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: readonly [{
                    readonly sourceId: "[E4].{7}";
                    readonly targetId: "1.{7}";
                }, {
                    readonly sourceId: "[E4].{7}";
                    readonly targetId: "4.{7}";
                }, {
                    readonly effectId: readonly ["B9A", "808"];
                }];
                readonly combatantIdFields: readonly [5, 7];
            };
        };
        readonly NetworkGauge: {
            readonly type: "31";
            readonly name: "NetworkGauge";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Gauge";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly data0: 3;
                readonly data1: 4;
                readonly data2: 5;
                readonly data3: 6;
            };
            readonly playerIds: {
                readonly 2: null;
            };
            readonly firstUnknownField: 3;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly NetworkWorld: {
            readonly type: "32";
            readonly name: "NetworkWorld";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "World";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly isUnknown: true;
            readonly firstOptionalField: undefined;
        };
        readonly ActorControl: {
            readonly type: "33";
            readonly name: "ActorControl";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Director";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly instance: 2;
                readonly command: 3;
                readonly data0: 4;
                readonly data1: 5;
                readonly data2: 6;
                readonly data3: 7;
            };
            readonly possiblePlayerIds: readonly [4, 5, 6, 7];
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly NameToggle: {
            readonly type: "34";
            readonly name: "NameToggle";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "NameToggle";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
                readonly targetId: 4;
                readonly targetName: 5;
                readonly toggle: 6;
            };
            readonly playerIds: {
                readonly 2: 3;
                readonly 4: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly Tether: {
            readonly type: "35";
            readonly name: "Tether";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Tether";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly source: 3;
                readonly targetId: 4;
                readonly target: 5;
                readonly id: 8;
            };
            readonly playerIds: {
                readonly 2: 3;
                readonly 4: 5;
            };
            readonly canAnonymize: true;
            readonly firstUnknownField: 9;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: readonly [2, 4];
            };
        };
        readonly LimitBreak: {
            readonly type: "36";
            readonly name: "LimitBreak";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "LimitBreak";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly valueHex: 2;
                readonly bars: 3;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly NetworkEffectResult: {
            readonly type: "37";
            readonly name: "NetworkEffectResult";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "EffectResult";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
                readonly sequenceId: 4;
                readonly currentHp: 5;
                readonly maxHp: 6;
                readonly currentMp: 7;
                readonly maxMp: 8;
                readonly currentShield: 9;
                readonly x: 11;
                readonly y: 12;
                readonly z: 13;
                readonly heading: 14;
            };
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly firstUnknownField: 22;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly StatusEffect: {
            readonly type: "38";
            readonly name: "StatusEffect";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "StatusList";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly targetId: 2;
                readonly target: 3;
                readonly jobLevelData: 4;
                readonly hp: 5;
                readonly maxHp: 6;
                readonly mp: 7;
                readonly maxMp: 8;
                readonly currentShield: 9;
                readonly x: 11;
                readonly y: 12;
                readonly z: 13;
                readonly heading: 14;
                readonly data0: 15;
                readonly data1: 16;
                readonly data2: 17;
                readonly data3: 18;
                readonly data4: 19;
                readonly data5: 20;
            };
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly firstUnknownField: 18;
            readonly canAnonymize: true;
            readonly firstOptionalField: 18;
        };
        readonly NetworkUpdateHP: {
            readonly type: "39";
            readonly name: "NetworkUpdateHP";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "UpdateHp";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
                readonly currentHp: 4;
                readonly maxHp: 5;
                readonly currentMp: 6;
                readonly maxMp: 7;
                readonly x: 10;
                readonly y: 11;
                readonly z: 12;
                readonly heading: 13;
            };
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly Map: {
            readonly type: "40";
            readonly name: "Map";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "ChangeMap";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly regionName: 3;
                readonly placeName: 4;
                readonly placeNameSub: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly lastInclude: true;
            readonly analysisOptions: {
                readonly include: "all";
            };
        };
        readonly SystemLogMessage: {
            readonly type: "41";
            readonly name: "SystemLogMessage";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "SystemLogMessage";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly instance: 2;
                readonly id: 3;
                readonly param0: 4;
                readonly param1: 5;
                readonly param2: 6;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
            };
        };
        readonly StatusList3: {
            readonly type: "42";
            readonly name: "StatusList3";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "StatusList3";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly name: 3;
            };
            readonly playerIds: {
                readonly 2: 3;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: 4;
            readonly firstUnknownField: 4;
        };
        readonly ParserInfo: {
            readonly type: "249";
            readonly name: "ParserInfo";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Settings";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly globalInclude: true;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly ProcessInfo: {
            readonly type: "250";
            readonly name: "ProcessInfo";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Process";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly globalInclude: true;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly Debug: {
            readonly type: "251";
            readonly name: "Debug";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Debug";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly globalInclude: true;
            readonly canAnonymize: false;
            readonly firstOptionalField: undefined;
        };
        readonly PacketDump: {
            readonly type: "252";
            readonly name: "PacketDump";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "PacketDump";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly canAnonymize: false;
            readonly firstOptionalField: undefined;
        };
        readonly Version: {
            readonly type: "253";
            readonly name: "Version";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Version";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly globalInclude: true;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly Error: {
            readonly type: "254";
            readonly name: "Error";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "Error";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly canAnonymize: false;
            readonly firstOptionalField: undefined;
        };
        readonly None: {
            readonly type: "[0-9]+";
            readonly name: "None";
            readonly source: "FFXIV_ACT_Plugin";
            readonly messageType: "None";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
            };
            readonly isUnknown: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly LineRegistration: {
            readonly type: "256";
            readonly name: "LineRegistration";
            readonly source: "OverlayPlugin";
            readonly messageType: "256";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly source: 3;
                readonly name: 4;
                readonly version: 5;
            };
            readonly globalInclude: true;
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly MapEffect: {
            readonly type: "257";
            readonly name: "MapEffect";
            readonly source: "OverlayPlugin";
            readonly messageType: "257";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly instance: 2;
                readonly flags: 3;
                readonly location: 4;
                readonly data0: 5;
                readonly data1: 6;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
            };
        };
        readonly FateDirector: {
            readonly type: "258";
            readonly name: "FateDirector";
            readonly source: "OverlayPlugin";
            readonly messageType: "258";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly category: 2;
                readonly fateId: 4;
                readonly progress: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly CEDirector: {
            readonly type: "259";
            readonly name: "CEDirector";
            readonly source: "OverlayPlugin";
            readonly messageType: "259";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly popTime: 2;
                readonly timeRemaining: 3;
                readonly ceKey: 5;
                readonly numPlayers: 6;
                readonly status: 7;
                readonly progress: 9;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly InCombat: {
            readonly type: "260";
            readonly name: "InCombat";
            readonly source: "OverlayPlugin";
            readonly messageType: "260";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly inACTCombat: 2;
                readonly inGameCombat: 3;
                readonly isACTChanged: 4;
                readonly isGameChanged: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
            };
        };
        readonly CombatantMemory: {
            readonly type: "261";
            readonly name: "CombatantMemory";
            readonly source: "OverlayPlugin";
            readonly messageType: "261";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly change: 2;
                readonly id: 3;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: 5;
            readonly repeatingFields: {
                readonly startingIndex: 4;
                readonly label: "pair";
                readonly names: readonly ["key", "value"];
                readonly sortKeys: true;
                readonly primaryKey: "key";
                readonly possibleKeys: readonly (keyof PluginCombatantState)[];
                readonly keysToAnonymize: {
                    readonly 3: "Name";
                    readonly OwnerID: null;
                    readonly TargetID: null;
                    readonly PCTargetID: null;
                    readonly NPCTargetID: null;
                    readonly CastTargetID: null;
                };
            };
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: readonly [{
                    readonly id: "4.{7}";
                    readonly change: "Change";
                    readonly pair: readonly [{
                        readonly key: "ModelStatus";
                        readonly value: ".*";
                    }];
                }, {
                    readonly id: "4.{7}";
                    readonly change: "Change";
                    readonly pair: readonly [{
                        readonly key: "WeaponId";
                        readonly value: ".*";
                    }];
                }, {
                    readonly id: "4.{7}";
                    readonly change: "Change";
                    readonly pair: readonly [{
                        readonly key: "TransformationId";
                        readonly value: ".*";
                    }];
                }];
                readonly combatantIdFields: 3;
            };
        };
        readonly RSVData: {
            readonly type: "262";
            readonly name: "RSVData";
            readonly source: "OverlayPlugin";
            readonly messageType: "262";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly locale: 2;
                readonly key: 4;
                readonly value: 5;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly StartsUsingExtra: {
            readonly type: "263";
            readonly name: "StartsUsingExtra";
            readonly source: "OverlayPlugin";
            readonly messageType: "263";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly id: 3;
                readonly x: 4;
                readonly y: 5;
                readonly z: 6;
                readonly heading: 7;
            };
            readonly playerIds: {
                readonly 2: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly sourceId: "4.{7}";
                };
                readonly combatantIdFields: 2;
            };
        };
        readonly AbilityExtra: {
            readonly type: "264";
            readonly name: "AbilityExtra";
            readonly source: "OverlayPlugin";
            readonly messageType: "264";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly sourceId: 2;
                readonly id: 3;
                readonly globalEffectCounter: 4;
                readonly dataFlag: 5;
                readonly x: 6;
                readonly y: 7;
                readonly z: 8;
                readonly heading: 9;
                readonly animationTargetId: 10;
            };
            readonly blankFields: readonly [6, 7, 8];
            readonly playerIds: {
                readonly 2: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly ContentFinderSettings: {
            readonly type: "265";
            readonly name: "ContentFinderSettings";
            readonly source: "OverlayPlugin";
            readonly messageType: "265";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly zoneId: 2;
                readonly zoneName: 3;
                readonly inContentFinderContent: 4;
                readonly unrestrictedParty: 5;
                readonly minimalItemLevel: 6;
                readonly silenceEcho: 7;
                readonly explorerMode: 8;
                readonly levelSync: 9;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
        };
        readonly NpcYell: {
            readonly type: "266";
            readonly name: "NpcYell";
            readonly source: "OverlayPlugin";
            readonly messageType: "266";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly npcId: 2;
                readonly npcNameId: 3;
                readonly npcYellId: 4;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: 2;
            };
        };
        readonly BattleTalk2: {
            readonly type: "267";
            readonly name: "BattleTalk2";
            readonly source: "OverlayPlugin";
            readonly messageType: "267";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly npcId: 2;
                readonly instance: 3;
                readonly npcNameId: 4;
                readonly instanceContentTextId: 5;
                readonly displayMs: 6;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: 2;
            };
        };
        readonly Countdown: {
            readonly type: "268";
            readonly name: "Countdown";
            readonly source: "OverlayPlugin";
            readonly messageType: "268";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly worldId: 3;
                readonly countdownTime: 4;
                readonly result: 5;
                readonly name: 6;
            };
            readonly playerIds: {
                readonly 2: 6;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly CountdownCancel: {
            readonly type: "269";
            readonly name: "CountdownCancel";
            readonly source: "OverlayPlugin";
            readonly messageType: "269";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly worldId: 3;
                readonly name: 4;
            };
            readonly playerIds: {
                readonly 2: 4;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly ActorMove: {
            readonly type: "270";
            readonly name: "ActorMove";
            readonly source: "OverlayPlugin";
            readonly messageType: "270";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly heading: 3;
                readonly x: 6;
                readonly y: 7;
                readonly z: 8;
            };
            readonly playerIds: {
                readonly 2: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "never";
            };
        };
        readonly ActorSetPos: {
            readonly type: "271";
            readonly name: "ActorSetPos";
            readonly source: "OverlayPlugin";
            readonly messageType: "271";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly heading: 3;
                readonly x: 6;
                readonly y: 7;
                readonly z: 8;
            };
            readonly playerIds: {
                readonly 2: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "filter";
                readonly filters: {
                    readonly id: "4.{7}";
                };
                readonly combatantIdFields: 2;
            };
        };
        readonly SpawnNpcExtra: {
            readonly type: "272";
            readonly name: "SpawnNpcExtra";
            readonly source: "OverlayPlugin";
            readonly messageType: "272";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly parentId: 3;
                readonly tetherId: 4;
                readonly animationState: 5;
            };
            readonly playerIds: {
                readonly 3: null;
            };
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: readonly [2, 3];
            };
        };
        readonly ActorControlExtra: {
            readonly type: "273";
            readonly name: "ActorControlExtra";
            readonly source: "OverlayPlugin";
            readonly messageType: "273";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly category: 3;
                readonly param1: 4;
                readonly param2: 5;
                readonly param3: 6;
                readonly param4: 7;
            };
            readonly playerIds: {
                readonly 2: null;
            };
            readonly possiblePlayerIds: readonly [4, 5, 6, 7];
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: 2;
            };
        };
        readonly ActorControlSelfExtra: {
            readonly type: "274";
            readonly name: "ActorControlSelfExtra";
            readonly source: "OverlayPlugin";
            readonly messageType: "274";
            readonly fields: {
                readonly type: 0;
                readonly timestamp: 1;
                readonly id: 2;
                readonly category: 3;
                readonly param1: 4;
                readonly param2: 5;
                readonly param3: 6;
                readonly param4: 7;
                readonly param5: 8;
                readonly param6: 9;
            };
            readonly playerIds: {
                readonly 2: null;
            };
            readonly possiblePlayerIds: readonly [4, 5, 6, 7, 8, 9];
            readonly canAnonymize: true;
            readonly firstOptionalField: undefined;
            readonly analysisOptions: {
                readonly include: "all";
                readonly combatantIdFields: 2;
            };
        };
    };
};
export type LogDefinitions = typeof latestLogDefinitions;
export type LogDefinitionName = keyof LogDefinitions;
export type LogDefinitionType = LogDefinitions[LogDefinitionName]['type'];
export type LogDefinitionMap = {
    [K in LogDefinitionName]: LogDefinition<K>;
};
export type LogDefinitionVersions = keyof typeof logDefinitionsVersions;
type RepeatingFieldsNarrowingType = {
    readonly repeatingFields: unknown;
};
export type RepeatingFieldsTypes = keyof {
    [type in LogDefinitionName as LogDefinitions[type] extends RepeatingFieldsNarrowingType ? type : never]: null;
};
export type RepeatingFieldsDefinitions = {
    [type in RepeatingFieldsTypes]: LogDefinitions[type] & {
        readonly repeatingFields: Exclude<LogDefinitions[type]['repeatingFields'], undefined>;
    };
};
export type ParseHelperField<Type extends LogDefinitionName, Fields extends NetFieldsReverse[Type], Field extends keyof Fields> = {
    field: Fields[Field] extends string ? Fields[Field] : never;
    value?: string;
    optional?: boolean;
    repeating?: boolean;
    repeatingKeys?: string[];
    sortKeys?: boolean;
    primaryKey?: string;
    possibleKeys?: string[];
};
export type ParseHelperFields<T extends LogDefinitionName> = {
    [field in keyof NetFieldsReverse[T]]: ParseHelperField<T, NetFieldsReverse[T], field>;
};
declare const _default: {
    readonly GameLog: {
        readonly type: "00";
        readonly name: "GameLog";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ChatLog";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly code: 2;
            readonly name: 3;
            readonly line: 4;
        };
        readonly subFields: {
            readonly code: {
                readonly '0039': {
                    readonly name: "message";
                    readonly canAnonymize: true;
                };
                readonly '0038': {
                    readonly name: "echo";
                    readonly canAnonymize: true;
                };
                readonly '0044': {
                    readonly name: "dialog";
                    readonly canAnonymize: true;
                };
                readonly '0839': {
                    readonly name: "message";
                    readonly canAnonymize: true;
                };
            };
        };
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly code: readonly ["0044", "0839"];
            };
        };
    };
    readonly ChangeZone: {
        readonly type: "01";
        readonly name: "ChangeZone";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Territory";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
        };
        readonly lastInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly ChangedPlayer: {
        readonly type: "02";
        readonly name: "ChangedPlayer";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ChangePrimaryPlayer";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly lastInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly AddedCombatant: {
        readonly type: "03";
        readonly name: "AddedCombatant";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "AddCombatant";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly job: 4;
            readonly level: 5;
            readonly ownerId: 6;
            readonly worldId: 7;
            readonly world: 8;
            readonly npcNameId: 9;
            readonly npcBaseId: 10;
            readonly currentHp: 11;
            readonly hp: 12;
            readonly currentMp: 13;
            readonly mp: 14;
            readonly x: 17;
            readonly y: 18;
            readonly z: 19;
            readonly heading: 20;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly RemovedCombatant: {
        readonly type: "04";
        readonly name: "RemovedCombatant";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "RemoveCombatant";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly job: 4;
            readonly level: 5;
            readonly owner: 6;
            readonly world: 8;
            readonly npcNameId: 9;
            readonly npcBaseId: 10;
            readonly currentHp: 11;
            readonly hp: 12;
            readonly currentMp: 13;
            readonly mp: 14;
            readonly x: 17;
            readonly y: 18;
            readonly z: 19;
            readonly heading: 20;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly PartyList: {
        readonly type: "11";
        readonly name: "PartyList";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "PartyList";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly partyCount: 2;
            readonly id0: 3;
            readonly id1: 4;
            readonly id2: 5;
            readonly id3: 6;
            readonly id4: 7;
            readonly id5: 8;
            readonly id6: 9;
            readonly id7: 10;
            readonly id8: 11;
            readonly id9: 12;
            readonly id10: 13;
            readonly id11: 14;
            readonly id12: 15;
            readonly id13: 16;
            readonly id14: 17;
            readonly id15: 18;
            readonly id16: 19;
            readonly id17: 20;
            readonly id18: 21;
            readonly id19: 22;
            readonly id20: 23;
            readonly id21: 24;
            readonly id22: 25;
            readonly id23: 26;
        };
        readonly playerIds: {
            readonly 3: null;
            readonly 4: null;
            readonly 5: null;
            readonly 6: null;
            readonly 7: null;
            readonly 8: null;
            readonly 9: null;
            readonly 10: null;
            readonly 11: null;
            readonly 12: null;
            readonly 13: null;
            readonly 14: null;
            readonly 15: null;
            readonly 16: null;
            readonly 17: null;
            readonly 18: null;
            readonly 19: null;
            readonly 20: null;
            readonly 21: null;
            readonly 22: null;
            readonly 23: null;
            readonly 24: null;
            readonly 25: null;
            readonly 26: null;
        };
        readonly firstOptionalField: 3;
        readonly canAnonymize: true;
        readonly lastInclude: true;
    };
    readonly PlayerStats: {
        readonly type: "12";
        readonly name: "PlayerStats";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "PlayerStats";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly job: 2;
            readonly strength: 3;
            readonly dexterity: 4;
            readonly vitality: 5;
            readonly intelligence: 6;
            readonly mind: 7;
            readonly piety: 8;
            readonly attackPower: 9;
            readonly directHit: 10;
            readonly criticalHit: 11;
            readonly attackMagicPotency: 12;
            readonly healMagicPotency: 13;
            readonly determination: 14;
            readonly skillSpeed: 15;
            readonly spellSpeed: 16;
            readonly tenacity: 18;
            readonly localContentId: 19;
        };
        readonly canAnonymize: true;
        readonly lastInclude: true;
        readonly firstOptionalField: undefined;
    };
    readonly StartsUsing: {
        readonly type: "20";
        readonly name: "StartsUsing";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StartsCasting";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly ability: 5;
            readonly targetId: 6;
            readonly target: 7;
            readonly castTime: 8;
            readonly x: 9;
            readonly y: 10;
            readonly z: 11;
            readonly heading: 12;
        };
        readonly possibleRsvFields: 5;
        readonly blankFields: readonly [6];
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: 7;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: readonly [2, 6];
        };
    };
    readonly Ability: {
        readonly type: "21";
        readonly name: "Ability";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ActionEffect";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly ability: 5;
            readonly targetId: 6;
            readonly target: 7;
            readonly flags: 8;
            readonly damage: 9;
            readonly targetCurrentHp: 24;
            readonly targetMaxHp: 25;
            readonly targetCurrentMp: 26;
            readonly targetMaxMp: 27;
            readonly targetX: 30;
            readonly targetY: 31;
            readonly targetZ: 32;
            readonly targetHeading: 33;
            readonly currentHp: 34;
            readonly maxHp: 35;
            readonly currentMp: 36;
            readonly maxMp: 37;
            readonly x: 40;
            readonly y: 41;
            readonly z: 42;
            readonly heading: 43;
            readonly sequence: 44;
            readonly targetIndex: 45;
            readonly targetCount: 46;
            readonly ownerId: 47;
            readonly ownerName: 48;
            readonly effectDisplayType: 49;
            readonly actionId: 50;
            readonly actionAnimationId: 51;
            readonly animationLockTime: 52;
            readonly rotationHex: 53;
        };
        readonly possibleRsvFields: 5;
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: 7;
            readonly 47: 48;
        };
        readonly blankFields: readonly [6, 47, 48];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: readonly [2, 6];
        };
    };
    readonly NetworkAOEAbility: {
        readonly type: "22";
        readonly name: "NetworkAOEAbility";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "AOEActionEffect";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly ability: 5;
            readonly targetId: 6;
            readonly target: 7;
            readonly flags: 8;
            readonly damage: 9;
            readonly targetCurrentHp: 24;
            readonly targetMaxHp: 25;
            readonly targetCurrentMp: 26;
            readonly targetMaxMp: 27;
            readonly targetX: 30;
            readonly targetY: 31;
            readonly targetZ: 32;
            readonly targetHeading: 33;
            readonly currentHp: 34;
            readonly maxHp: 35;
            readonly currentMp: 36;
            readonly maxMp: 37;
            readonly x: 40;
            readonly y: 41;
            readonly z: 42;
            readonly heading: 43;
            readonly sequence: 44;
            readonly targetIndex: 45;
            readonly targetCount: 46;
            readonly ownerId: 47;
            readonly ownerName: 48;
            readonly effectDisplayType: 49;
            readonly actionId: 50;
            readonly actionAnimationId: 51;
            readonly animationLockTime: 52;
            readonly rotationHex: 53;
        };
        readonly possibleRsvFields: 5;
        readonly playerIds: {
            readonly 2: 3;
            readonly 6: 7;
            readonly 47: 48;
        };
        readonly blankFields: readonly [6, 47, 48];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: readonly [2, 6];
        };
    };
    readonly NetworkCancelAbility: {
        readonly type: "23";
        readonly name: "NetworkCancelAbility";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "CancelAction";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly id: 4;
            readonly name: 5;
            readonly reason: 6;
        };
        readonly possibleRsvFields: 5;
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly NetworkDoT: {
        readonly type: "24";
        readonly name: "NetworkDoT";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "DoTHoT";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly which: 4;
            readonly effectId: 5;
            readonly damage: 6;
            readonly currentHp: 7;
            readonly maxHp: 8;
            readonly currentMp: 9;
            readonly maxMp: 10;
            readonly x: 13;
            readonly y: 14;
            readonly z: 15;
            readonly heading: 16;
            readonly sourceId: 17;
            readonly source: 18;
            readonly damageType: 19;
            readonly sourceCurrentHp: 20;
            readonly sourceMaxHp: 21;
            readonly sourceCurrentMp: 22;
            readonly sourceMaxMp: 23;
            readonly sourceX: 26;
            readonly sourceY: 27;
            readonly sourceZ: 28;
            readonly sourceHeading: 29;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 17: 18;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "1.{7}";
                readonly which: "DoT";
                readonly effectId: "0*?[1-9A-F][0-9A-F]*";
            };
            readonly combatantIdFields: readonly [2, 17];
        };
    };
    readonly WasDefeated: {
        readonly type: "25";
        readonly name: "WasDefeated";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Death";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly targetId: 2;
            readonly target: 3;
            readonly sourceId: 4;
            readonly source: 5;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly targetId: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly GainsEffect: {
        readonly type: "26";
        readonly name: "GainsEffect";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusAdd";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly effectId: 2;
            readonly effect: 3;
            readonly duration: 4;
            readonly sourceId: 5;
            readonly source: 6;
            readonly targetId: 7;
            readonly target: 8;
            readonly count: 9;
            readonly targetMaxHp: 10;
            readonly sourceMaxHp: 11;
        };
        readonly possibleRsvFields: 3;
        readonly playerIds: {
            readonly 5: 6;
            readonly 7: 8;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: readonly [{
                readonly sourceId: "[E4].{7}";
                readonly targetId: "1.{7}";
            }, {
                readonly sourceId: "[E4].{7}";
                readonly targetId: "4.{7}";
            }, {
                readonly effectId: readonly ["B9A", "808"];
            }];
            readonly combatantIdFields: readonly [5, 7];
        };
    };
    readonly HeadMarker: {
        readonly type: "27";
        readonly name: "HeadMarker";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "TargetIcon";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly targetId: 2;
            readonly target: 3;
            readonly id: 6;
            readonly data0: 7;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly possiblePlayerIds: readonly [7];
        readonly canAnonymize: true;
        readonly firstOptionalField: 7;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly NetworkRaidMarker: {
        readonly type: "28";
        readonly name: "NetworkRaidMarker";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "WaymarkMarker";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly operation: 2;
            readonly waymark: 3;
            readonly id: 4;
            readonly name: 5;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
        };
        readonly playerIds: {
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NetworkTargetMarker: {
        readonly type: "29";
        readonly name: "NetworkTargetMarker";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "SignMarker";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly operation: 2;
            readonly waymark: 3;
            readonly id: 4;
            readonly name: 5;
            readonly targetId: 6;
            readonly targetName: 7;
        };
        readonly playerIds: {
            readonly 4: 5;
            readonly 6: 7;
        };
        readonly firstOptionalField: undefined;
    };
    readonly LosesEffect: {
        readonly type: "30";
        readonly name: "LosesEffect";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusRemove";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly effectId: 2;
            readonly effect: 3;
            readonly sourceId: 5;
            readonly source: 6;
            readonly targetId: 7;
            readonly target: 8;
            readonly count: 9;
        };
        readonly possibleRsvFields: 3;
        readonly playerIds: {
            readonly 5: 6;
            readonly 7: 8;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: readonly [{
                readonly sourceId: "[E4].{7}";
                readonly targetId: "1.{7}";
            }, {
                readonly sourceId: "[E4].{7}";
                readonly targetId: "4.{7}";
            }, {
                readonly effectId: readonly ["B9A", "808"];
            }];
            readonly combatantIdFields: readonly [5, 7];
        };
    };
    readonly NetworkGauge: {
        readonly type: "31";
        readonly name: "NetworkGauge";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Gauge";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly data0: 3;
            readonly data1: 4;
            readonly data2: 5;
            readonly data3: 6;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly firstUnknownField: 3;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NetworkWorld: {
        readonly type: "32";
        readonly name: "NetworkWorld";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "World";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly isUnknown: true;
        readonly firstOptionalField: undefined;
    };
    readonly ActorControl: {
        readonly type: "33";
        readonly name: "ActorControl";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Director";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly instance: 2;
            readonly command: 3;
            readonly data0: 4;
            readonly data1: 5;
            readonly data2: 6;
            readonly data3: 7;
        };
        readonly possiblePlayerIds: readonly [4, 5, 6, 7];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly NameToggle: {
        readonly type: "34";
        readonly name: "NameToggle";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "NameToggle";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly targetId: 4;
            readonly targetName: 5;
            readonly toggle: 6;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly Tether: {
        readonly type: "35";
        readonly name: "Tether";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Tether";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly source: 3;
            readonly targetId: 4;
            readonly target: 5;
            readonly id: 8;
        };
        readonly playerIds: {
            readonly 2: 3;
            readonly 4: 5;
        };
        readonly canAnonymize: true;
        readonly firstUnknownField: 9;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: readonly [2, 4];
        };
    };
    readonly LimitBreak: {
        readonly type: "36";
        readonly name: "LimitBreak";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "LimitBreak";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly valueHex: 2;
            readonly bars: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NetworkEffectResult: {
        readonly type: "37";
        readonly name: "NetworkEffectResult";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "EffectResult";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly sequenceId: 4;
            readonly currentHp: 5;
            readonly maxHp: 6;
            readonly currentMp: 7;
            readonly maxMp: 8;
            readonly currentShield: 9;
            readonly x: 11;
            readonly y: 12;
            readonly z: 13;
            readonly heading: 14;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly firstUnknownField: 22;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly StatusEffect: {
        readonly type: "38";
        readonly name: "StatusEffect";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusList";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly targetId: 2;
            readonly target: 3;
            readonly jobLevelData: 4;
            readonly hp: 5;
            readonly maxHp: 6;
            readonly mp: 7;
            readonly maxMp: 8;
            readonly currentShield: 9;
            readonly x: 11;
            readonly y: 12;
            readonly z: 13;
            readonly heading: 14;
            readonly data0: 15;
            readonly data1: 16;
            readonly data2: 17;
            readonly data3: 18;
            readonly data4: 19;
            readonly data5: 20;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly firstUnknownField: 18;
        readonly canAnonymize: true;
        readonly firstOptionalField: 18;
    };
    readonly NetworkUpdateHP: {
        readonly type: "39";
        readonly name: "NetworkUpdateHP";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "UpdateHp";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
            readonly currentHp: 4;
            readonly maxHp: 5;
            readonly currentMp: 6;
            readonly maxMp: 7;
            readonly x: 10;
            readonly y: 11;
            readonly z: 12;
            readonly heading: 13;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly Map: {
        readonly type: "40";
        readonly name: "Map";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "ChangeMap";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly regionName: 3;
            readonly placeName: 4;
            readonly placeNameSub: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly lastInclude: true;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly SystemLogMessage: {
        readonly type: "41";
        readonly name: "SystemLogMessage";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "SystemLogMessage";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly instance: 2;
            readonly id: 3;
            readonly param0: 4;
            readonly param1: 5;
            readonly param2: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly StatusList3: {
        readonly type: "42";
        readonly name: "StatusList3";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "StatusList3";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly name: 3;
        };
        readonly playerIds: {
            readonly 2: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: 4;
        readonly firstUnknownField: 4;
    };
    readonly ParserInfo: {
        readonly type: "249";
        readonly name: "ParserInfo";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Settings";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly ProcessInfo: {
        readonly type: "250";
        readonly name: "ProcessInfo";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Process";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly Debug: {
        readonly type: "251";
        readonly name: "Debug";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Debug";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: false;
        readonly firstOptionalField: undefined;
    };
    readonly PacketDump: {
        readonly type: "252";
        readonly name: "PacketDump";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "PacketDump";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly canAnonymize: false;
        readonly firstOptionalField: undefined;
    };
    readonly Version: {
        readonly type: "253";
        readonly name: "Version";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Version";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly Error: {
        readonly type: "254";
        readonly name: "Error";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "Error";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly canAnonymize: false;
        readonly firstOptionalField: undefined;
    };
    readonly None: {
        readonly type: "[0-9]+";
        readonly name: "None";
        readonly source: "FFXIV_ACT_Plugin";
        readonly messageType: "None";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
        };
        readonly isUnknown: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly LineRegistration: {
        readonly type: "256";
        readonly name: "LineRegistration";
        readonly source: "OverlayPlugin";
        readonly messageType: "256";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly source: 3;
            readonly name: 4;
            readonly version: 5;
        };
        readonly globalInclude: true;
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly MapEffect: {
        readonly type: "257";
        readonly name: "MapEffect";
        readonly source: "OverlayPlugin";
        readonly messageType: "257";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly instance: 2;
            readonly flags: 3;
            readonly location: 4;
            readonly data0: 5;
            readonly data1: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly FateDirector: {
        readonly type: "258";
        readonly name: "FateDirector";
        readonly source: "OverlayPlugin";
        readonly messageType: "258";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly category: 2;
            readonly fateId: 4;
            readonly progress: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly CEDirector: {
        readonly type: "259";
        readonly name: "CEDirector";
        readonly source: "OverlayPlugin";
        readonly messageType: "259";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly popTime: 2;
            readonly timeRemaining: 3;
            readonly ceKey: 5;
            readonly numPlayers: 6;
            readonly status: 7;
            readonly progress: 9;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly InCombat: {
        readonly type: "260";
        readonly name: "InCombat";
        readonly source: "OverlayPlugin";
        readonly messageType: "260";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly inACTCombat: 2;
            readonly inGameCombat: 3;
            readonly isACTChanged: 4;
            readonly isGameChanged: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
        };
    };
    readonly CombatantMemory: {
        readonly type: "261";
        readonly name: "CombatantMemory";
        readonly source: "OverlayPlugin";
        readonly messageType: "261";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly change: 2;
            readonly id: 3;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: 5;
        readonly repeatingFields: {
            readonly startingIndex: 4;
            readonly label: "pair";
            readonly names: readonly ["key", "value"];
            readonly sortKeys: true;
            readonly primaryKey: "key";
            readonly possibleKeys: readonly (keyof PluginCombatantState)[];
            readonly keysToAnonymize: {
                readonly 3: "Name";
                readonly OwnerID: null;
                readonly TargetID: null;
                readonly PCTargetID: null;
                readonly NPCTargetID: null;
                readonly CastTargetID: null;
            };
        };
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: readonly [{
                readonly id: "4.{7}";
                readonly change: "Change";
                readonly pair: readonly [{
                    readonly key: "ModelStatus";
                    readonly value: ".*";
                }];
            }, {
                readonly id: "4.{7}";
                readonly change: "Change";
                readonly pair: readonly [{
                    readonly key: "WeaponId";
                    readonly value: ".*";
                }];
            }, {
                readonly id: "4.{7}";
                readonly change: "Change";
                readonly pair: readonly [{
                    readonly key: "TransformationId";
                    readonly value: ".*";
                }];
            }];
            readonly combatantIdFields: 3;
        };
    };
    readonly RSVData: {
        readonly type: "262";
        readonly name: "RSVData";
        readonly source: "OverlayPlugin";
        readonly messageType: "262";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly locale: 2;
            readonly key: 4;
            readonly value: 5;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly StartsUsingExtra: {
        readonly type: "263";
        readonly name: "StartsUsingExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "263";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly id: 3;
            readonly x: 4;
            readonly y: 5;
            readonly z: 6;
            readonly heading: 7;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly sourceId: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly AbilityExtra: {
        readonly type: "264";
        readonly name: "AbilityExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "264";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly sourceId: 2;
            readonly id: 3;
            readonly globalEffectCounter: 4;
            readonly dataFlag: 5;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
            readonly heading: 9;
            readonly animationTargetId: 10;
        };
        readonly blankFields: readonly [6, 7, 8];
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly ContentFinderSettings: {
        readonly type: "265";
        readonly name: "ContentFinderSettings";
        readonly source: "OverlayPlugin";
        readonly messageType: "265";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly zoneId: 2;
            readonly zoneName: 3;
            readonly inContentFinderContent: 4;
            readonly unrestrictedParty: 5;
            readonly minimalItemLevel: 6;
            readonly silenceEcho: 7;
            readonly explorerMode: 8;
            readonly levelSync: 9;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
    };
    readonly NpcYell: {
        readonly type: "266";
        readonly name: "NpcYell";
        readonly source: "OverlayPlugin";
        readonly messageType: "266";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly npcId: 2;
            readonly npcNameId: 3;
            readonly npcYellId: 4;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly BattleTalk2: {
        readonly type: "267";
        readonly name: "BattleTalk2";
        readonly source: "OverlayPlugin";
        readonly messageType: "267";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly npcId: 2;
            readonly instance: 3;
            readonly npcNameId: 4;
            readonly instanceContentTextId: 5;
            readonly displayMs: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly Countdown: {
        readonly type: "268";
        readonly name: "Countdown";
        readonly source: "OverlayPlugin";
        readonly messageType: "268";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly worldId: 3;
            readonly countdownTime: 4;
            readonly result: 5;
            readonly name: 6;
        };
        readonly playerIds: {
            readonly 2: 6;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly CountdownCancel: {
        readonly type: "269";
        readonly name: "CountdownCancel";
        readonly source: "OverlayPlugin";
        readonly messageType: "269";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly worldId: 3;
            readonly name: 4;
        };
        readonly playerIds: {
            readonly 2: 4;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly ActorMove: {
        readonly type: "270";
        readonly name: "ActorMove";
        readonly source: "OverlayPlugin";
        readonly messageType: "270";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly heading: 3;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "never";
        };
    };
    readonly ActorSetPos: {
        readonly type: "271";
        readonly name: "ActorSetPos";
        readonly source: "OverlayPlugin";
        readonly messageType: "271";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly heading: 3;
            readonly x: 6;
            readonly y: 7;
            readonly z: 8;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "filter";
            readonly filters: {
                readonly id: "4.{7}";
            };
            readonly combatantIdFields: 2;
        };
    };
    readonly SpawnNpcExtra: {
        readonly type: "272";
        readonly name: "SpawnNpcExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "272";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly parentId: 3;
            readonly tetherId: 4;
            readonly animationState: 5;
        };
        readonly playerIds: {
            readonly 3: null;
        };
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: readonly [2, 3];
        };
    };
    readonly ActorControlExtra: {
        readonly type: "273";
        readonly name: "ActorControlExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "273";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly category: 3;
            readonly param1: 4;
            readonly param2: 5;
            readonly param3: 6;
            readonly param4: 7;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly possiblePlayerIds: readonly [4, 5, 6, 7];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
    readonly ActorControlSelfExtra: {
        readonly type: "274";
        readonly name: "ActorControlSelfExtra";
        readonly source: "OverlayPlugin";
        readonly messageType: "274";
        readonly fields: {
            readonly type: 0;
            readonly timestamp: 1;
            readonly id: 2;
            readonly category: 3;
            readonly param1: 4;
            readonly param2: 5;
            readonly param3: 6;
            readonly param4: 7;
            readonly param5: 8;
            readonly param6: 9;
        };
        readonly playerIds: {
            readonly 2: null;
        };
        readonly possiblePlayerIds: readonly [4, 5, 6, 7, 8, 9];
        readonly canAnonymize: true;
        readonly firstOptionalField: undefined;
        readonly analysisOptions: {
            readonly include: "all";
            readonly combatantIdFields: 2;
        };
    };
};
export default _default;
