import { NetFields } from '../types/net_fields';
import { NetParams } from '../types/net_props';
import { CactbotBaseRegExp } from '../types/net_trigger';
import { LogDefinitionName, LogDefinitionVersions, RepeatingFieldsDefinitions, RepeatingFieldsTypes } from './netlog_defs';
declare const keysThatRequireTranslationAsConst: readonly ["ability", "name", "source", "target", "line"];
export declare const keysThatRequireTranslation: readonly string[];
export type KeysThatRequireTranslation = typeof keysThatRequireTranslationAsConst[number];
export declare const gameLogCodes: {
    readonly echo: "0038";
    readonly dialog: "0044";
    readonly message: "0839";
};
export declare const actorControlType: {
    readonly setAnimState: "003E";
    readonly publicContentText: "0834";
    readonly logMsg: "020F";
    readonly logMsgParams: "0210";
};
type RepeatingFieldsMap<TBase extends LogDefinitionName, TKey extends RepeatingFieldsTypes = TBase extends RepeatingFieldsTypes ? TBase : never> = {
    [name in RepeatingFieldsDefinitions[TKey]['repeatingFields']['names'][number]]: string | string[];
}[];
type RepeatingFieldsMapTypeCheck<TBase extends LogDefinitionName, F extends keyof NetFields[TBase], TKey extends RepeatingFieldsTypes = TBase extends RepeatingFieldsTypes ? TBase : never> = F extends RepeatingFieldsDefinitions[TKey]['repeatingFields']['label'] ? RepeatingFieldsMap<TKey> : never;
type RepeatingFieldsMapType<T extends LogDefinitionName, F extends keyof NetFields[T]> = T extends RepeatingFieldsTypes ? RepeatingFieldsMapTypeCheck<T, F> : never;
type ParseHelperType<T extends LogDefinitionName> = {
    [field in keyof NetFields[T]]?: string | readonly string[] | RepeatingFieldsMapType<T, field>;
} & {
    capture?: boolean;
};
export declare const buildRegex: <T extends "None" | "ChangeZone" | "Debug" | "GameLog" | "ChangedPlayer" | "AddedCombatant" | "RemovedCombatant" | "PartyList" | "PlayerStats" | "StartsUsing" | "Ability" | "NetworkAOEAbility" | "NetworkCancelAbility" | "NetworkDoT" | "WasDefeated" | "GainsEffect" | "HeadMarker" | "NetworkRaidMarker" | "NetworkTargetMarker" | "LosesEffect" | "NetworkGauge" | "NetworkWorld" | "ActorControl" | "NameToggle" | "Tether" | "LimitBreak" | "NetworkEffectResult" | "StatusEffect" | "NetworkUpdateHP" | "Map" | "SystemLogMessage" | "StatusList3" | "ParserInfo" | "ProcessInfo" | "PacketDump" | "Version" | "Error" | "LineRegistration" | "MapEffect" | "FateDirector" | "CEDirector" | "InCombat" | "CombatantMemory" | "RSVData" | "StartsUsingExtra" | "AbilityExtra" | "ContentFinderSettings" | "NpcYell" | "BattleTalk2" | "Countdown" | "CountdownCancel" | "ActorMove" | "ActorSetPos" | "SpawnNpcExtra" | "ActorControlExtra" | "ActorControlSelfExtra">(type: T, params?: ParseHelperType<T> | undefined) => CactbotBaseRegExp<T>;
export default class NetRegexes {
    static logVersion: LogDefinitionVersions;
    static flagTranslationsNeeded: boolean;
    static setFlagTranslationsNeeded(value: boolean): void;
    static doesNetRegexNeedTranslation(regex: RegExp | string): boolean;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-20-0x14-networkstartscasting
     */
    static startsUsing(params?: NetParams['StartsUsing']): CactbotBaseRegExp<'StartsUsing'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-21-0x15-networkability
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-22-0x16-networkaoeability
     */
    static ability(params?: NetParams['Ability']): CactbotBaseRegExp<'Ability'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-21-0x15-networkability
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-22-0x16-networkaoeability
     *
     * @deprecated Use `ability` instead
     */
    static abilityFull(params?: NetParams['Ability']): CactbotBaseRegExp<'Ability'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-27-0x1b-networktargeticon-head-marker
     */
    static headMarker(params?: NetParams['HeadMarker']): CactbotBaseRegExp<'HeadMarker'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-03-0x03-addcombatant
     */
    static addedCombatant(params?: NetParams['AddedCombatant']): CactbotBaseRegExp<'AddedCombatant'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-03-0x03-addcombatant
     * @deprecated Use `addedCombatant` instead
     */
    static addedCombatantFull(params?: NetParams['AddedCombatant']): CactbotBaseRegExp<'AddedCombatant'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-04-0x04-removecombatant
     */
    static removingCombatant(params?: NetParams['RemovedCombatant']): CactbotBaseRegExp<'RemovedCombatant'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-26-0x1a-networkbuff
     */
    static gainsEffect(params?: NetParams['GainsEffect']): CactbotBaseRegExp<'GainsEffect'>;
    /**
     * Prefer gainsEffect over this function unless you really need extra data.
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-38-0x26-networkstatuseffects
     */
    static statusEffectExplicit(params?: NetParams['StatusEffect']): CactbotBaseRegExp<'StatusEffect'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-30-0x1e-networkbuffremove
     */
    static losesEffect(params?: NetParams['LosesEffect']): CactbotBaseRegExp<'LosesEffect'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-35-0x23-networktether
     */
    static tether(params?: NetParams['Tether']): CactbotBaseRegExp<'Tether'>;
    /**
     * 'target' was defeated by 'source'
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-25-0x19-networkdeath
     */
    static wasDefeated(params?: NetParams['WasDefeated']): CactbotBaseRegExp<'WasDefeated'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-24-0x18-networkdot
     */
    static networkDoT(params?: NetParams['NetworkDoT']): CactbotBaseRegExp<'NetworkDoT'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-00-0x00-logline
     */
    static echo(params?: Omit<NetParams['GameLog'], 'code'>): CactbotBaseRegExp<'GameLog'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-00-0x00-logline
     */
    static dialog(params?: Omit<NetParams['GameLog'], 'code'>): CactbotBaseRegExp<'GameLog'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-00-0x00-logline
     */
    static message(params?: Omit<NetParams['GameLog'], 'code'>): CactbotBaseRegExp<'GameLog'>;
    /**
     * fields: code, name, line, capture
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-00-0x00-logline
     */
    static gameLog(params?: NetParams['GameLog']): CactbotBaseRegExp<'GameLog'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-00-0x00-logline
     */
    static gameNameLog(params?: NetParams['GameLog']): CactbotBaseRegExp<'GameLog'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-12-0x0c-playerstats
     */
    static statChange(params?: NetParams['PlayerStats']): CactbotBaseRegExp<'PlayerStats'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-01-0x01-changezone
     */
    static changeZone(params?: NetParams['ChangeZone']): CactbotBaseRegExp<'ChangeZone'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-33-0x21-network6d-actor-control
     */
    static network6d(params?: NetParams['ActorControl']): CactbotBaseRegExp<'ActorControl'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-34-0x22-networknametoggle
     */
    static nameToggle(params?: NetParams['NameToggle']): CactbotBaseRegExp<'NameToggle'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-40-0x28-map
     */
    static map(params?: NetParams['Map']): CactbotBaseRegExp<'Map'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-41-0x29-systemlogmessage
     */
    static systemLogMessage(params?: NetParams['SystemLogMessage']): CactbotBaseRegExp<'SystemLogMessage'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-257-0x101-mapeffect
     */
    static mapEffect(params?: NetParams['MapEffect']): CactbotBaseRegExp<'MapEffect'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-258-0x102-fatedirector
     */
    static fateDirector(params?: NetParams['FateDirector']): CactbotBaseRegExp<'FateDirector'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-259-0x103-cedirector
     */
    static ceDirector(params?: NetParams['CEDirector']): CactbotBaseRegExp<'CEDirector'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-260-0x104-incombat
     */
    static inCombat(params?: NetParams['InCombat']): CactbotBaseRegExp<'InCombat'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-261-0x105-combatantmemory
     */
    static combatantMemory(params?: NetParams['CombatantMemory']): CactbotBaseRegExp<'CombatantMemory'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-262-0x106-rsvdata
     */
    static rsvData(params?: NetParams['RSVData']): CactbotBaseRegExp<'RSVData'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-263-0x107-startsusingextra
     */
    static startsUsingExtra(params?: NetParams['StartsUsingExtra']): CactbotBaseRegExp<'StartsUsingExtra'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-264-0x108-abilityextra
     */
    static abilityExtra(params?: NetParams['AbilityExtra']): CactbotBaseRegExp<'AbilityExtra'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-265-0x109-contentfindersettings
     */
    static contentFinderSettings(params?: NetParams['ContentFinderSettings']): CactbotBaseRegExp<'ContentFinderSettings'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-266-0x10a-npcyell
     */
    static npcYell(params?: NetParams['NpcYell']): CactbotBaseRegExp<'NpcYell'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-267-0x10b-battletalk2
     */
    static battleTalk2(params?: NetParams['BattleTalk2']): CactbotBaseRegExp<'BattleTalk2'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-268-0x10c-countdown
     */
    static countdown(params?: NetParams['Countdown']): CactbotBaseRegExp<'Countdown'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-269-0x10d-countdowncancel
     */
    static countdownCancel(params?: NetParams['CountdownCancel']): CactbotBaseRegExp<'CountdownCancel'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-270-0x10e-actormove
     */
    static actorMove(params?: NetParams['ActorMove']): CactbotBaseRegExp<'ActorMove'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-271-0x10f-actorsetpos
     */
    static actorSetPos(params?: NetParams['ActorSetPos']): CactbotBaseRegExp<'ActorSetPos'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-272-0x110-spawnnpcextra
     */
    static spawnNpcExtra(params?: NetParams['SpawnNpcExtra']): CactbotBaseRegExp<'SpawnNpcExtra'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-273-0x111-actorcontrolextra
     */
    static actorControlExtra(params?: NetParams['ActorControlExtra']): CactbotBaseRegExp<'ActorControlExtra'>;
    /**
     * matches: https://github.com/OverlayPlugin/cactbot/blob/main/docs/LogGuide.md#line-274-0x112-actorcontrolselfextra
     */
    static actorControlSelfExtra(params?: NetParams['ActorControlSelfExtra']): CactbotBaseRegExp<'ActorControlSelfExtra'>;
}
export declare const commonNetRegex: {
    readonly wipe: CactbotBaseRegExp<"ActorControl">;
    readonly cactbotWipeEcho: CactbotBaseRegExp<"GameLog">;
    readonly userWipeEcho: CactbotBaseRegExp<"GameLog">;
};
export declare const buildNetRegexForTrigger: <T extends "None" | "ChangeZone" | "Debug" | "GameLog" | "ChangedPlayer" | "AddedCombatant" | "RemovedCombatant" | "PartyList" | "PlayerStats" | "StartsUsing" | "Ability" | "NetworkAOEAbility" | "NetworkCancelAbility" | "NetworkDoT" | "WasDefeated" | "GainsEffect" | "HeadMarker" | "NetworkRaidMarker" | "NetworkTargetMarker" | "LosesEffect" | "NetworkGauge" | "NetworkWorld" | "ActorControl" | "NameToggle" | "Tether" | "LimitBreak" | "NetworkEffectResult" | "StatusEffect" | "NetworkUpdateHP" | "Map" | "SystemLogMessage" | "StatusList3" | "ParserInfo" | "ProcessInfo" | "PacketDump" | "Version" | "Error" | "LineRegistration" | "MapEffect" | "FateDirector" | "CEDirector" | "InCombat" | "CombatantMemory" | "RSVData" | "StartsUsingExtra" | "AbilityExtra" | "ContentFinderSettings" | "NpcYell" | "BattleTalk2" | "Countdown" | "CountdownCancel" | "ActorMove" | "ActorSetPos" | "SpawnNpcExtra" | "ActorControlExtra" | "ActorControlSelfExtra">(type: T, params?: NetParams[T] | undefined) => CactbotBaseRegExp<T>;
export {};
