import { RaidbossData as Data } from '../types/data';
import { Matches } from '../types/net_matches';
import { LooseTrigger, Output, ResponseFunc, ResponseOutput, TargetedMatches, TriggerFunc, TriggerOutput } from '../types/trigger';
type TargetedResponseOutput = ResponseOutput<Data, TargetedMatches>;
type StaticResponseFunc = ResponseFunc<Data, Matches>;
export declare const severityList: readonly ["info", "alert", "alarm"];
export type Severity = typeof severityList[number];
export type SevText = 'infoText' | 'alertText' | 'alarmText';
export declare const builtInResponseStr = "cactbot-builtin-response";
export declare const triggerFunctions: (keyof LooseTrigger)[];
export declare const triggerTextOutputFunctions: (keyof LooseTrigger)[];
export declare const triggerOutputFunctions: (keyof LooseTrigger)[];
export declare const severityMap: {
    [sev in Severity]: SevText;
};
export declare const Responses: {
    readonly tankBuster: (targetSev?: Severity, otherSev?: Severity) => (_data: unknown, _matches: unknown, output: Output) => TargetedResponseOutput;
    readonly tankBusterSwap: (busterSev?: Severity, swapSev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        infoText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        alertText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        alarmText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        tts?: import("../types/trigger").PartialTriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, import("../types/trigger").PartialTriggerOutput<Data, TargetedMatches>>;
    };
    readonly tankCleave: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly sharedTankBuster: (targetSev?: Severity, otherSev?: Severity) => (_data: unknown, _matches: unknown, output: Output) => TargetedResponseOutput;
    readonly miniBuster: (sev?: Severity) => StaticResponseFunc;
    readonly aoe: (sev?: Severity) => StaticResponseFunc;
    readonly bigAoe: (sev?: Severity) => StaticResponseFunc;
    readonly bleedAoe: (sev?: Severity) => StaticResponseFunc;
    readonly spread: (sev?: Severity) => StaticResponseFunc;
    readonly protean: (sev?: Severity) => StaticResponseFunc;
    readonly stackMarker: (sev?: Severity) => StaticResponseFunc;
    readonly getTogether: (sev?: Severity) => StaticResponseFunc;
    readonly stackMarkerOn: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly stackMiddle: (sev?: Severity) => StaticResponseFunc;
    readonly doritoStack: (sev?: Severity) => StaticResponseFunc;
    readonly spreadThenStack: (sev?: Severity) => StaticResponseFunc;
    readonly stackThenSpread: (sev?: Severity) => StaticResponseFunc;
    readonly knockback: (sev?: Severity) => StaticResponseFunc;
    readonly knockbackOn: (targetSev?: Severity, otherSev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        infoText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        alertText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        alarmText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        tts?: import("../types/trigger").PartialTriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, import("../types/trigger").PartialTriggerOutput<Data, TargetedMatches>>;
    };
    readonly drawIn: (sev?: Severity) => StaticResponseFunc;
    readonly lookTowards: (sev?: Severity) => StaticResponseFunc;
    readonly lookAway: (sev?: Severity) => StaticResponseFunc;
    readonly lookAwayFromTarget: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly lookAwayFromSource: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly getBehind: (sev?: Severity) => StaticResponseFunc;
    readonly goFrontOrSides: (sev?: Severity) => StaticResponseFunc;
    readonly getUnder: (sev?: Severity) => StaticResponseFunc;
    readonly getIn: (sev?: Severity) => StaticResponseFunc;
    readonly getOut: (sev?: Severity) => StaticResponseFunc;
    readonly outOfMelee: (sev?: Severity) => StaticResponseFunc;
    readonly getInThenOut: (sev?: Severity) => StaticResponseFunc;
    readonly getOutThenIn: (sev?: Severity) => StaticResponseFunc;
    readonly getBackThenFront: (sev?: Severity) => StaticResponseFunc;
    readonly getFrontThenBack: (sev?: Severity) => StaticResponseFunc;
    readonly goFront: (sev?: Severity) => StaticResponseFunc;
    readonly goMiddle: (sev?: Severity) => StaticResponseFunc;
    readonly goRight: (sev?: Severity) => StaticResponseFunc;
    readonly goLeft: (sev?: Severity) => StaticResponseFunc;
    readonly goWest: (sev?: Severity) => StaticResponseFunc;
    readonly goEast: (sev?: Severity) => StaticResponseFunc;
    readonly goLeftThenRight: (sev?: Severity) => StaticResponseFunc;
    readonly goRightThenLeft: (sev?: Severity) => StaticResponseFunc;
    readonly goFrontBack: (sev?: Severity) => StaticResponseFunc;
    readonly goSides: (sev?: Severity) => StaticResponseFunc;
    readonly killAdds: (sev?: Severity) => StaticResponseFunc;
    readonly killExtraAdd: (sev?: Severity) => StaticResponseFunc;
    readonly awayFromFront: (sev?: Severity) => StaticResponseFunc;
    readonly sleep: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (_data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly stunOrInterruptIfPossible: (sev?: Severity) => (_data: Data, _matches: TargetedMatches, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly stun: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (_data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly stunIfPossible: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly interrupt: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (_data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly interruptIfPossible: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly preyOn: (targetSev?: Severity, otherSev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        infoText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        alertText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        alarmText?: TriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, TriggerOutput<Data, TargetedMatches>>;
        tts?: import("../types/trigger").PartialTriggerOutput<Data, TargetedMatches> | TriggerFunc<Data, TargetedMatches, import("../types/trigger").PartialTriggerOutput<Data, TargetedMatches>>;
    };
    readonly awayFrom: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly meteorOnYou: (sev?: Severity) => StaticResponseFunc;
    readonly stopMoving: (sev?: Severity) => StaticResponseFunc;
    readonly stopEverything: (sev?: Severity) => StaticResponseFunc;
    readonly moveAway: (sev?: Severity) => StaticResponseFunc;
    readonly moveAround: (sev?: Severity) => StaticResponseFunc;
    readonly breakChains: (sev?: Severity) => StaticResponseFunc;
    readonly moveChainsTogether: (sev?: Severity) => StaticResponseFunc;
    readonly earthshaker: (sev?: Severity) => (_data: Data, _matches: unknown, output: Output) => {
        [x: string]: (data: Data, matches: TargetedMatches, output: Output) => string | undefined;
    };
    readonly wakeUp: (sev?: Severity) => StaticResponseFunc;
    readonly getTowers: (sev?: Severity) => StaticResponseFunc;
};
export {};
