import { NetParams } from '../types/net_props';
import { TimelineReplacement } from '../ui/raidboss/timeline_parser';
import { Lang } from './languages';
declare const localeLines: {
    readonly countdownStart: {
        readonly en: "Battle commencing in (?<time>\\y{Float}) seconds! \\((?<player>.*?)\\)";
        readonly de: "Noch (?<time>\\y{Float}) Sekunden bis Kampfbeginn! \\((?<player>.*?)\\)";
        readonly fr: "Début du combat dans (?<time>\\y{Float}) secondes[ ]?! \\((?<player>.*?)\\)";
        readonly ja: "戦闘開始まで(?<time>\\y{Float})秒！ （(?<player>.*?)）";
        readonly cn: "距离战斗开始还有(?<time>\\y{Float})秒！ （(?<player>.*?)）";
        readonly ko: "전투 시작 (?<time>\\y{Float})초 전! \\((?<player>.*?)\\)";
    };
    readonly countdownEngage: {
        readonly en: "Engage!";
        readonly de: "Start!";
        readonly fr: "À l'attaque[ ]?!";
        readonly ja: "戦闘開始！";
        readonly cn: "战斗开始！";
        readonly ko: "전투 시작!";
    };
    readonly countdownCancel: {
        readonly en: "Countdown canceled by (?<player>\\y{Name})";
        readonly de: "(?<player>\\y{Name}) hat den Countdown abgebrochen";
        readonly fr: "Le compte à rebours a été interrompu par (?<player>\\y{Name})[ ]?\\.";
        readonly ja: "(?<player>\\y{Name})により、戦闘開始カウントがキャンセルされました。";
        readonly cn: "(?<player>\\y{Name})取消了战斗开始倒计时。";
        readonly ko: "(?<player>\\y{Name}) 님이 초읽기를 취소했습니다\\.";
    };
    readonly areaSeal: {
        readonly en: "(?<area>.*?) will be sealed off in (?<time>\\y{Float}) seconds!";
        readonly de: "Noch (?<time>\\y{Float}) Sekunden, bis sich (?<area>.*?) schließt";
        readonly fr: "Fermeture (?<area>.*?) dans (?<time>\\y{Float}) secondes[ ]?\\.";
        readonly ja: "(?<area>.*?)の封鎖まであと(?<time>\\y{Float})秒";
        readonly cn: "距(?<area>.*?)被封锁还有(?<time>\\y{Float})秒";
        readonly ko: "(?<time>\\y{Float})초 후에 (?<area>.*?)(이|가) 봉쇄됩니다\\.";
    };
    readonly areaUnseal: {
        readonly en: "(?<area>.*?) is no longer sealed.";
        readonly de: "(?<area>.*?) öffnet sich erneut.";
        readonly fr: "Ouverture (?<area>.*?)[ ]?!";
        readonly ja: "(?<area>.*?)の封鎖が解かれた……";
        readonly cn: "(?<area>.*?)的封锁解除了";
        readonly ko: "(?<area>.*?)의 봉쇄가 해제되었습니다\\.";
    };
    readonly craftingStart: {
        readonly en: "You begin synthesizing (?<count>(an?|\\d+) )?(?<recipe>.*)\\.";
        readonly de: "Du hast begonnen, durch Synthese (?<count>(ein(e|es|em|er)?|\\d+) )?(?<recipe>.*) herzustellen\\.";
        readonly fr: "Vous commencez à fabriquer (?<count>(une?|\\d+) )?(?<recipe>.*)\\.";
        readonly ja: "(?<player>\\y{Name})は(?<recipe>.*)(×(?<count>\\d+))?の製作を開始した。";
        readonly cn: "(?<player>\\y{Name})开始制作“(?<recipe>.*)”(×(?<count>\\d+))?。";
        readonly ko: "(?<recipe>.*)(×(?<count>\\d+)개)? 제작을 시작합니다\\.";
    };
    readonly trialCraftingStart: {
        readonly en: "You begin trial synthesis of (?<recipe>.*)\\.";
        readonly de: "Du hast mit der Testsynthese von (?<recipe>.*) begonnen\\.";
        readonly fr: "Vous commencez une synthèse d'essai pour une? (?<recipe>.*)\\.";
        readonly ja: "(?<player>\\y{Name})は(?<recipe>.*)の製作練習を開始した。";
        readonly cn: "(?<player>\\y{Name})开始练习制作(?<recipe>.*)。";
        readonly ko: "(?<recipe>.*) 제작 연습을 시작합니다\\.";
    };
    readonly craftingFinish: {
        readonly en: "You synthesize (?<count>(an?|\\d+) )?(?<recipe>.*)()?\\.";
        readonly de: "Du hast erfolgreich (?<count>(ein(e|es|em|er)?|\\d+) )?(?<recipe>.*)()? hergestellt\\.";
        readonly fr: "Vous fabriquez (?<count>(une?|\\d+) )?(?<recipe>.*)()?\\.";
        readonly ja: "(?<player>\\y{Name})は(?<recipe>.*)()?(×(?<count>\\d+))?を完成させた！";
        readonly cn: "(?<player>\\y{Name})制作“(?<recipe>.*)()?”(×(?<count>\\d+))?成功！";
        readonly ko: "(?<player>\\y{Name}) 님이 (?<recipe>.*)()?(×(?<count>\\d+)개)?(을|를) 완성했습니다!";
    };
    readonly trialCraftingFinish: {
        readonly en: "Your trial synthesis of (?<recipe>.*) proved a success!";
        readonly de: "Die Testsynthese von (?<recipe>.*) war erfolgreich!";
        readonly fr: "Votre synthèse d'essai pour fabriquer (?<recipe>.*) a été couronnée de succès!";
        readonly ja: "(?<player>\\y{Name})は(?<recipe>.*)の製作練習に成功した！";
        readonly cn: "(?<player>\\y{Name})练习制作(?<recipe>.*)成功了！";
        readonly ko: "(?<recipe>.*) 제작 연습에 성공했습니다!";
    };
    readonly craftingFail: {
        readonly en: "Your synthesis fails!";
        readonly de: "Deine Synthese ist fehlgeschlagen!";
        readonly fr: "La synthèse échoue\\.{3}";
        readonly ja: "(?<player>\\y{Name})は製作に失敗した……";
        readonly cn: "(?<player>\\y{Name})制作失败了……";
        readonly ko: "제작에 실패했습니다……\\.";
    };
    readonly trialCraftingFail: {
        readonly en: "Your trial synthesis of (?<recipe>.*) failed\\.{3}";
        readonly de: "Die Testsynthese von (?<recipe>.*) ist fehlgeschlagen\\.{3}";
        readonly fr: "Votre synthèse d'essai pour fabriquer (?<recipe>.*) s'est soldée par un échec\\.{3}";
        readonly ja: "(?<player>\\y{Name})は(?<recipe>.*)の製作練習に失敗した……";
        readonly cn: "(?<player>\\y{Name})练习制作(?<recipe>.*)失败了……";
        readonly ko: "(?<recipe>.*) 제작 연습에 실패했습니다……\\.";
    };
    readonly craftingCancel: {
        readonly en: "You cancel the synthesis\\.";
        readonly de: "Du hast die Synthese abgebrochen\\.";
        readonly fr: "La synthèse est annulée\\.";
        readonly ja: "(?<player>\\y{Name})は製作を中止した。";
        readonly cn: "(?<player>\\y{Name})中止了制作作业。";
        readonly ko: "제작을 중지했습니다\\.";
    };
    readonly trialCraftingCancel: {
        readonly en: "You abandoned trial synthesis\\.";
        readonly de: "Testsynthese abgebrochen\\.";
        readonly fr: "Vous avez interrompu la synthèse d'essai\\.";
        readonly ja: "(?<player>\\y{Name})は製作練習を中止した。";
        readonly cn: "(?<player>\\y{Name})停止了练习。";
        readonly ko: "제작 연습을 중지했습니다\\.";
    };
};
type LocaleRegexesObj = Record<keyof typeof localeLines, Record<Lang, RegExp>>;
export type AnonNetRegexParams = {
    [name: string]: string | readonly string[] | boolean | undefined | unknown[];
};
export declare const LocaleRegex: LocaleRegexesObj;
export declare const LocaleNetRegex: LocaleRegexesObj;
export declare const translateWithReplacements: (text: string, replaceKey: 'replaceSync' | 'replaceText', replaceLang: Lang, replacements?: TimelineReplacement[]) => {
    text: string;
    wasTranslated: boolean;
};
export declare const translateRegex: (text: string | RegExp, replaceLang: Lang, replacements?: TimelineReplacement[]) => string;
export declare const translateText: (text: string, replaceLang: Lang, replacements?: TimelineReplacement[]) => string;
export declare const translateRegexBuildParam: <T extends "None" | "ChangeZone" | "Debug" | "GameLog" | "ChangedPlayer" | "AddedCombatant" | "RemovedCombatant" | "PartyList" | "PlayerStats" | "StartsUsing" | "Ability" | "NetworkAOEAbility" | "NetworkCancelAbility" | "NetworkDoT" | "WasDefeated" | "GainsEffect" | "HeadMarker" | "NetworkRaidMarker" | "NetworkTargetMarker" | "LosesEffect" | "NetworkGauge" | "NetworkWorld" | "ActorControl" | "NameToggle" | "Tether" | "LimitBreak" | "NetworkEffectResult" | "StatusEffect" | "NetworkUpdateHP" | "Map" | "SystemLogMessage" | "StatusList3" | "ParserInfo" | "ProcessInfo" | "PacketDump" | "Version" | "Error" | "LineRegistration" | "MapEffect" | "FateDirector" | "CEDirector" | "InCombat" | "CombatantMemory" | "RSVData" | "StartsUsingExtra" | "AbilityExtra" | "ContentFinderSettings" | "NpcYell" | "BattleTalk2" | "Countdown" | "CountdownCancel" | "ActorMove" | "ActorSetPos" | "SpawnNpcExtra" | "ActorControlExtra" | "ActorControlSelfExtra">(params: NetParams[T], replaceLang: Lang, replacements?: TimelineReplacement[]) => {
    params: NetParams[T];
    wasTranslated: boolean;
    missingFields?: string[] | undefined;
};
export declare const translateRegexBuildParamAnon: (anonParams: Readonly<AnonNetRegexParams>, replaceLang: Lang, replacements?: TimelineReplacement[]) => {
    params: AnonNetRegexParams;
    wasTranslated: boolean;
    missingFields?: string[] | undefined;
};
export {};
