import { OverlayHandlerResponseTypes, PluginCombatantState } from '../types/event';
import { Job, Role } from '../types/job';
import { NetMatches } from '../types/net_matches';
import { OutputStrings } from '../types/trigger';
export type WatchCombatantParams = {
    ids?: number[];
    names?: string[];
    props?: string[];
    delay?: number;
    maxDuration?: number;
};
export type WatchCombatantFunc = (params: WatchCombatantParams, func: (ret: OverlayHandlerResponseTypes['getCombatants']) => boolean) => Promise<void>;
export type DirectionOutput16 = 'dirN' | 'dirNNE' | 'dirNE' | 'dirENE' | 'dirE' | 'dirESE' | 'dirSE' | 'dirSSE' | 'dirS' | 'dirSSW' | 'dirSW' | 'dirWSW' | 'dirW' | 'dirWNW' | 'dirNW' | 'dirNNW' | 'unknown';
export type DirectionOutput8 = 'dirN' | 'dirNE' | 'dirE' | 'dirSE' | 'dirS' | 'dirSW' | 'dirW' | 'dirNW' | 'unknown';
export type DirectionOutputCardinal = 'dirN' | 'dirE' | 'dirS' | 'dirW' | 'unknown';
export type DirectionOutputIntercard = 'dirNE' | 'dirSE' | 'dirSW' | 'dirNW' | 'unknown';
export declare const Directions: {
    output8Dir: DirectionOutput8[];
    output16Dir: DirectionOutput16[];
    outputCardinalDir: DirectionOutputCardinal[];
    outputIntercardDir: DirectionOutputIntercard[];
    outputStrings16Dir: OutputStrings;
    outputStrings8Dir: OutputStrings;
    outputStringsCardinalDir: OutputStrings;
    outputStringsIntercardDir: OutputStrings;
    xyTo16DirNum: (x: number, y: number, centerX: number, centerY: number) => number;
    xyTo8DirNum: (x: number, y: number, centerX: number, centerY: number) => number;
    xyTo4DirNum: (x: number, y: number, centerX: number, centerY: number) => number;
    hdgTo16DirNum: (heading: number) => number;
    hdgTo8DirNum: (heading: number) => number;
    hdgTo4DirNum: (heading: number) => number;
    outputFrom8DirNum: (dirNum: number) => DirectionOutput8;
    outputFromCardinalNum: (dirNum: number) => DirectionOutputCardinal;
    combatantStatePosTo8Dir: (combatant: PluginCombatantState, centerX: number, centerY: number) => number;
    combatantStatePosTo8DirOutput: (combatant: PluginCombatantState, centerX: number, centerY: number) => DirectionOutput8;
    combatantStateHdgTo8Dir: (combatant: PluginCombatantState) => number;
    combatantStateHdgTo8DirOutput: (combatant: PluginCombatantState) => DirectionOutput8;
    addedCombatantPosTo8Dir: (combatant: NetMatches['AddedCombatant'], centerX: number, centerY: number) => number;
    addedCombatantPosTo8DirOutput: (combatant: NetMatches['AddedCombatant'], centerX: number, centerY: number) => DirectionOutput8;
    addedCombatantHdgTo8Dir: (combatant: NetMatches['AddedCombatant']) => number;
    addedCombatantHdgTo8DirOutput: (combatant: NetMatches['AddedCombatant']) => DirectionOutput8;
    xyTo8DirOutput: (x: number, y: number, centerX: number, centerY: number) => DirectionOutput8;
    xyToCardinalDirOutput: (x: number, y: number, centerX: number, centerY: number) => DirectionOutputCardinal;
    xyToIntercardDirOutput: (x: number, y: number, centerX: number, centerY: number) => DirectionOutputIntercard;
};
declare const Util: {
    readonly jobEnumToJob: (id: number) => Job;
    readonly jobToJobEnum: (job: Job) => number;
    readonly jobToRole: (job: Job) => Role;
    readonly getAllRoles: () => readonly Role[];
    readonly isTankJob: (job: Job) => boolean;
    readonly isHealerJob: (job: Job) => boolean;
    readonly isMeleeDpsJob: (job: Job) => boolean;
    readonly isRangedDpsJob: (job: Job) => boolean;
    readonly isCasterDpsJob: (job: Job) => boolean;
    readonly isDpsJob: (job: Job) => boolean;
    readonly isCraftingJob: (job: Job) => boolean;
    readonly isGatheringJob: (job: Job) => boolean;
    readonly isCombatJob: (job: Job) => boolean;
    readonly canStun: (job: Job) => boolean;
    readonly canSilence: (job: Job) => boolean;
    readonly canSleep: (job: Job) => boolean;
    readonly canCleanse: (job: Job) => boolean;
    readonly canFeint: (job: Job) => boolean;
    readonly canAddle: (job: Job) => boolean;
    readonly watchCombatant: WatchCombatantFunc;
    readonly clearWatchCombatants: () => void;
    readonly setWatchCombatantOverride: (watchFunc: WatchCombatantFunc, clearFunc: () => void) => void;
    readonly gameLogCodes: {
        readonly echo: "0038";
        readonly dialog: "0044";
        readonly message: "0839";
    };
    readonly actorControlType: {
        readonly setAnimState: "003E";
        readonly publicContentText: "0834";
        readonly logMsg: "020F";
        readonly logMsgParams: "0210";
    };
    readonly shortName: (name: string | undefined, playerNicks: {
        [name: string]: string;
    }) => string;
};
export default Util;
