import { actorControlType, gameLogCodes } from './netregexes';
import Outputs from './outputs';
import { callOverlayHandler } from './overlay_plugin_api';
// TODO: it'd be nice to not repeat job names, but at least Record enforces that all are set.
const nameToJobEnum = {
    NONE: 0,
    GLA: 1,
    PGL: 2,
    MRD: 3,
    LNC: 4,
    ARC: 5,
    CNJ: 6,
    THM: 7,
    CRP: 8,
    BSM: 9,
    ARM: 10,
    GSM: 11,
    LTW: 12,
    WVR: 13,
    ALC: 14,
    CUL: 15,
    MIN: 16,
    BTN: 17,
    FSH: 18,
    PLD: 19,
    MNK: 20,
    WAR: 21,
    DRG: 22,
    BRD: 23,
    WHM: 24,
    BLM: 25,
    ACN: 26,
    SMN: 27,
    SCH: 28,
    ROG: 29,
    NIN: 30,
    MCH: 31,
    DRK: 32,
    AST: 33,
    SAM: 34,
    RDM: 35,
    BLU: 36,
    GNB: 37,
    DNC: 38,
    RPR: 39,
    SGE: 40,
    VPR: 41,
    PCT: 42,
};
const allJobs = Object.keys(nameToJobEnum);
const allRoles = ['tank', 'healer', 'dps', 'crafter', 'gatherer', 'none'];
const tankJobs = ['GLA', 'PLD', 'MRD', 'WAR', 'DRK', 'GNB'];
const healerJobs = ['CNJ', 'WHM', 'SCH', 'AST', 'SGE'];
const meleeDpsJobs = ['PGL', 'MNK', 'LNC', 'DRG', 'ROG', 'NIN', 'SAM', 'RPR', 'VPR'];
const rangedDpsJobs = ['ARC', 'BRD', 'DNC', 'MCH'];
const casterDpsJobs = ['BLU', 'RDM', 'BLM', 'SMN', 'ACN', 'THM', 'PCT'];
const dpsJobs = [...meleeDpsJobs, ...rangedDpsJobs, ...casterDpsJobs];
const craftingJobs = ['CRP', 'BSM', 'ARM', 'GSM', 'LTW', 'WVR', 'ALC', 'CUL'];
const gatheringJobs = ['MIN', 'BTN', 'FSH'];
const stunJobs = ['BLU', ...tankJobs, ...meleeDpsJobs];
const silenceJobs = ['BLU', ...tankJobs, ...rangedDpsJobs];
const sleepJobs = [...casterDpsJobs, ...healerJobs];
const feintJobs = [...meleeDpsJobs];
const addleJobs = [...casterDpsJobs];
const cleanseJobs = ['BLU', 'BRD', ...healerJobs];
const jobToRoleMap = (() => {
    const addToMap = (map, jobs, role) => {
        jobs.forEach((job) => map.set(job, role));
    };
    const map = new Map([['NONE', 'none']]);
    addToMap(map, tankJobs, 'tank');
    addToMap(map, healerJobs, 'healer');
    addToMap(map, dpsJobs, 'dps');
    addToMap(map, craftingJobs, 'crafter');
    addToMap(map, gatheringJobs, 'gatherer');
    return map;
})();
const watchCombatantMap = [];
const shouldCancelWatch = (params, entry) => {
    if (entry.cancel)
        return true;
    if (params.maxDuration !== undefined && Date.now() - entry.start > params.maxDuration)
        return true;
    return false;
};
const defaultWatchCombatant = (params, func) => {
    return new Promise((res, rej) => {
        const delay = params.delay ?? 1000;
        const call = {
            call: 'getCombatants',
        };
        if (params.ids)
            call.ids = params.ids;
        if (params.names)
            call.names = params.names;
        if (params.props)
            call.props = params.props;
        const entry = {
            cancel: false,
            start: Date.now(),
        };
        watchCombatantMap.push(entry);
        const checkFunc = () => {
            if (shouldCancelWatch(params, entry)) {
                rej(new Error('cancelled'));
                return;
            }
            void callOverlayHandler(call).then((response) => {
                if (entry.cancel) {
                    rej(new Error('was cancelled'));
                    return;
                }
                if (func(response))
                    res();
                else
                    window.setTimeout(checkFunc, delay);
            });
        };
        window.setTimeout(checkFunc, delay);
    });
};
let watchCombatantOverride;
let clearCombatantsOverride;
const defaultClearCombatants = () => {
    while (watchCombatantMap.length > 0) {
        const watch = watchCombatantMap.pop();
        if (watch)
            watch.cancel = true;
    }
};
const watchCombatant = (params, func) => {
    if (watchCombatantOverride)
        return watchCombatantOverride(params, func);
    return defaultWatchCombatant(params, func);
};
const output8Dir = [
    'dirN',
    'dirNE',
    'dirE',
    'dirSE',
    'dirS',
    'dirSW',
    'dirW',
    'dirNW',
];
const output16Dir = [
    'dirN',
    'dirNNE',
    'dirNE',
    'dirENE',
    'dirE',
    'dirESE',
    'dirSE',
    'dirSSE',
    'dirS',
    'dirSSW',
    'dirSW',
    'dirWSW',
    'dirW',
    'dirWNW',
    'dirNW',
    'dirNNW',
];
const outputCardinalDir = ['dirN', 'dirE', 'dirS', 'dirW'];
const outputIntercardDir = ['dirNE', 'dirSE', 'dirSW', 'dirNW'];
const outputStrings16Dir = {
    dirN: Outputs.dirN,
    dirNNE: Outputs.dirNNE,
    dirNE: Outputs.dirNE,
    dirENE: Outputs.dirENE,
    dirE: Outputs.dirE,
    dirESE: Outputs.dirESE,
    dirSE: Outputs.dirSE,
    dirSSE: Outputs.dirSSE,
    dirS: Outputs.dirS,
    dirSSW: Outputs.dirSSW,
    dirSW: Outputs.dirSW,
    dirWSW: Outputs.dirWSW,
    dirW: Outputs.dirW,
    dirWNW: Outputs.dirWNW,
    dirNW: Outputs.dirNW,
    dirNNW: Outputs.dirNNW,
    unknown: Outputs.unknown,
};
const outputStrings8Dir = {
    dirN: Outputs.dirN,
    dirNE: Outputs.dirNE,
    dirE: Outputs.dirE,
    dirSE: Outputs.dirSE,
    dirS: Outputs.dirS,
    dirSW: Outputs.dirSW,
    dirW: Outputs.dirW,
    dirNW: Outputs.dirNW,
    unknown: Outputs.unknown,
};
const outputStringsCardinalDir = {
    dirN: Outputs.dirN,
    dirE: Outputs.dirE,
    dirS: Outputs.dirS,
    dirW: Outputs.dirW,
    unknown: Outputs.unknown,
};
const outputStringsIntercardDir = {
    dirNE: Outputs.dirNE,
    dirSE: Outputs.dirSE,
    dirSW: Outputs.dirSW,
    dirNW: Outputs.dirNW,
    unknown: Outputs.unknown,
};
// TODO: Accept 'north' as a function input and adjust output accordingly.
// E.g. Math.round((north + 4) - 4 * Math.atan2(x, y) / Math.PI) % 8;
// Will need to adjust the output arrays as well though.
const xyTo16DirNum = (x, y, centerX, centerY) => {
    // N = 0, NNE = 1, ..., NNW = 15
    x = x - centerX;
    y = y - centerY;
    return Math.round(8 - 8 * Math.atan2(x, y) / Math.PI) % 16;
};
const xyTo8DirNum = (x, y, centerX, centerY) => {
    // N = 0, NE = 1, ..., NW = 7
    x = x - centerX;
    y = y - centerY;
    return Math.round(4 - 4 * Math.atan2(x, y) / Math.PI) % 8;
};
const xyTo4DirNum = (x, y, centerX, centerY) => {
    // N = 0, E = 1, S = 2, W = 3
    x = x - centerX;
    y = y - centerY;
    return Math.round(2 - 2 * Math.atan2(x, y) / Math.PI) % 4;
};
const xyTo4DirIntercardNum = (x, y, centerX, centerY) => {
    // NE = 0, SE = 1, SW = 2, NW = 3
    x = x - centerX;
    y = y - centerY;
    return Math.round(2 - 2 * ((Math.PI / 4) + Math.atan2(x, y)) / Math.PI) % 4;
};
const hdgTo16DirNum = (heading) => {
    // N = 0, NNE = 1, ..., NNW = 15
    return (Math.round(8 - 8 * heading / Math.PI) % 16 + 16) % 16;
};
const hdgTo8DirNum = (heading) => {
    // N = 0, NE = 1, ..., NW = 7
    return (Math.round(4 - 4 * heading / Math.PI) % 8 + 8) % 8;
};
const hdgTo4DirNum = (heading) => {
    // N = 0, E = 1, S = 2, W = 3
    return (Math.round(2 - heading * 2 / Math.PI) % 4 + 4) % 4;
};
const outputFrom8DirNum = (dirNum) => {
    return output8Dir[dirNum] ?? 'unknown';
};
const outputFromCardinalNum = (dirNum) => {
    return outputCardinalDir[dirNum] ?? 'unknown';
};
const outputFromIntercardNum = (dirNum) => {
    return outputIntercardDir[dirNum] ?? 'unknown';
};
export const Directions = {
    output8Dir: output8Dir,
    output16Dir: output16Dir,
    outputCardinalDir: outputCardinalDir,
    outputIntercardDir: outputIntercardDir,
    outputStrings16Dir: outputStrings16Dir,
    outputStrings8Dir: outputStrings8Dir,
    outputStringsCardinalDir: outputStringsCardinalDir,
    outputStringsIntercardDir: outputStringsIntercardDir,
    xyTo16DirNum: xyTo16DirNum,
    xyTo8DirNum: xyTo8DirNum,
    xyTo4DirNum: xyTo4DirNum,
    hdgTo16DirNum: hdgTo16DirNum,
    hdgTo8DirNum: hdgTo8DirNum,
    hdgTo4DirNum: hdgTo4DirNum,
    outputFrom8DirNum: outputFrom8DirNum,
    outputFromCardinalNum: outputFromCardinalNum,
    combatantStatePosTo8Dir: (combatant, centerX, centerY) => {
        return xyTo8DirNum(combatant.PosX, combatant.PosY, centerX, centerY);
    },
    combatantStatePosTo8DirOutput: (combatant, centerX, centerY) => {
        const dirNum = xyTo8DirNum(combatant.PosX, combatant.PosY, centerX, centerY);
        return outputFrom8DirNum(dirNum);
    },
    combatantStateHdgTo8Dir: (combatant) => {
        return hdgTo8DirNum(combatant.Heading);
    },
    combatantStateHdgTo8DirOutput: (combatant) => {
        const dirNum = hdgTo8DirNum(combatant.Heading);
        return outputFrom8DirNum(dirNum);
    },
    addedCombatantPosTo8Dir: (combatant, centerX, centerY) => {
        const x = parseFloat(combatant.x);
        const y = parseFloat(combatant.y);
        return xyTo8DirNum(x, y, centerX, centerY);
    },
    addedCombatantPosTo8DirOutput: (combatant, centerX, centerY) => {
        const x = parseFloat(combatant.x);
        const y = parseFloat(combatant.y);
        const dirNum = xyTo8DirNum(x, y, centerX, centerY);
        return outputFrom8DirNum(dirNum);
    },
    addedCombatantHdgTo8Dir: (combatant) => {
        const heading = parseFloat(combatant.heading);
        return hdgTo8DirNum(heading);
    },
    addedCombatantHdgTo8DirOutput: (combatant) => {
        const heading = parseFloat(combatant.heading);
        const dirNum = hdgTo8DirNum(heading);
        return outputFrom8DirNum(dirNum);
    },
    xyTo8DirOutput: (x, y, centerX, centerY) => {
        const dirNum = xyTo8DirNum(x, y, centerX, centerY);
        return outputFrom8DirNum(dirNum);
    },
    xyToCardinalDirOutput: (x, y, centerX, centerY) => {
        const dirNum = xyTo4DirNum(x, y, centerX, centerY);
        return outputFromCardinalNum(dirNum);
    },
    xyToIntercardDirOutput: (x, y, centerX, centerY) => {
        const dirNum = xyTo4DirIntercardNum(x, y, centerX, centerY);
        return outputFromIntercardNum(dirNum);
    },
};
const Util = {
    jobEnumToJob: (id) => {
        const job = allJobs.find((job) => nameToJobEnum[job] === id);
        return job ?? 'NONE';
    },
    jobToJobEnum: (job) => nameToJobEnum[job],
    jobToRole: (job) => {
        const role = jobToRoleMap.get(job);
        return role ?? 'none';
    },
    getAllRoles: () => allRoles,
    isTankJob: (job) => tankJobs.includes(job),
    isHealerJob: (job) => healerJobs.includes(job),
    isMeleeDpsJob: (job) => meleeDpsJobs.includes(job),
    isRangedDpsJob: (job) => rangedDpsJobs.includes(job),
    isCasterDpsJob: (job) => casterDpsJobs.includes(job),
    isDpsJob: (job) => dpsJobs.includes(job),
    isCraftingJob: (job) => craftingJobs.includes(job),
    isGatheringJob: (job) => gatheringJobs.includes(job),
    isCombatJob: (job) => {
        return !craftingJobs.includes(job) && !gatheringJobs.includes(job);
    },
    canStun: (job) => stunJobs.includes(job),
    canSilence: (job) => silenceJobs.includes(job),
    canSleep: (job) => sleepJobs.includes(job),
    canCleanse: (job) => cleanseJobs.includes(job),
    canFeint: (job) => feintJobs.includes(job),
    canAddle: (job) => addleJobs.includes(job),
    watchCombatant: watchCombatant,
    clearWatchCombatants: () => {
        if (clearCombatantsOverride !== undefined)
            clearCombatantsOverride();
        else
            defaultClearCombatants();
    },
    setWatchCombatantOverride: (watchFunc, clearFunc) => {
        watchCombatantOverride = watchFunc;
        clearCombatantsOverride = clearFunc;
    },
    gameLogCodes: gameLogCodes,
    actorControlType: actorControlType,
    shortName: (name, playerNicks) => {
        // TODO: make this unique among the party in case of first name collisions.
        if (typeof name !== 'string') {
            if (typeof name !== 'undefined')
                console.error('called ShortNamify with non-string');
            return '???';
        }
        const nick = playerNicks[name];
        if (nick !== undefined)
            return nick;
        const idx = name.indexOf(' ');
        return idx < 0 ? name : name.slice(0, idx);
    },
};
export default Util;
//# sourceMappingURL=util.js.map