import { Lang } from '../../resources/languages';
import { ConfigEntry, ConfigEntryToDivMap, ConfigIdToValueMap, ConfigValue, OptionsTemplate } from '../../resources/user_config';
import { BaseOptions } from '../../types/data';
import { SavedConfig, SavedConfigEntry } from '../../types/event';
import { LooseOopsyTrigger, LooseOopsyTriggerSet } from '../../types/oopsy';
import { LocaleObject, LooseTimelineTrigger, LooseTrigger, LooseTriggerSet } from '../../types/trigger';
import { ConfigOptions } from './config_options';
import './general_config';
import '../eureka/eureka_config';
import '../jobs/jobs_config';
import '../oopsyraidsy/oopsyraidsy_config';
import '../radar/radar_config';
import '../raidboss/raidboss_config';
import '../../resources/defaults.css';
import './config.css';
export declare const kPrefixToCategory: {
    '00-misc': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    '02-arr': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    '03-hw': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    '04-sb': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    '05-shb': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    '06-ew': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    '07-dt': {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    user: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
};
export declare const kDirectoryToCategory: {
    alliance: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    dungeon: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    eureka: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    raid: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    pvp: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    trial: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    ultimate: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    hunts: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    map: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
    deepdungeon: {
        en: string;
        de: string;
        fr: string;
        ja: string;
        cn: string;
        ko: string;
    };
};
type ConfigState = {
    elements: [HTMLElement, HTMLElement];
    value: ConfigValue;
};
export type ConfigLooseTrigger = LooseTrigger & LooseTimelineTrigger & {
    isMissingId?: boolean;
    overriddenByFile?: string;
    isTimelineTrigger?: boolean;
    timelineRegex?: RegExp;
    triggerRegex?: RegExp;
    triggerNetRegex?: RegExp;
    configOutput?: {
        [field: string]: string;
    };
};
export type ConfigLooseTriggerSet = LooseTriggerSet;
export type ConfigLooseOopsyTrigger = LooseOopsyTrigger;
export type ConfigLooseOopsyTriggerSet = LooseOopsyTriggerSet & {
    filename?: string;
    isUserTriggerSet?: boolean;
};
export type ConfigContents = {
    [group: string]: OptionsTemplate[];
};
export type ConfigProcessedFile<T extends ConfigLooseOopsyTriggerSet | ConfigLooseTriggerSet> = {
    filename: string;
    fileKey: string;
    prefixKey: string;
    prefix: string;
    section: string;
    type?: string;
    title: string;
    triggerSet: T;
    zoneId?: number;
    triggers?: {
        [id: string]: T extends ConfigLooseOopsyTriggerSet ? ConfigLooseOopsyTrigger : ConfigLooseTrigger;
    };
};
export type ConfigProcessedFileMap<T extends ConfigLooseOopsyTriggerSet | ConfigLooseTriggerSet> = {
    [filename: string]: ConfigProcessedFile<T>;
};
export declare class CactbotConfigurator {
    configOptions: ConfigOptions;
    lang: Lang;
    private savedConfig;
    private contents;
    developerOptions: boolean;
    constructor(configOptions: ConfigOptions, savedConfig: SavedConfig);
    saveConfigData(): Promise<void>;
    translate<T>(textObj: LocaleObject<T>): T;
    getBooleanOption(group: string, path: string | string[], defaultValue: boolean): boolean;
    getStringOption(group: string, path: string | string[], defaultValue: string): string;
    getNumberOption(group: string, path: string | string[], defaultValue: number): number;
    _getOptionLeafHelper(group: string, path: string | string[]): SavedConfigEntry | undefined;
    getOption(group: string, path: string | string[], defaultValue: ConfigValue): ConfigValue;
    getJsonOption(group: string, path: string | string[], defaultValue: SavedConfigEntry): SavedConfigEntry;
    setOption(group: string, path: string | string[], value: ConfigValue): void;
    setJsonOption(group: string, path: string | string[], value: SavedConfigEntry): void;
    buildButterBar(): void;
    buildConfigEntry(derivedOptions: BaseOptions, groupDiv: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState | null;
    buildUI(container: HTMLElement, contents: ConfigContents): void;
    buildOverlayGroup(container: HTMLElement, group: string): HTMLElement;
    buildLeftDiv(opt: ConfigEntry): HTMLElement;
    buildCheckbox(options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState;
    buildHtml(_options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, _group: string, _path?: string[], _elements?: ConfigEntryToDivMap, _values?: ConfigIdToValueMap): ConfigState;
    buildDirectory(options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState;
    buildSelect(options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState;
    buildFloat(options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState;
    buildInteger(options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState;
    buildString(options: BaseOptions, parent: HTMLElement, opt: ConfigEntry, group: string, path?: string[], elements?: ConfigEntryToDivMap, values?: ConfigIdToValueMap): ConfigState;
    updateVisibility(elements: ConfigEntryToDivMap, values: ConfigIdToValueMap): void;
    processFiles<T extends ConfigLooseTriggerSet | ConfigLooseOopsyTriggerSet>(files: {
        [filename: string]: T;
    }, userTriggerSets?: T[]): ConfigProcessedFileMap<T>;
}
export {};
