import ResourceBar from '../../resources/resourcebar';
import TimerBar from '../../resources/timerbar';
import TimerBox from '../../resources/timerbox';
import WidgetList, { Toward } from '../../resources/widget_list';
import { Job } from '../../types/job';
import { ShouldShow } from './components/base';
import { JobsEventEmitter } from './event_emitter';
import { FfxivVersion } from './jobs';
import './jobs_config';
import { JobsOptions } from './jobs_options';
import { Player } from './player';
type JobDomObjects = {
    pullCountdown?: TimerBar;
    leftBuffsList?: WidgetList;
    rightBuffsList?: WidgetList;
    cpBar?: ResourceBar;
    gpBar?: ResourceBar;
    healthBar?: ResourceBar;
    manaBar?: ResourceBar;
    mpTicker?: TimerBar;
    foodBuff?: HTMLElement;
};
export interface ResourceBox extends HTMLDivElement {
    parentNode: HTMLElement;
}
export declare class Bars {
    private options;
    private jobsContainer;
    o: JobDomObjects;
    ee: JobsEventEmitter;
    readonly player: Player;
    constructor(options: JobsOptions, o: {
        emitter: JobsEventEmitter;
        player: Player;
    });
    updateProcBoxNotifyRepeat(): void;
    _updateUIVisibility(inPvP?: boolean): void;
    _setupJobContainers(job: Job, show: ShouldShow): void;
    addJobBarContainer(): HTMLElement;
    addJobBoxContainer(): HTMLElement;
    addResourceBox({ classList }: {
        classList?: string[];
    }): ResourceBox;
    addProcBox({ id, fgColor, threshold, notifyWhenExpired }: {
        id?: string;
        fgColor?: string;
        threshold?: number;
        notifyWhenExpired?: boolean;
    }): TimerBox;
    addTimerBar({ id, fgColor }: {
        id: string;
        fgColor: string;
    }): TimerBar;
    addResourceBar({ id, fgColor, maxvalue }: {
        id: string;
        fgColor: string;
        maxvalue: number;
    }): ResourceBar;
    addPullCountdownBar(): TimerBar;
    addCPBar(): ResourceBar;
    addGPBar(): ResourceBar;
    addHPBar(showHPNumber?: boolean): ResourceBar;
    addMPBar(showMPNumber?: boolean): ResourceBar;
    addMPTicker(): TimerBar;
    addBuffsList(o: {
        id: string;
        rowcolsize: number;
        maxnumber: number;
        toward: Toward;
    }): WidgetList;
    playNotification(): void;
    _updateHealth(healthBar: ResourceBar | undefined, data: {
        hp: number;
        maxHp: number;
        shield: number;
    }): void;
    _updateProcBoxNotifyState(inCombat: boolean): void;
    _updateMPTicker(data: {
        mp: number;
        maxMp: number;
        prevMp?: number;
        umbralStacks?: number;
        inCombat: boolean;
        ffxivVersion: FfxivVersion;
    }): void;
    _updateMana(data: {
        mp: number;
        maxMp: number;
        prevMp: number;
    }): void;
    updateMpBarColor(data: {
        mp: number;
        far?: boolean;
    }): void;
    _updateCp(data: {
        cp: number;
        maxCp: number;
    }): void;
    _updateGp(data: {
        gp: number;
        maxGp: number;
    }): void;
    _playGpAlarm(): void;
    _updateOpacity(transparent: boolean): void;
    _showFoodBuff(show: boolean): void;
    _setPullCountdown(seconds: number): void;
    setJobsContainerVisibility(show?: boolean): void;
}
export {};
