import EffectId from '../../../resources/effect_id';
import { kAbility } from '../constants';
import { computeBackgroundColorFrom } from '../utils';
import { BaseComponent } from './base';
export class MCHComponent extends BaseComponent {
    comboTimer;
    heatGauge;
    batteryGauge;
    drillBox;
    airAnchorBox;
    chainSawBox;
    wildFireBox;
    stacksContainer;
    tid1 = 0;
    tid2 = 0;
    wildFireStacks = [];
    wildFireCounts = 0;
    wildFireActive = false;
    overheatstack = 0;
    constructor(o) {
        super(o);
        this.comboTimer = this.bars.addTimerBar({
            id: 'mch-timers-combo',
            fgColor: 'combo-color',
        });
        this.heatGauge = this.bars.addResourceBox({
            classList: ['mch-color-heat'],
        });
        this.batteryGauge = this.bars.addResourceBox({
            classList: ['mch-color-battery'],
        });
        this.drillBox = this.bars.addProcBox({
            id: 'mch-procs-drill',
            fgColor: 'mch-color-drill',
        });
        this.airAnchorBox = this.bars.addProcBox({
            id: 'mch-procs-airanchor',
            fgColor: 'mch-color-airanchor',
        });
        this.chainSawBox = this.bars.addProcBox({
            id: 'mch-procs-chainsaw',
            fgColor: 'mch-color-chainsaw',
        });
        this.wildFireBox = this.bars.addProcBox({
            id: 'mch-procs-wildfire',
            fgColor: 'mch-color-wildfire',
        });
        // Wild Fire Gauge
        this.stacksContainer = document.createElement('div');
        this.stacksContainer.id = 'mch-stacks';
        this.stacksContainer.classList.add('stacks', 'hide');
        this.bars.addJobBarContainer().appendChild(this.stacksContainer);
        const wildFireContainer = document.createElement('div');
        wildFireContainer.id = 'mch-stacks-wildfire';
        this.stacksContainer.appendChild(wildFireContainer);
        for (let i = 0; i < 6; ++i) {
            const d = document.createElement('div');
            wildFireContainer.appendChild(d);
            this.wildFireStacks.push(d);
        }
        this.reset();
    }
    onCombo(skill, combo) {
        this.comboTimer.duration = 0;
        if (combo.isFinalSkill)
            return;
        if (skill)
            this.comboTimer.duration = this.comboDuration;
    }
    onJobDetailUpdate(jobDetail) {
        this.heatGauge.innerText = jobDetail.heat.toString();
        this.batteryGauge.innerText = jobDetail.battery.toString();
        // These two seconds are shown by half adjust, not like others' ceil.
        if (jobDetail.overheatActive === true) {
            this.heatGauge.parentNode.classList.add('overheat');
            this.heatGauge.innerText = this.overheatstack.toString();
        }
        else {
            this.heatGauge.parentNode.classList.remove('overheat');
            this.heatGauge.innerText = jobDetail.heat.toString();
        }
        if (jobDetail.batteryMilliseconds > 0) {
            this.batteryGauge.parentNode.classList.add('robot-active');
            this.batteryGauge.innerText = Math.round(jobDetail.batteryMilliseconds / 1000).toString();
        }
        else {
            this.batteryGauge.parentNode.classList.remove('robot-active');
            this.batteryGauge.innerText = jobDetail.battery.toString();
        }
    }
    refreshWildFireGauge() {
        for (let i = 0; i < 6; ++i) {
            const stack = this.wildFireStacks[i];
            if (!stack)
                continue;
            stack.classList.remove('fix', 'active');
            if (this.wildFireCounts > i) {
                if (this.wildFireActive)
                    stack.classList.add('active');
                else
                    stack.classList.add('fix');
            }
        }
    }
    onYouGainEffect(id, matches) {
        if (id === EffectId.Overheated_A80)
            this.overheatstack = parseInt(matches.count ?? '0');
    }
    onMobGainsEffectFromYou(id, matches) {
        if (id === EffectId.Wildfire_35D) {
            this.wildFireActive = true;
            this.wildFireCounts = parseInt(matches.count ?? '0');
            this.refreshWildFireGauge();
            this.stacksContainer.classList.remove('hide');
        }
    }
    onMobLosesEffectFromYou(id) {
        if (id === EffectId.Wildfire_35D) {
            this.wildFireActive = false;
            this.refreshWildFireGauge();
        }
    }
    onUseAbility(id, matches) {
        switch (id) {
            case kAbility.Drill:
            case kAbility.Bioblaster:
                if (matches.targetIndex === '0') {
                    this.drillBox.duration = this.player.getActionCooldown(20000, 'skill') +
                        this.drillBox.value;
                }
                break;
            case kAbility.AirAnchor:
            case kAbility.HotShot:
                this.airAnchorBox.duration = this.player.getActionCooldown(40000, 'skill');
                break;
            case kAbility.ChainSaw:
                this.chainSawBox.duration = this.player.getActionCooldown(60000, 'skill');
                break;
            case kAbility.WildFire: {
                this.wildFireBox.duration = 10 + 0.9; // animation delay
                this.wildFireBox.threshold = 1000;
                this.wildFireBox.fg = computeBackgroundColorFrom(this.wildFireBox, 'mch-color-wildfire.active');
                this.tid1 = window.setTimeout(() => {
                    this.wildFireBox.duration = 110 - 0.9;
                    this.wildFireBox.threshold = this.player.gcdSkill + 1;
                    this.wildFireBox.fg = computeBackgroundColorFrom(this.wildFireBox, 'mch-color-wildfire');
                }, 10000);
                this.tid2 = window.setTimeout(() => {
                    this.stacksContainer.classList.add('hide');
                    this.wildFireCounts = 0;
                }, 15000);
                break;
            }
        }
    }
    onStatChange({ gcdSkill }) {
        this.drillBox.threshold = gcdSkill * 3 + 1;
        this.airAnchorBox.threshold = gcdSkill * 3 + 1;
        this.chainSawBox.threshold = gcdSkill * 3 + 1;
        this.wildFireBox.threshold = gcdSkill + 1;
    }
    reset() {
        this.comboTimer.duration = 0;
        this.drillBox.duration = 0;
        this.airAnchorBox.duration = 0;
        this.chainSawBox.duration = 0;
        this.wildFireCounts = 0;
        this.wildFireActive = false;
        this.refreshWildFireGauge();
        this.wildFireBox.duration = 0;
        this.wildFireBox.threshold = this.player.gcdSkill + 1;
        this.wildFireBox.fg = computeBackgroundColorFrom(this.wildFireBox, 'mch-color-wildfire');
        this.stacksContainer.classList.add('hide');
        window.clearTimeout(this.tid1);
        window.clearTimeout(this.tid2);
    }
}
//# sourceMappingURL=mch.js.map