import EffectId from '../../../resources/effect_id';
import { kAbility } from '../constants';
import { BaseComponent } from './base';
export class SAMComponent extends BaseComponent {
    comboTimer;
    setsu;
    getsu;
    ka;
    kenkiGauge;
    meditationGauge;
    fuka;
    fugetsu;
    ikishoten;
    higanbana;
    constructor(o) {
        super(o);
        this.comboTimer = this.bars.addTimerBar({
            id: 'sam-timers-combo',
            fgColor: 'combo-color',
        });
        const stacksContainer = document.createElement('div');
        stacksContainer.id = 'sam-stacks';
        stacksContainer.classList.add('stacks');
        const senContainer = document.createElement('div');
        senContainer.id = 'sam-stacks-sen';
        stacksContainer.appendChild(senContainer);
        this.bars.addJobBarContainer().appendChild(stacksContainer);
        this.setsu = document.createElement('div');
        this.getsu = document.createElement('div');
        this.ka = document.createElement('div');
        this.setsu.id = 'sam-stacks-setsu';
        this.getsu.id = 'sam-stacks-getsu';
        this.ka.id = 'sam-stacks-ka';
        [this.setsu, this.getsu, this.ka].forEach((e) => senContainer.appendChild(e));
        this.kenkiGauge = this.bars.addResourceBox({
            classList: ['sam-color-kenki'],
        });
        this.meditationGauge = this.bars.addResourceBox({
            classList: ['sam-color-meditation'],
        });
        this.fugetsu = this.bars.addProcBox({
            id: 'sam-procs-fugetsu',
            fgColor: 'sam-color-fugetsu',
            notifyWhenExpired: true,
        });
        this.fuka = this.bars.addProcBox({
            id: 'sam-procs-fuka',
            fgColor: 'sam-color-fuka',
            notifyWhenExpired: true,
        });
        this.higanbana = this.bars.addProcBox({
            id: 'sam-procs-higanbana',
            fgColor: 'sam-color-higanbana',
            notifyWhenExpired: true,
        });
        this.ikishoten = this.bars.addProcBox({
            id: 'sam-procs-ikishoten',
            fgColor: 'sam-color-ikishoten',
        });
        this.reset();
    }
    onCombo(skill, combo) {
        this.comboTimer.duration = 0;
        if (combo.isFinalSkill)
            return;
        if (skill)
            this.comboTimer.duration = this.comboDuration;
    }
    onJobDetailUpdate(jobDetail) {
        this.kenkiGauge.innerText = jobDetail.kenki.toString();
        this.meditationGauge.innerText = jobDetail.meditationStacks.toString();
        this.kenkiGauge.parentNode.classList.toggle('high', jobDetail.kenki >= 70);
        this.meditationGauge.parentNode.classList.toggle('high', jobDetail.meditationStacks >= 2);
        this.setsu.classList.toggle('active', jobDetail.setsu);
        this.getsu.classList.toggle('active', jobDetail.getsu);
        this.ka.classList.toggle('active', jobDetail.ka);
    }
    onYouGainEffect(id, matches) {
        if (id === EffectId.Fuka) {
            this.fuka.duration = parseFloat(matches.duration ?? '0') - 0.5; // -0.5s for log line delay
            this.player.speedBuffs.fuka = true;
        }
        if (id === EffectId.Fugetsu)
            this.fugetsu.duration = parseFloat(matches.duration ?? '0') - 0.5; // -0.5s for log line delay
    }
    onYouLoseEffect(id) {
        if (id === EffectId.Fuka) {
            this.fuka.duration = 0;
            this.player.speedBuffs.fuka = false;
        }
        if (id === EffectId.Fugetsu)
            this.fugetsu.duration = 0;
    }
    onUseAbility(id) {
        switch (id) {
            case kAbility.Ikishoten:
                this.ikishoten.duration = 120;
                break;
        }
    }
    onMobGainsEffectFromYou(id) {
        if (id === EffectId.Higanbana_4CC)
            this.higanbana.duration = 60 - 0.5; // -0.5s for log line delay
    }
    onStatChange({ gcdSkill }) {
        this.fuka.threshold = gcdSkill * 6;
        this.fugetsu.threshold = gcdSkill * 6;
        this.ikishoten.threshold = gcdSkill + 1;
        this.higanbana.threshold = gcdSkill * 4;
    }
    reset() {
        this.comboTimer.duration = 0;
        this.fuka.duration = 0;
        this.fugetsu.duration = 0;
        this.ikishoten.duration = 0;
        this.higanbana.duration = 0;
    }
}
//# sourceMappingURL=sam.js.map