import EffectId from '../../../resources/effect_id';
import { kAbility } from '../constants';
import { BaseComponent } from './base';
export class WARComponent extends BaseComponent {
    BeastBox;
    tempestBox;
    upheavalBox;
    innerReleaseBox;
    comboTimer;
    bonus;
    constructor(o) {
        super(o);
        this.BeastBox = this.bars.addResourceBox({
            classList: ['war-color-beast'],
        });
        this.tempestBox = this.bars.addProcBox({
            fgColor: 'war-color-tempest',
            notifyWhenExpired: true,
        });
        this.upheavalBox = this.bars.addProcBox({
            fgColor: 'war-color-upheaval',
        });
        this.innerReleaseBox = this.bars.addProcBox({
            fgColor: 'war-color-innerrelease',
        });
        this.comboTimer = this.bars.addTimerBar({
            id: 'war-timers-combo',
            fgColor: 'combo-color',
        });
        this.bonus = 0;
        this.reset();
    }
    onJobDetailUpdate(jobDetail) {
        const beast = jobDetail.beast.toString();
        if (this.BeastBox.innerText === beast)
            return;
        this.BeastBox.innerText = beast;
        const p = this.BeastBox.parentNode;
        if (jobDetail.beast < 50) {
            p.classList.add('low');
            p.classList.remove('mid');
        }
        else if (jobDetail.beast < 90) {
            p.classList.remove('low');
            p.classList.add('mid');
        }
        else {
            p.classList.remove('low');
            p.classList.remove('mid');
        }
    }
    onUseAbility(skill) {
        switch (skill) {
            case kAbility.Upheaval:
            case kAbility.Orogeny:
                this.upheavalBox.duration = 30;
                break;
            case kAbility.InnerRelease:
            case kAbility.Berserk:
                this.innerReleaseBox.duration = 60;
                break;
        }
    }
    onCombo(skill, combo) {
        this.comboTimer.duration = 0;
        // Storm's Eye initiation will freeze Surging Tempest buff for about 1.6s before countdown start
        if (skill === kAbility.StormsEye && !this.tempestBox.duration)
            this.bonus = 1.6;
        if (combo.isFinalSkill)
            return;
        if (skill)
            this.comboTimer.duration = this.comboDuration;
    }
    onYouGainEffect(id, matches) {
        if (id !== EffectId.SurgingTempest)
            return;
        const duration = parseFloat(matches.duration ?? '0');
        this.tempestBox.duration = duration + this.bonus - 0.5; // buff logline delay
        this.bonus = 0;
    }
    onYouLoseEffect(id) {
        if (id === EffectId.SurgingTempest)
            this.tempestBox.duration = 0;
    }
    onStatChange({ gcdSkill }) {
        this.tempestBox.threshold = gcdSkill * 3 + 1;
        this.upheavalBox.threshold = gcdSkill;
        this.innerReleaseBox.threshold = gcdSkill * 3;
    }
    reset() {
        this.tempestBox.duration = 0;
        this.upheavalBox.duration = 0;
        this.innerReleaseBox.duration = 0;
        this.comboTimer.duration = 0;
    }
}
//# sourceMappingURL=war.js.map