import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
const triggerSet = {
    zoneId: ZoneId.TheWeepingCityOfMhach,
    damageWarn: {
        'Weeping Critical Bite': '1848',
        'Weeping Realm Shaker': '183E',
        'Weeping Silkscreen': '183C',
        'Weeping Silken Spray': '1824',
        'Weeping Tremblor 1': '1837',
        'Weeping Tremblor 2': '1836',
        'Weeping Tremblor 3': '1835',
        'Weeping Spider Thread': '1839',
        'Weeping Fire II': '184E',
        'Weeping Necropurge': '17D7',
        'Weeping Rotten Breath': '17D0',
        'Weeping Mow': '17D2',
        'Weeping Dark Eruption': '17C3',
        // 1806 is also Flare Star, but if you get by 1805 you also get hit by 1806?
        'Weeping Flare Star': '1805',
        'Weeping Execration': '1829',
        'Weeping Haircut 1': '180B',
        'Weeping Haircut 2': '180F',
        'Weeping Entanglement': '181D',
        'Weeping Evil Curl': '1816',
        'Weeping Evil Tress': '1817',
        'Weeping Depth Charge': '1820',
        'Weeping Feint Particle Beam': '1928',
        'Weeping Evil Switch': '1815', // Calofisteri lasers
    },
    gainsEffectWarn: {
        'Weeping Hysteria': '128',
        'Weeping Zombification': '173',
        'Weeping Toad': '1B7',
        'Weeping Doom': '38E',
        'Weeping Assimilation': '42C',
        'Weeping Stun': '95', // Calofisteri Penetration look-away
    },
    shareWarn: {
        'Weeping Arachne Web': '185E',
        'Weeping Earth Aether': '1841',
        'Weeping Epigraph': '1852',
        // This is too noisy.  Better to pop the balloons than worry about friends.
        // 'Weeping Explosion': '1807', // Ozmasphere Cube orb explosion
        'Weeping Split End 1': '180C',
        'Weeping Split End 2': '1810',
        'Weeping Bloodied Nail': '181F', // Calofisteri axe/bulb appearing
    },
    triggers: [
        {
            id: 'Weeping Forgall Gradual Zombification Gain',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: '415' }),
            run: (data, matches) => {
                data.zombie ??= {};
                data.zombie[matches.target] = true;
            },
        },
        {
            id: 'Weeping Forgall Gradual Zombification Lose',
            type: 'LosesEffect',
            netRegex: NetRegexes.losesEffect({ effectId: '415' }),
            run: (data, matches) => {
                data.zombie = data.zombie || {};
                data.zombie[matches.target] = false;
            },
        },
        {
            id: 'Weeping Forgall Mega Death',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '17CA' }),
            condition: (data, matches) => data.zombie && !data.zombie[matches.target],
            mistake: (_data, matches) => {
                return { type: 'fail', blame: matches.target, text: matches.ability };
            },
        },
        {
            id: 'Weeping Headstone Shield Gain',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: '15E' }),
            run: (data, matches) => {
                data.shield ??= {};
                data.shield[matches.target] = true;
            },
        },
        {
            id: 'Weeping Headstone Shield Lose',
            type: 'LosesEffect',
            netRegex: NetRegexes.losesEffect({ effectId: '15E' }),
            run: (data, matches) => {
                data.shield = data.shield || {};
                data.shield[matches.target] = false;
            },
        },
        {
            id: 'Weeping Flaring Epigraph',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '1856' }),
            condition: (data, matches) => data.shield && !data.shield[matches.target],
            mistake: (_data, matches) => {
                return { type: 'fail', blame: matches.target, text: matches.ability };
            },
        },
        {
            // This ability name is helpfully called "Attack" so name it something else.
            id: 'Weeping Ozma Tank Laser',
            type: 'Ability',
            netRegex: NetRegexes.ability({ type: '22', id: '1831' }),
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    text: {
                        en: 'Tank Laser',
                        de: 'Tank Laser',
                        fr: 'Tank Laser',
                        ja: 'タンクレザー',
                        cn: '坦克激光',
                        ko: '탱커 레이저',
                    },
                };
            },
        },
        {
            id: 'Weeping Ozma Holy',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '182E' }),
            deathReason: (_data, matches) => {
                return {
                    id: matches.targetId,
                    name: matches.target,
                    text: {
                        en: 'Slid off!',
                        de: 'ist runtergerutscht!',
                        fr: 'A glissé(e) !',
                        ja: 'ノックバック',
                        cn: '击退！',
                        ko: '넉백됨!',
                    },
                };
            },
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=weeping_city.js.map