import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { playerDamageFields } from '../../../oopsy_common';
const triggerSet = {
    zoneId: ZoneId.TheGreatGubalLibraryHard,
    damageWarn: {
        'GubalHm Terror Eye': '930',
        'GubalHm Batter': '198A',
        'GubalHm Condemnation': '390',
        'GubalHm Discontinue 1': '1943',
        'GubalHm Discontinue 2': '1940',
        'GubalHm Discontinue 3': '1942',
        'GubalHm Frightful Roar': '193B',
        'GubalHm Issue 1': '193D',
        'GubalHm Issue 2': '193F',
        'GubalHm Issue 3': '1941',
        'GubalHm Desolation': '198C',
        'GubalHm Double Smash': '26A',
        'GubalHm Darkness': '3A0',
        'GubalHm Firewater': '3BA',
        'GubalHm Elbow Drop': 'CBA',
        'GubalHm Dark': '19DF',
        'GubalHm Seals': '194A',
        'GubalHm Water III': '1C67',
        'GubalHm Raging Axe': '1703',
        'GubalHm Magic Hammer': '1990',
        'GubalHm Properties Of Gravity': '1950',
        'GubalHm Properties Of Levitation': '194F',
        'GubalHm Comet': '1969', // Small circle AoE, intermission, boss 3
    },
    damageFail: {
        'GubalHm Ecliptic Meteor': '195C', // LoS mechanic, boss 3
    },
    shareWarn: {
        'GubalHm Searing Wind': '1944',
        'GubalHm Thunder': '19[AB]', // Spread marker, boss 3
    },
    triggers: [
        {
            // Fire gate in hallway to boss 2, magnet failure on boss 2
            id: 'GubalHm Burns',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: '10B' }),
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.effect,
                };
            },
        },
        {
            // Helper for Thunder 3 failures
            id: 'GubalHm Imp Gain',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: '46E' }),
            run: (data, matches) => {
                data.hasImp ??= {};
                data.hasImp[matches.target] = true;
            },
        },
        {
            id: 'GubalHm Imp Lose',
            type: 'LosesEffect',
            netRegex: NetRegexes.losesEffect({ effectId: '46E' }),
            run: (data, matches) => {
                data.hasImp = data.hasImp || {};
                data.hasImp[matches.target] = false;
            },
        },
        {
            // Targets with Imp when Thunder III resolves receive a vulnerability stack and brief stun
            id: 'GubalHm Imp Thunder',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '195[AB]', ...playerDamageFields }),
            condition: (data, matches) => data.hasImp?.[matches.target],
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: {
                        en: 'Shocked Imp',
                        de: 'Schockierter Imp',
                        fr: 'Kappa choqué(e)',
                        ja: 'カッパを解除しなかった',
                        cn: '河童状态吃了暴雷',
                        ko: '물요정 상태 해제하지 않음',
                    },
                };
            },
        },
        {
            id: 'GubalHm Quake',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '1956', ...playerDamageFields }),
            // Always hits target, but if correctly resolved will deal 0 damage
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
        {
            id: 'GubalHm Tornado',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '195[78]', ...playerDamageFields }),
            // Always hits target, but if correctly resolved will deal 0 damage
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=gubal_library_hard.js.map