import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { playerDamageFields } from '../../../oopsy_common';
// TODO: could add Patch warnings for double/unbroken tethers
// TODO: Hello World could have any warnings (sorry)
const triggerSet = {
    zoneId: ZoneId.AlphascapeV40Savage,
    damageWarn: {
        'O12S Superliminal Motion 1': '3334',
        'O12S Efficient Bladework 1': '3329',
        'O12S Efficient Bladework 2': '332A',
        'O12S Beyond Strength': '3328',
        'O12S Superliminal Steel 1': '3330',
        'O12S Superliminal Steel 2': '3331',
        'O12S Optimized Blizzard III': '3332',
        'O12S Diffuse Wave Cannon': '3369',
        'O12S Right Arm Unit Hyper Pulse 1': '335A',
        'O12S Right Arm Unit Hyper Pulse 2': '335B',
        'O12S Right Arm Unit Colossal Blow': '335F',
        'O12S Left Arm Unit Colossal Blow': '3360', // Exploding Archive All hands
    },
    damageFail: {
        'O12S Optical Laser': '3347',
        'O12S Advanced Optical Laser': '334A',
        'O12S Rear Power Unit Rear Lasers 1': '3361',
        'O12S Rear Power Unit Rear Lasers 2': '3362', // Archive All rotating laser
    },
    shareWarn: {
        'O12S Optimized Fire III P1': '3337',
        'O12S Hyper Pulse Tether': '335C',
        'O12S Wave Cannon': '336B',
        'O12S Optimized Fire III P2': '3379', // Archive All spread
    },
    shareFail: {
        'O12S Optimized Sagittarius Arrow': '334D',
        'O12S Oversampled Wave Cannon': '3366',
        'O12S Savage Wave Cannon': '336D', // Tank buster with the vuln first
    },
    triggers: [
        {
            id: 'O12S Discharger Knocked Off',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '3327' }),
            deathReason: (_data, matches) => {
                return {
                    id: matches.targetId,
                    name: matches.target,
                    text: {
                        en: 'Knocked off',
                        de: 'Runtergefallen',
                        fr: 'Renversé(e)',
                        ja: 'ノックバック',
                        cn: '击退坠落',
                        ko: '넉백',
                    },
                };
            },
        },
        {
            id: 'O12S Magic Vulnerability Up Gain',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: '472' }),
            run: (data, matches) => {
                data.vuln ??= {};
                data.vuln[matches.target] = true;
            },
        },
        {
            id: 'O12S Magic Vulnerability Up Lose',
            type: 'LosesEffect',
            netRegex: NetRegexes.losesEffect({ effectId: '472' }),
            run: (data, matches) => {
                data.vuln = data.vuln || {};
                data.vuln[matches.target] = false;
            },
        },
        {
            id: 'O12S Magic Vulnerability Damage',
            type: 'Ability',
            // 332E = Pile Pitch stack
            // 333E = Electric Slide (Omega-M square 1-4 dashes)
            // 333F = Electric Slide (Omega-F triangle 1-4 dashes)
            netRegex: NetRegexes.ability({ id: ['332E', '333E', '333F'], ...playerDamageFields }),
            condition: (data, matches) => data.vuln && data.vuln[matches.target],
            mistake: (_data, matches) => {
                return {
                    type: 'fail',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: {
                        en: `${matches.ability} (with vuln)`,
                        de: `${matches.ability} (mit Verwundbarkeit)`,
                        fr: `${matches.ability} (avec Vulnérabilité)`,
                        ja: `${matches.ability} (被ダメージ上昇)`,
                        cn: `${matches.ability} (带易伤)`,
                        ko: `${matches.ability} (받피증 상태에서 피격)`,
                    },
                };
            },
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=o12s.js.map