import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { playerDamageFields } from '../../../oopsy_common';
const triggerSet = {
    zoneId: ZoneId.Euphrosyne,
    damageWarn: {
        'Euphrosyne Nophica Spring Flowers': '7C10',
        'Euphrosyne Nophica Summer Shade': '7C0F',
        'Euphrosyne Nophica Reaper\'s Gale': '7C0E',
        'Euphrosyne Nophica Landwaker': '7C1C',
        'Euphrosyne Nophica Sowing Circle 1': '7C14',
        'Euphrosyne Nophica Sowing Circle 2': '7C15',
        'Euphrosyne Gigantoad Labored Leap': '7D31',
        'Euphrosyne Gigantoad Rush': '7D32',
        'Euphrosyne Werewood Ovation': '7D33',
        'Euphrosyne Ktenos Rock Throw': '7D3A',
        'Euphrosyne Behemoth Touchdown': '7D34',
        'Euphrosyne Behemoth Trounce': '7D36',
        'Euphrosyne Althyk Mythril Greataxe': '7A46',
        'Euphrosyne Nymeia Hydrorythmos 1': '7A40',
        'Euphrosyne Nymeia Hydrorythmos 2': '7A41',
        'Euphrosyne Dhruva Aetherial Blizzard': '7D3F',
        'Euphrosyne Colossus Frozen Perimeter': '7D3D',
        'Euphrosyne Colossus Inner Bladestorm': '7D3E',
        'Euphrosyne Halone Tetrapagos Hailstorm': '7D4E',
        'Euphrosyne Halone Tetrapagos Swirl': '7D4F',
        'Euphrosyne Halone Tetrapagos Rightrime': '7D50',
        'Euphrosyne Halone Tetrapagos Leftrime': '7D51',
        'Euphrosyne Halone Thousandfold Thrust 1': '7D57',
        'Euphrosyne Halone Thousandfold Thrust 2': '7D58',
        'Euphrosyne Halone Lochos 1': '7D5B',
        'Euphrosyne Halone Lochos 2': '7D5C',
        'Euphrosyne Halone Will of the Fury 1': '7D5E',
        'Euphrosyne Halone Will of the Fury 2': '7D5F',
        'Euphrosyne Halone Will of the Fury 3': '7D60',
        'Euphrosyne Halone Will of the Fury 4': '7D61',
        'Euphrosyne Halone Will of the Fury 5': '7D62',
        'Euphrosyne Halone Glacial Spear Niphas': '7D69',
        'Euphrosyne Halone Glacial Spear Cheimon 1': '7D6C',
        'Euphrosyne Halone Glacial Spear Cheimon 2': '7D6D',
        'Euphrosyne Menphina First Blush': '7BBC',
        'Euphrosyne Menphina Midnight Frost 1': '7BCD',
        'Euphrosyne Menphina Midnight Frost 2': '7BDD',
        'Euphrosyne Menphina Midnight Frost 3': '7BD1',
        'Euphrosyne Menphina Midnight Frost 4': '7BD2',
        // FIXME: this id is the same as Midnight Frost 2 above, is it correct or one of them incorrect?
        // 'Euphrosyne Menphina Midnight Frost 5': '7BDD', // 180 cleave
        'Euphrosyne Menphina Midnight Frost 6': '7BDE',
        'Euphrosyne Menphina Midnight Frost 7': '7BEA',
        'Euphrosyne Menphina Midnight Frost 8': '7BEB',
        'Euphrosyne Menphina Lover\'s Bridge': '7BBD',
        'Euphrosyne Menphina Silver Mirror': '7BF6',
        'Euphrosyne Menphina Moonset': '7BC9',
        'Euphrosyne Menphina Winter Halo 1': '7BC7',
        'Euphrosyne Menphina Winter Halo 2': '7BEC',
        'Euphrosyne Menphina Winter Halo 3': '7BDF',
        'Euphrosyne Menphina Ice Sprite Ancient Blizzard': '8066',
        'Euphrosyne Menphina Waxing Claw 1': '7BE0',
        'Euphrosyne Menphina Waxing Claw 2': '7BE1', // 180 cleave from dog
    },
    gainsEffectWarn: {
        'Euphrosyne Halone Deep Freeze': '4E6', // getting hit by Will of the Fury
    },
    shareWarn: {
        'Euphrosyne Nymeia Hydroptosis': '7A45',
        'Euphrosyne Halone Ice Dart': '7D66',
        'Euphrosyne Menphina Keen Boonbeam': '7BF4', // spread during add phase
    },
    shareFail: {
        'Euphrosyne Nophica Heavens\' Earth': '7C23',
        'Euphrosyne Ktenos Sweeping Gouge': '7D39',
        'Euphrosyne Colossuus Rapid Sever': '7D3C',
        'Euphrosyne Halone Spears Three': '7D78',
        'Euphrosyne Menphina Lunar Kiss': '7BF9', // laser tankbuster
    },
    triggers: [
        {
            // These do no damage if you are standing in the correct shield.
            id: 'Euphrosyne Nophica Blossoms',
            type: 'Ability',
            // 7C20 = Blueblossoms
            // 7C21 = Giltblossoms
            netRegex: NetRegexes.ability({ id: ['7C20', '7C21'], ...playerDamageFields }),
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
        {
            // No damage if on a purple fissure.
            id: 'Euphrosyne Althyk Inexorable Pull',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '7A43', ...playerDamageFields }),
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
        {
            // No damage if looking towards/away.
            id: 'Euphrosyne Althyk Spinner\'s Wheel Arcane Attraction',
            type: 'Ability',
            // 7A54 = Spinner's Wheel damage for Arcane Attraction
            // 7A55 = Spinner's Wheel damage for Attraction Reversed
            netRegex: NetRegexes.ability({ id: ['7A54', '7A55'], ...playerDamageFields }),
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
        {
            id: 'Euphrosyne Nymeia Hydrostasis',
            type: 'Ability',
            // 7A3B = 1, 7A3C = 2, 7A3D = 3, 7A3E = 3 renumbered to 1
            netRegex: NetRegexes.ability({ id: ['7A3B', '7A3C', '7A3D', '7A3E'] }),
            deathReason: (_data, matches) => {
                return {
                    id: matches.targetId,
                    name: matches.target,
                    text: {
                        en: 'Knocked off',
                        de: 'Runtergefallen',
                        fr: 'Renversé(e)',
                        ja: 'ノックバック',
                        cn: '击退坠落',
                        ko: '넉백',
                    },
                };
            },
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=euphrosyne.js.map