import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { playerDamageFields, playerTargetFields } from '../../../oopsy_common';
// TODO: people who missed their 8AC2 Burst tower
// TODO: failing 8894 Radiance orb damage during Analysis
// TODO: failing 8CDF Targeted Light during Analysis
// TODO: people who failed Subtractive Suppressor Alpha + Beta
// TODO: walking over 889B Arcane Combustion when you don't have Suppressor
// TODO: taking extra 8893 Inferno Divide squares during Spatial Tactics
// TODO: 01F7(success) and 01F8(fail) check and x markers?
// TODO: players not in Trapshooting stack 895A
// TODO: players not in Present Box / Pinwheeling Dartboard two person stack
const renameMistake = (triggerId, abilityId, type, text) => {
    return {
        id: triggerId,
        type: 'Ability',
        netRegex: NetRegexes.ability({ id: abilityId, ...playerTargetFields }),
        mistake: (_data, matches) => {
            return {
                type: type,
                blame: matches.target,
                reportId: matches.targetId,
                text: text,
            };
        },
    };
};
// TODO: we could probably move these helpers to some oopsy util.
const pushedIntoWall = (triggerId, abilityId) => {
    return {
        id: triggerId,
        type: 'Ability',
        netRegex: NetRegexes.ability({ id: abilityId, ...playerDamageFields }),
        condition: (data, matches) => data.DamageFromMatches(matches) > 0,
        deathReason: (_data, matches) => {
            return {
                id: matches.targetId,
                name: matches.target,
                text: {
                    en: 'Pushed into wall',
                    de: 'Rückstoß in die Wand',
                    fr: 'Poussé(e) dans le mur',
                    ja: '壁へノックバック',
                    cn: '击退至墙',
                    ko: '넉백',
                },
            };
        },
    };
};
const nonzeroDamageMistake = (triggerId, abilityId, type) => {
    return {
        id: triggerId,
        type: 'Ability',
        netRegex: NetRegexes.ability({ id: abilityId, ...playerDamageFields }),
        condition: (data, matches) => data.DamageFromMatches(matches) > 0,
        mistake: (_data, matches) => {
            return {
                type: type,
                blame: matches.target,
                reportId: matches.targetId,
                text: matches.ability,
            };
        },
    };
};
const triggerSet = {
    zoneId: ZoneId.AnotherAloaloIsland,
    damageWarn: {
        // Trash 1
        'AAI Twister': '8BC0',
        'AAI Kiwakin Tail Screw': '8BB8',
        'AAI Snipper Bubble Shower': '8BB9',
        'AAI Snipper Crab Dribble': '8BBA',
        'AAI Ray Hydrocannon': '8BBD',
        'AAI Ray Expulsion': '8BBF',
        'AAI Ray Electric Whorl': '8BBE',
        // Ketuduke
        'AAI Spring Crystal Saturate 1': '8AAB',
        'AAI Spring Crystal Saturate 2': '8AAC',
        'AAI Sphere Shatter': '8ABC',
        'AAI Receding Twintides': '8ACC',
        'AAI Near Tide': '8ACD',
        'AAI Encroaching Twintides': '8ACE',
        'AAI Far Tide': '8ACF',
        'AAI Hydrobomb': '8AD1',
        // Trash 2
        'AAI Wood Golem Ovation': '8BC1',
        'AAI Islekeeper Isle Drop': '8C6F',
        // Lala
        'AAI Arcane Blight': '888F',
        'AAI Bright Pulse 1': '8891',
        'AAI Bright Pulse 2': '8892',
        'AAI Arcane Mine': '889A',
        'AAI Golem Aero II': '88A4',
        'AAI Telluric Theorem': '88A9',
        // Statice
        'AAI Trigger Happy': '894C',
        'AAI Bomb Burst': '895D',
        'AAI Uncommon Ground': '8CC2',
        'AAI Faerie Ring': '8956',
        'AAI Fire Spread 1': '8982',
        'AAI Fire Spread 2': '89F9', // ongoing rotating fire damage (from Statice)
    },
    damageFail: {
        'AAI Big Burst': '8AC3',
        'AAI Massive Explosion 1': '889C',
        'AAI Massive Explosion 2': '889D',
        'AAI Burning Chains': '8CBE',
        'AAI Surprising Missile Burst': '8957',
        'AAI Surprising Claw Death by Claw': '8958', // running into Surprising Claw tethered add
    },
    gainsEffectFail: {
        // C03 = 9999 duration, ??? = 15s duration
        'AAI Dropsy': 'C03',
        // C05 = 9999 duration, C06 = 15s duration
        'AAI Bleeding': 'C05',
        // BF9 = 9999 duration, BFA??? = 15s duration
        'AAI Burns': 'BF9', // standing outside Lala
    },
    shareWarn: {
        'AAI Hydrobullet': '8ABA',
        'AAI Wood Golem Tornado': '8C4D',
        'AAI Powerful Light': '88A6',
        'AAI Explosive Theorem': '88A8',
        'AAI Trapshooting Spread': '895B',
        'AAI Firewords Spread': '8960', // spread damage during Present Box / Pinwheeling Dartboard
    },
    soloWarn: {
        'AAI Snipper Water III': '8C64',
        'AAI Islekeeper Gravity Force': '8BC5',
        'AAI Trapshooting Stack': '895A', // stack damage from Trick Reload
    },
    soloFail: {
        'AAI Hydrofall': '8AB7',
        'AAI Symmetric Surge': '889E',
        'AAI Fireworks Stack': '895F', // two person stack damage during Present Box / Pinwheeling Dartboard
    },
    triggers: [
        renameMistake('AAI Tornado', '8BC0', 'fail', {
            // running into a tornado in the initial trash section
            en: 'Tornado',
            de: 'Tornado',
            fr: 'Tornade',
            ja: 'トルネド',
            cn: '龙卷风',
            ko: '토네이도',
        }),
        pushedIntoWall('AAI Angry Seas', '8AC1'),
        pushedIntoWall('AAI Pop', '894E'),
        nonzeroDamageMistake('AAI Hundred Lashings', ['8AC9', '8ACB'], 'warn'),
    ],
};
export default triggerSet;
//# sourceMappingURL=another_aloalo_island.js.map