import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { GetShareMistakeText, GetSoloMistakeText, playerDamageFields } from '../../../oopsy_common';
// TODO: we probably could use an oopsy utility library (and Data should be `any` here).
const stackMistake = (type, expected, abilityText) => {
    return (_data, matches) => {
        const actual = parseFloat(matches.targetCount);
        if (actual === expected || actual === 0)
            return;
        const ability = abilityText ?? matches.ability;
        const text = actual === 1 ? GetSoloMistakeText(ability) : GetShareMistakeText(ability, actual);
        return { type: type, blame: matches.target, text: text };
    };
};
const triggerSet = {
    zoneId: ZoneId.AnotherSildihnSubterrane,
    initData: () => {
        return {
            hasRiteOfPassage: {},
        };
    },
    damageWarn: {
        'ASS Aqueduct Kaluk Right Sweep': '7963',
        'ASS Aqueduct Kaluk Left Sweep': '7964',
        'ASS Aqueduct Kaluk Creeping Ivy': '7965',
        'ASS Aqueduct Belladonna Atropine Spore': '7960',
        'ASS Aqueduct Sapria Bloody Caress': '795F',
        'ASS Aqueduct Udumbara Honeyed Right': '795C',
        'ASS Aqueduct Udumbara Honeyed Left': '795B',
        'ASS Aqueduct Dryad Acorn Bomb': '7958',
        'ASS Aqueduct Dryad Arboreal Storm': '7957',
        'ASS Aqueduct Oqdan Uproot': '795A',
        'ASS Aqueduct Oqdan Gelid Gale': '7959',
        'ASS Silkie Chilling Duster': '7763',
        'ASS Silkie Bracing Duster': '7764',
        'ASS Silkie Fizzling Duster 1': '7765',
        'ASS Silkie Fizzling Duster 2': '775D',
        'ASS Silkie Soapsud Static': '77ED',
        'ASS Silkie Squeaky Clean 1': '7753',
        'ASS Silkie Squeaky Clean 2': '7754',
        'ASS Silkie Squeaky Clean 3': '7755',
        'ASS Silkie Squeaky Clean 4': '7756',
        'ASS Silkie Silken Puff Chilling Duster': '7768',
        'ASS Silkie Silken Puff Bracing Duster': '7769',
        'ASS Silkie Silken Puff Fizzling Duster': '776A',
        'ASS Silkie Silken Puff Puff and Tumble 1': '7770',
        'ASS Silkie Silken Puff Puff and Tumble 2': '7771',
        'ASS Silkie Eastern Ewer Brim Over': '776E',
        'ASS Silkie Eastern Ewer Rinse': '776F',
        'ASS Sil\'dihn Dullahan Blighted Gloom': '7966',
        'ASS Aqueduct Armor Dominion Slash': '796A',
        'ASS Gladiator Rush of Might Front': '765B',
        'ASS Gladiator Rush of Might Back': '765C',
        'ASS Gladiator Ring of Might Out 1': '765D',
        'ASS Gladiator Ring of Might Out 2': '765E',
        'ASS Gladiator Ring of Might Out 3': '765F',
        'ASS Gladiator Ring of Might In 1': '7660',
        'ASS Gladiator Ring of Might In 2': '7661',
        'ASS Gladiator Ring of Might In 3': '7662',
        'ASS Gladiator Lingering Echo': '7677',
        'ASS Gladiator Regret Rack and Ruin': '7664',
        'ASS Gladiator Sundered Remains': '7668',
        'ASS Shadowcaster Ball of Fire Burn': '7490',
        'ASS Shadowcaster Arcane Font Blazing Benifice': '74A6',
        'ASS Shadowcaster Cast Shadow 1': '749C',
        'ASS Shadowcaster Cast Shadow 2': '749E',
        'ASS Shadowcaster Pure Fire': '74A1', // baited puddles
    },
    damageFail: {
        'ASS Silkie Silken Puff Buffeted Puffs': '77EA',
        'ASS Gladiator Massive Explosion': '766B',
        'ASS Gladiator Chains of Resentment': '7667',
        'ASS Shadowcaster Trespasser\'s Pyre': '7499',
        'ASS Shadowcaster Big Burst': '74B9', // failing Cryptic Flames
    },
    gainsEffectWarn: {
        'ASS Silkie Deep Freeze': '4E6', // not moving after Soap's Up
    },
    gainsEffectFail: {
        'ASS Silkie Bleeding': 'C05',
        'ASS Shadowcaster Burns': 'BF9', // standing outside Shadowcaster arena
    },
    shareWarn: {
        'ASS Gladiator Echo of the Fallen': '7675',
        'ASS Gladiator Nothing beside Remains': '768C', // spread during Hateful Visage
    },
    shareFail: {
        'ASS Aqueduct Belladonna Deracinator': '7962',
        'ASS Gladiator Mighty Smite': '7672',
        'ASS Gladiator Scream of the Fallen': '7678',
        'ASS Gladiator Explosion': '766A',
        'ASS Shadowcaster Firesteel Strike': '74B1',
        'ASS Shadowcaster Firesteel Fracture': '74AD',
        'ASS Shadowcaster Infirn Brand Infirm Wave': '74BB', // 90 degree large cleaves on closest people
    },
    soloFail: {
        'ASS Silkie Slippery Soap': '7760',
        'ASS Gladiator Scultor\'s Passion': '79F3',
        'ASS Gladiator Thunderous Echo': '7676', // Curse of the Fallen share
    },
    triggers: [
        {
            // Gaze attack
            id: 'ASS Aqueduct Belladonna Frond Affront',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '7961', ...playerDamageFields }),
            // Always hits target, but if correctly resolved will deal 0 damage
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
        {
            // Golden and Silver flames do damage if not cleansing a debuff
            // The same abilities are used for both versions.
            id: 'ASS Gladiator Hateful Visage Flame',
            type: 'Ability',
            // 766F = Golden Flame
            // 7670 = Silver Flame
            netRegex: NetRegexes.ability({ id: ['766F', '7670'], ...playerDamageFields }),
            condition: (data, matches) => data.DamageFromMatches(matches) > 0,
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.ability,
                };
            },
        },
        {
            id: 'ASS Shadowcaster Blessed Beacon',
            type: 'Ability',
            // TODO: this could be invuln'd
            netRegex: NetRegexes.ability({ id: ['74B4', '74B5'] }),
            mistake: stackMistake('fail', 2),
        },
        {
            // This will kill the players if they don't take a portal.
            id: 'ASS Shadowcaster Call of the Portal',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: 'CCC' }),
            delaySeconds: (_data, matches) => parseFloat(matches.duration) - 0.5,
            deathReason: (_data, matches) => {
                return {
                    id: matches.targetId,
                    name: matches.target,
                    reportId: matches.targetId,
                    text: matches.effect,
                };
            },
        },
        {
            id: 'ASS Shadowcaster Rite of Passage Gain',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: 'CCD' }),
            run: (data, matches) => data.hasRiteOfPassage[matches.target] = true,
        },
        {
            id: 'ASS Shadowcaster Rite of Passage Lose',
            type: 'LosesEffect',
            netRegex: NetRegexes.losesEffect({ effectId: 'CCD' }),
            run: (data, matches) => data.hasRiteOfPassage[matches.target] = false,
        },
        {
            id: 'ASS Shadowcaster Stun',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: 'A60' }),
            // Stuns are a good way to indicate who broke a line incorrectly.
            // However, everybody gets a stun during the teleport section.
            condition: (data, matches) => !data.hasRiteOfPassage[matches.target],
            mistake: (_data, matches) => {
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.effect,
                };
            },
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=another_sildihn_subterrane.js.map