import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { GetShareMistakeText } from '../../../oopsy_common';
const triggerSet = {
    zoneId: ZoneId.AnabaseiosTheTwelfthCircleSavage,
    damageWarn: {
        'P12S Trinity of Souls 1': '82E1',
        'P12S Trinity of Souls 2': '82E2',
        'P12S Trinity of Souls 3': '82E3',
        'P12S Trinity of Souls 4': '82E4',
        'P12S Trinity of Souls 5': '82E5',
        'P12S Trinity of Souls 6': '82E6',
        'P12S Trinity of Souls 7': '82E7',
        'P12S Trinity of Souls 8': '82E8',
        'P12S Trinity of Souls 9': '82E9',
        'P12S Trinity of Souls 10': '82EA',
        'P12S Trinity of Souls 11': '82EB',
        'P12S Trinity of Souls 12': '82EC',
        'P12S Ray of Light': '82EE',
        'P12S Superchain Burst': '82DB',
        'P12S Superchain Coil': '82DC',
        'P12S Theos\'s Cross': '830A',
        'P12S Theos\'s Saltire': '830B',
        'P12S Clear Cut': '82FB',
        'P12S Palladion Floor Drop': '82F9',
        'P12S Parthenos': '8303',
        'P12S Ultima Ray': '8330',
        'P12S Demi Parhelion': '832C',
        'P12S Implode': '8333',
        'P12S Palladian Ray Ongoing': '8325',
        'P12S Ekpyrosis Exaflare': '8320',
        'P12S Entropic Excess': '833C', // ground circles during Caloric Theory 2
    },
    damageFail: {
        'P12S Sample': '82E0',
        'P12S Tilted Balance': '8335', // failing tether distance during Classical Concepts
    },
    gainsEffectWarn: {
        'P12S Bleeding': 'B87', // standing in a Palladion puddle
    },
    shareWarn: {
        'P12S Searing Radiance': '82F1',
        'P12S Shadowsear': '82F2',
        'P12S Theos\'s Holy': '8306',
        'P12S Divine Excoriation': '832E',
        'P12S Palladian Ray Initial': '8324',
        'P12S Ekpyrosis Spread': '8322', // spread during exaflares
    },
    shareFail: {
        'P12S Superchain Radiation': '82DF',
        'P12S Umbral Glow': '830C',
        'P12S Astral Glow': '830D',
        'P12S Shock': '8312',
        'P12S Palladian Grasp 1': '831C',
        'P12S Palladian Grasp 2': '831D',
        'P12S Dynamic Atmosphere': '833B',
        'P12S Caloric Theory 2': '8792', // initial Caloric Theory 2 wind spread
    },
    soloFail: {
        'P12S Superchain Emission': '82DE',
        'P12S Pyre Pulse': '833A', // partner 2x stack
    },
    triggers: [
        {
            id: 'P12S White Flame Share',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '82F0' }),
            condition: (data, matches) => !data.IsImmune(matches.targetId),
            mistake: (_data, matches) => {
                const numTargets = parseInt(matches.targetCount);
                if (numTargets === 1 || isNaN(numTargets))
                    return;
                return {
                    type: 'warn',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: GetShareMistakeText(matches.ability, numTargets),
                };
            },
        },
        {
            id: 'P12S Close Caloric Count',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: 'E05', count: '05' }),
            suppressSeconds: 10,
            mistake: (_data, matches) => {
                return {
                    type: 'wipe',
                    blame: matches.target,
                    reportId: matches.targetId,
                    text: matches.effect,
                };
            },
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=p12s.js.map