import NetRegexes from '../../../../../resources/netregexes';
import ZoneId from '../../../../../resources/zone_id';
import { GetShareMistakeText, GetSoloMistakeText } from '../../../oopsy_common';
// TODO: we probably could use an oopsy utility library (and Data should be `any` here).
const stackMistake = (type, expected, abilityText) => {
    return (_data, matches) => {
        const actual = parseFloat(matches.targetCount);
        if (actual === expected || actual === 0)
            return;
        const ability = abilityText ?? matches.ability;
        const text = actual === 1 ? GetSoloMistakeText(ability) : GetShareMistakeText(ability, actual);
        return { type: type, blame: matches.target, text: text };
    };
};
const purpleMistake = () => {
    return (_data, matches) => {
        return {
            type: 'fail',
            blame: matches.target,
            text: {
                en: `${matches.ability} (purple)`,
                de: `${matches.ability} (lila)`,
                fr: `${matches.ability} (violet)`,
                ja: `${matches.ability} (紫)`,
                cn: `${matches.ability} (紫色)`,
                ko: `${matches.ability} (보라)`,
            },
        };
    };
};
const wallDeathReason = () => {
    return (_data, matches) => {
        return {
            id: matches.targetId,
            name: matches.target,
            text: {
                en: 'Pushed into wall',
                de: 'Rückstoß in die Wand',
                fr: 'Poussé(e) dans le mur',
                ja: '壁へノックバック',
                cn: '击退至墙',
                ko: '벽으로 넉백',
            },
        };
    };
};
const triggerSet = {
    zoneId: ZoneId.AbyssosTheEighthCircleSavage,
    damageWarn: {
        'P8S Torch Flame': '7927',
        'P8S Scorching Fang': '7912',
        'P8S Sun\'s Pinion': '7913',
        'P8S Snaking Kick': '7929',
        'P8S Eye of the Gorgon': '792D',
        'P8S Illusory Hephaistos Scorched Pinion': '7953',
        'P8S Illusory Hephaistos Scorching Fang': '7952',
        'P8S Cthonic Vent 1': '7925',
        'P8S Cthonic Vent 2': '7926',
        'P8S Cthonic Vent 3': '794E',
        'P8S Illusory Hephaistos Gorgospit': '7932',
        'P8S Quadrupedal Crush 1': '7105',
        'P8S Quadrupedal Crush 2': '7107',
        'P8S Tyrant\'s Flare': '7A8A',
        'P8S Ashing Blaze Left': '79D7',
        'P8S Ashing Blaze Right': '79D8',
        'P8S Illusory Hephaistoss End of Days': '7A8B',
        'P8S Tyrant\'s Flare II': '7A88', // baited puddles during Limitless Desolation
    },
    damageFail: {
        'P8S Crown of the Gorgon': '792E',
        'P8S Trailblaze': '793E', // line aoe down the middle during beast2 trailblaze knockback
    },
    gainsEffectFail: {
        // Needs to not happen for Gorgons
        'P8S Petrification': 'BBF',
    },
    shareWarn: {
        'P8S Nest of Flamevipers': '7920',
        'P8S Emergent Octaflare': '7918', // stored spread
    },
    shareFail: {
        'P8S Flameviper 1': '7945',
        'P8S Flameviper 2': '7946',
        'P8S Uplift': '7935',
        'P8S Hemitheos\'s Flare': '72CE',
        'P8S Tyrant\'s Unholy Darkness': '79DE',
        'P8S Tyrant\'s Fire III': '75F0',
        'P8S Orogenic Deformation': '79DB', // Dominion spread
    },
    triggers: [
        {
            // Stored partner stacks.
            id: 'P8S Emergent Tetraflare',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '7919' }),
            mistake: stackMistake('fail', 2),
        },
        {
            // Stored beast2 light party stacks.
            id: 'P8S Emergent Diflare',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '791B' }),
            mistake: stackMistake('warn', 4),
        },
        {
            // 4x beast1 jumps with partners
            id: 'P8S Stomp Dead',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '7937' }),
            mistake: stackMistake('fail', 2),
        },
        {
            // Initial knockback from beast transformation.
            id: 'P8S Footprint',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '7109' }),
            deathReason: wallDeathReason(),
        },
        {
            // Black line knockback during beast2
            id: 'P8S Trailblaze Knockback',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '793E' }),
            deathReason: wallDeathReason(),
        },
        {
            // Radial knockback during beast2
            id: 'P8S Quadrupedal Impact',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: ['7104', '7106'] }),
            deathReason: wallDeathReason(),
        },
        {
            id: 'P8S Natural Alignment Gain',
            type: 'GainsEffect',
            netRegex: NetRegexes.gainsEffect({ effectId: 'D54' }),
            run: (data, matches) => (data.hasPurple ??= {})[matches.target] = true,
        },
        {
            id: 'P8S Natural Alignment Lose',
            type: 'LosesEffect',
            netRegex: NetRegexes.losesEffect({ effectId: 'D54' }),
            run: (data, matches) => (data.hasPurple ??= {})[matches.target] = false,
        },
        {
            // Natural Alignment stack
            id: 'P8S Forcible Fire III',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79BF' }),
            mistake: (data, matches) => {
                if (data.hasPurple?.[matches.target])
                    return purpleMistake()(data, matches);
                return stackMistake('warn', 6)(data, matches);
            },
        },
        {
            // Natural Alignment spread
            id: 'P8S Forcible Fire II',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79C0' }),
            mistake: (data, matches) => {
                if (data.hasPurple?.[matches.target])
                    return purpleMistake()(data, matches);
                return stackMistake('warn', 1)(data, matches);
            },
        },
        {
            // Natural Alignment ice
            id: 'P8S Forcible Difreeze',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79BE' }),
            mistake: (data, matches) => {
                if (data.hasPurple?.[matches.target])
                    return purpleMistake()(data, matches);
                return stackMistake('fail', 3)(data, matches);
            },
        },
        {
            // Natural Alignment fire
            id: 'P8S Forcible Trifire',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79BD' }),
            mistake: (data, matches) => {
                if (data.hasPurple?.[matches.target])
                    return purpleMistake()(data, matches);
                return stackMistake('fail', 2)(data, matches);
            },
        },
        {
            id: 'P8S Solosplice',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79B2' }),
            mistake: stackMistake('fail', 1, {
                // This is all just "Splicer", so rename it here.
                // Also sure this could just be in shareFail, but it fits with the other splicers.
                en: 'Single Splicer',
                de: 'Einzelne Konzeptreflektion',
                fr: 'Réaction conceptuelle simple',
                ja: '1人',
                cn: '1 重叠',
                ko: '1인징',
            }),
        },
        {
            id: 'P8S Multisplice',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79B3' }),
            mistake: stackMistake('fail', 2, {
                en: 'Double Splicer',
                de: 'Doppelte Konzeptreflektion',
                fr: 'Réaction conceptuelle double',
                ja: '2人頭割り',
                cn: '2 重叠',
                ko: '2인징',
            }),
        },
        {
            id: 'P8S Supersplice',
            type: 'Ability',
            netRegex: NetRegexes.ability({ id: '79B4' }),
            mistake: stackMistake('fail', 3, {
                en: 'Triple Splicer',
                de: 'Dreifache Konzeptreflektion',
                fr: 'Réaction conceptuelle triple',
                ja: '3人頭割り',
                cn: '3 重叠',
                ko: '3인징',
            }),
        },
    ],
};
export default triggerSet;
//# sourceMappingURL=p8s.js.map