import { RaidbossData } from '../../../../../types/data';
import { PluginCombatantState } from '../../../../../types/event';
import { NetMatches } from '../../../../../types/net_matches';
import { TriggerSet } from '../../../../../types/trigger';
type Phase = 'superchain1' | 'palladion' | 'superchain2a' | 'superchain2b' | 'gaiaochos1' | 'classical1' | 'caloric' | 'pangenesis' | 'classical2' | 'gaiaochos2';
declare const engravementLabelMapAsConst: {
    readonly DF8: "lightTilt";
    readonly DF9: "darkTilt";
    readonly DFB: "lightTower";
    readonly DFC: "darkTower";
    readonly DFD: "lightBeam";
    readonly DFE: "darkBeam";
    readonly DFF: "crossMarked";
    readonly E00: "xMarked";
};
type EngravementLabel = typeof engravementLabelMapAsConst[keyof typeof engravementLabelMapAsConst];
type AnthroposTether = 'light' | 'dark';
type ConceptColor = 'blue' | 'red' | 'yellow';
type ConceptDebuff = 'alpha' | 'beta';
type ConceptPair = 'circle' | 'triangle' | 'square' | 'cross';
type InterceptOutput = 'leanNorth' | 'leanEast' | 'leanSouth' | 'leanWest';
type PangenesisRole = 'shortLight' | 'shortDark' | 'longLight' | 'longDark' | 'one' | 'not';
type CaloricMarker = 'fire' | 'wind';
export type LimitCutCombatantState = PluginCombatantState & {
    order?: number;
};
export interface Data extends RaidbossData {
    readonly triggerSetConfig: {
        engravement1DropTower: 'quadrant' | 'clockwise' | 'tower' | 'tetherbase';
        classicalConceptsPairOrder: 'xsct' | 'cxts' | 'ctsx' | 'ctxs' | 'tcxs' | 'shapeAndDebuff';
        classicalConcepts2ActualNoFlip: true | false;
        pangenesisFirstTower: 'agnostic' | 'not' | 'one';
    };
    decOffset?: number;
    expectedFirstHeadmarker?: string;
    isDoorBoss: boolean;
    phase?: Phase;
    combatantData: PluginCombatantState[];
    paradeigmaCounter: number;
    glaukopisFirstHit?: string;
    glaukopisSecondHitSame: boolean;
    engravementCounter: number;
    engravement1BeamsPosMap: Map<string, string>;
    engravement1TetherIds: number[];
    engravement1TetherPlayers: {
        [name: string]: AnthroposTether;
    };
    engravement1LightBeamsPos: string[];
    engravement1DarkBeamsPos: string[];
    engravement1Towers: string[];
    engravement2MyLabel?: EngravementLabel;
    engravement3TowerType?: 'lightTower' | 'darkTower';
    engravement3TowerPlayers: string[];
    engravement3TetherPlayers: {
        [name: string]: AnthroposTether;
    };
    engravement3TethersSide?: 'east' | 'west';
    wingCollect: string[];
    wingCalls: ('swap' | 'stay')[];
    superchainCollect: NetMatches['AddedCombatant'][];
    superchain1FirstDest?: NetMatches['AddedCombatant'];
    limitCutNumber?: number;
    lcCombatants: LimitCutCombatantState[];
    lcCombatantsOffset: number;
    lcWhiteFlameDelay?: [number, number, number, number];
    whiteFlameCounter: number;
    superchain2aFirstDir?: 'north' | 'south';
    superchain2aSecondDir?: 'north' | 'south';
    superchain2aSecondMech?: 'protean' | 'partners';
    superchain2bFirstDir?: 'north' | 'south';
    superchain2bSecondMech?: 'protean' | 'partners';
    superchain2bSecondDir?: 'east' | 'west';
    sampleTiles: NetMatches['Tether'][];
    darknessClones: NetMatches['StartsUsing'][];
    conceptPair?: ConceptPair;
    conceptDebuff?: ConceptDebuff;
    conceptData: {
        [location: number]: ConceptColor;
    };
    classical2InitialColumn?: number;
    classical2InitialRow?: number;
    classical2Intercept?: InterceptOutput;
    pangenesisDebuffsCalled?: boolean;
    pangenesisRole: {
        [name: string]: PangenesisRole;
    };
    pangenesisTowerCount: number;
    lastPangenesisTowerColor?: 'light' | 'dark';
    pangenesisCurrentColor?: 'light' | 'dark';
    gaiaochosCounter: number;
    palladionGrapsTarget?: string;
    classicalCounter: number;
    caloricCounter: number;
    caloric1First: string[];
    caloric1Buff: {
        [name: string]: CaloricMarker;
    };
    caloric1Mine?: CaloricMarker;
    caloric2Fire?: string;
    caloric2PassCount: number;
    gaiaochosTetherCollect: string[];
    seenSecondTethers: boolean;
    geocentrism2OutputStr?: string;
}
declare const triggerSet: TriggerSet<Data>;
export default triggerSet;
