import { RaidbossData } from '../../../../../types/data';
import { PluginCombatantState } from '../../../../../types/event';
import { NetMatches } from '../../../../../types/net_matches';
import { Output, TriggerSet } from '../../../../../types/trigger';
export type Concept = 'shortalpha' | 'longalpha' | 'shortbeta' | 'longbeta' | 'shortgamma' | 'longgamma' | 'alpha' | 'beta' | 'gamma' | 'primal';
export type Splicer = 'solosplice' | 'multisplice' | 'supersplice';
export declare const towerColors: readonly ["green", "blue", "purple"];
export type TowerColor = typeof towerColors[number];
export declare const perfectedConcepts: readonly ["alpha", "beta", "gamma"];
export type PerfectedConcept = typeof perfectedConcepts[number];
export interface Data extends RaidbossData {
    conceptual?: 'octa' | 'tetra' | 'di';
    combatantData: PluginCombatantState[];
    torches: NetMatches['StartsUsing'][];
    flareTargets: string[];
    upliftCounter: number;
    ventCasts: (NetMatches['StartsUsing'] | NetMatches['Ability'])[];
    illusory?: 'bird' | 'snake';
    gorgons: NetMatches['AddedCombatant'][];
    gorgonCount: number;
    seenSnakeIllusoryCreation?: boolean;
    crushImpactSafeZone?: string;
    footfallsConcept?: string;
    footfallsDirs: number[];
    footfallsOrder: string[];
    trailblazeCount: number;
    trailblazeTorchSafeZone?: string;
    firstSnakeOrder: {
        [name: string]: 1 | 2;
    };
    firstSnakeDebuff: {
        [name: string]: 'gaze' | 'poison';
    };
    firstSnakeCalled?: boolean;
    secondSnakeGazeFirst: {
        [name: string]: boolean;
    };
    secondSnakeDebuff: {
        [name: string]: 'nothing' | 'shriek' | 'stack';
    };
    seenFirstTankAutos?: boolean;
    firstAlignmentSecondAbility?: 'stack' | 'spread';
    seenFirstAlignmentStackSpread?: boolean;
    concept: {
        [name: string]: Concept;
    };
    splicer: {
        [name: string]: Splicer;
    };
    arcaneChannelCount: number;
    arcaneChannelColor: Set<TowerColor>;
    alignmentTargets: string[];
    burstCounter: number;
    myTower?: number;
    flareCounter: number;
    inverseMagics: {
        [name: string]: boolean;
    };
    deformationHit: string[];
    deformationNotHit: string[];
    deformationOnMe: boolean;
    deformationPartner?: string;
}
export declare const positionMatchesTo8Dir: (combatant: NetMatches['AddedCombatant']) => number;
export declare const positionTo8Dir: (combatant: PluginCombatantState) => number;
export declare const headingTo8Dir: (heading: number) => number;
export declare const ventOutputStrings: {
    readonly comboDir: {
        readonly en: "${dir1} / ${dir2}";
        readonly de: "${dir1} / ${dir2}";
        readonly fr: "${dir1} / ${dir2}";
        readonly ja: "${dir1} / ${dir2}";
        readonly cn: "${dir1} / ${dir2}";
        readonly ko: "${dir1} / ${dir2}";
    };
    readonly north: {
        readonly en: "North";
        readonly de: "Norden";
        readonly fr: "Nord";
        readonly ja: "北";
        readonly cn: "上";
        readonly ko: "북쪽";
    };
    readonly east: {
        readonly en: "East";
        readonly de: "Osten";
        readonly fr: "Est";
        readonly ja: "東";
        readonly cn: "右";
        readonly ko: "동쪽";
    };
    readonly south: {
        readonly en: "South";
        readonly de: "Süden";
        readonly fr: "Sud";
        readonly ja: "南";
        readonly cn: "下";
        readonly ko: "남쪽";
    };
    readonly west: {
        readonly en: "West";
        readonly de: "Westen";
        readonly fr: "Ouest";
        readonly ja: "西";
        readonly cn: "左";
        readonly ko: "서쪽";
    };
    readonly dirNE: {
        readonly en: "NE";
        readonly de: "NO";
        readonly fr: "NE";
        readonly ja: "北東";
        readonly cn: "右上";
        readonly ko: "북동";
    };
    readonly dirSE: {
        readonly en: "SE";
        readonly de: "SO";
        readonly fr: "SE";
        readonly ja: "南東";
        readonly cn: "右下";
        readonly ko: "남동";
    };
    readonly dirSW: {
        readonly en: "SW";
        readonly de: "SW";
        readonly fr: "SO";
        readonly ja: "南西";
        readonly cn: "左下";
        readonly ko: "남서";
    };
    readonly dirNW: {
        readonly en: "NW";
        readonly de: "NW";
        readonly fr: "NO";
        readonly ja: "北西";
        readonly cn: "左上";
        readonly ko: "북서";
    };
    readonly unknown: {
        readonly en: "???";
        readonly de: "???";
        readonly fr: "???";
        readonly ja: "???";
        readonly cn: "???";
        readonly ko: "???";
    };
};
export declare const ventOutput: (unsafeSpots: number[], output: Output) => string;
declare const triggerSet: TriggerSet<Data>;
export default triggerSet;
