import { RaidbossData } from '../../../../../types/data';
import { PluginCombatantState } from '../../../../../types/event';
import { NetMatches } from '../../../../../types/net_matches';
import { TriggerSet } from '../../../../../types/trigger';
export type Phase = 'p1' | 'p2' | 'p3' | 'p4' | 'delta' | 'sigma' | 'omega' | 'p6';
export declare const playstationMarkers: readonly ["circle", "cross", "triangle", "square"];
export type PlaystationMarker = typeof playstationMarkers[number];
export type Glitch = 'mid' | 'remote';
export type Cannon = 'spread' | 'stack';
export type RotColor = 'blue' | 'red';
export type Regression = 'local' | 'remote';
export type TetherColor = 'blue' | 'green';
export type TrioDebuff = 'near' | 'distant';
export interface Data extends RaidbossData {
    readonly triggerSetConfig: {
        staffSwordDodge: 'mid' | 'far';
    };
    combatantData: PluginCombatantState[];
    phase: Phase;
    decOffset?: number;
    inLine: {
        [name: string]: number;
    };
    loopBlasterCount: number;
    pantoMissileCount: number;
    solarRayTargets: string[];
    glitch?: Glitch;
    synergyMarker: {
        [name: string]: PlaystationMarker;
    };
    spotlightStacks: string[];
    meteorTargets: string[];
    cannonFodder: {
        [name: string]: Cannon;
    };
    smellDefamation: string[];
    smellRot: {
        [name: string]: RotColor;
    };
    bugRot: {
        [name: string]: RotColor;
    };
    defamationColor?: RotColor;
    regression: {
        [name: string]: Regression;
    };
    latentDefectCount: number;
    patchVulnCount: number;
    waveCannonStacks: NetMatches['Ability'][];
    monitorPlayers: NetMatches['GainsEffect'][];
    deltaTethers: {
        [name: string]: TetherColor;
    };
    trioDebuff: {
        [name: string]: TrioDebuff;
    };
    omegaDodgeRotation?: 'right' | 'left';
    seenOmegaTethers?: boolean;
    cosmoArrowCount: number;
    cosmoArrowIn?: boolean;
    cosmoArrowExaCount: number;
    waveCannonFlares: number[];
}
export declare const headmarkers: {
    readonly spread: "0017";
    readonly buster: "0157";
    readonly firechainCircle: "01A0";
    readonly firechainTriangle: "01A1";
    readonly firechainSquare: "01A2";
    readonly firechainX: "01A3";
    readonly stack: "0064";
    readonly meteor: "015A";
};
export declare const playstationHeadmarkerIds: readonly string[];
export declare const playstationMarkerMap: {
    [id: string]: PlaystationMarker;
};
export declare const firstMarker: number;
export declare const getHeadmarkerId: (data: Data, matches: NetMatches['HeadMarker']) => string;
declare const triggerSet: TriggerSet<Data>;
export default triggerSet;
