import { DirectionOutput8 } from '../../../../../resources/util';
import { RaidbossData } from '../../../../../types/data';
import { NetMatches } from '../../../../../types/net_matches';
import { TriggerSet } from '../../../../../types/trigger';
type Phase = 'p1' | 'p2-dd' | 'p2-mm' | 'p2-lr' | 'p3-ur' | 'p3-apoc' | 'p4-dld' | 'p4-ct' | 'p5';
type RelativityDebuff = 'longFire' | 'mediumFire' | 'shortFire' | 'ice';
declare const newRoleMap: () => {
    support: {
        hasIce: boolean;
        shortFire: string;
        mediumFire: string;
        longFire: string[];
    };
    dps: {
        hasIce: boolean;
        shortFire: string[];
        mediumFire: string;
        longFire: string;
    };
    ice: string;
};
type ApocDebuffLength = 'short' | 'medium' | 'long' | 'none';
type ApocDebuffMap = Record<ApocDebuffLength, string[]>;
type CTRole = 'redIce' | 'redWind' | 'blueIce' | 'blueWater' | 'blueUnholy' | 'blueEruption';
declare const ctCollectDebuffs: readonly ["red", "blue", "ice", "wind"];
type CTCollectDebuff = typeof ctCollectDebuffs[number];
type CTCollectDebuffsMap = Record<CTCollectDebuff, string[]>;
export interface Data extends RaidbossData {
    readonly triggerSetConfig: {
        sinboundRotate: 'aacc' | 'addposonly';
        ultimateRel: 'yNorthDPSEast' | 'none';
        apoc: 'dpsNE-CW' | 'none';
        darklit: 'healerPlantNW' | 'none';
        ct: 'earlyPopSouth' | 'none';
    };
    phase: Phase | 'unknown';
    actorSetPosTracker: {
        [id: string]: NetMatches['ActorSetPos'];
    };
    p1ConcealSafeDirs: DirectionOutput8[];
    p1StackSpread?: 'stack' | 'spread';
    p1SeenBurnishedGlory: boolean;
    p1FallOfFaithTethers: ('fire' | 'lightning')[];
    p2QuadrupleFirstTarget: string;
    p2QuadrupleDebuffApplied: boolean;
    p2IcicleImpactStart: DirectionOutput8[];
    p2AxeScytheSafe?: 'in' | 'out';
    p2FrigidStoneTargets: string[];
    p2KBShivaDir?: DirectionOutput8;
    p2LightsteepedCount: number;
    p2LightRampantPuddles: string[];
    p2SeenFirstHolyLight: boolean;
    p3RelativityRoleCount: number;
    p3RelativityDebuff?: RelativityDebuff;
    p3RelativityRoleMap: ReturnType<typeof newRoleMap>;
    p3RelativityStoplights: {
        [id: string]: NetMatches['AddedCombatant'];
    };
    p3RelativityYellowDirNums: number[];
    p3RelativityMyDirStr: string;
    p3ApocDebuffCount: number;
    p3ApocDebuffs: ApocDebuffMap;
    p3ApocMyDebuff?: ApocDebuffLength;
    p3ApocInitialSide?: 'east' | 'west';
    p3ApocGroupSwap?: boolean;
    p3ApocFirstDirNum?: number;
    p3ApocRotationDir?: 1 | -1;
    p4DarklitTetherCount: number;
    p4DarklitTethers: {
        [player: string]: string[];
    };
    p4DarklitCleaves: string[];
    p4DarklitStacks: string[];
    p4DarklitTowerStackLoc?: 'north' | 'south';
    p4CTMyRole?: CTRole;
    p4CTDebuffs: CTCollectDebuffsMap;
    p4CTPartnerRole?: string;
    p4CTStoplights: {
        [id: string]: NetMatches['AddedCombatant'];
    };
    p4CTTidalDirs: number[];
}
declare const triggerSet: TriggerSet<Data>;
export default triggerSet;
