import { UnreachableCode } from '../../../../resources/not_reached';
import EmulatorCommon from '../EmulatorCommon';
import StubbedPopupText from '../overrides/StubbedPopupText';
export class Resolver {
    status;
    promise;
    run;
    delayUntil;
    final;
    delayPromise;
    promiseResolved = false;
    delayResolver;
    triggerHelper;
    constructor(status) {
        this.status = status;
    }
    async isResolved(log) {
        if (this.delayUntil) {
            if (this.delayUntil < log.timestamp) {
                delete this.delayUntil;
                if (this.delayResolver)
                    this.delayResolver();
                await this.delayPromise;
            }
            else {
                return false;
            }
        }
        if (this.promise && !this.promiseResolved)
            return false;
        if (this.run)
            this.run();
        if (this.final)
            this.final();
        return true;
    }
    setDelay(delayUntil) {
        this.delayUntil = delayUntil;
        return this.delayPromise = new Promise((res) => {
            this.delayResolver = res;
        });
    }
    setPromise(promise) {
        this.promise = promise;
        void this.promise.then(() => {
            this.promiseResolved = true;
        });
    }
    setRun(run) {
        this.run = run;
    }
    setFinal(final) {
        this.final = final;
    }
    setHelper(triggerHelper) {
        this.triggerHelper = triggerHelper;
    }
}
export default class PopupTextAnalysis extends StubbedPopupText {
    triggerResolvers = [];
    currentResolver;
    regexCache;
    callback;
    constructor(options, timelineLoader, raidbossFileData) {
        super(options, timelineLoader, raidbossFileData);
        this.regexCache = new Map();
        this.ttsSay = (_text) => {
            return;
        };
    }
    // Override `OnTrigger` so we can use our own exception handler
    OnTrigger(trigger, matches, currentTime) {
        try {
            this.OnTriggerInternal(trigger, matches, currentTime);
        }
        catch (e) {
            console.log(trigger, e);
        }
    }
    OnLog(_e) {
        throw new UnreachableCode();
    }
    async onEmulatorLog(logs, getCurrentLogLine) {
        for (const logObj of logs) {
            if (!this.regexCache.has(logObj))
                this.regexCache.set(logObj, new Map());
            const lineCache = this.regexCache.get(logObj);
            if (!lineCache)
                continue;
            // Deliberately exclude the check for `cactbot wipe` since that'll never happen here
            for (const trigger of this.triggers) {
                const regex = trigger.localRegex;
                if (!regex)
                    continue;
                let r = lineCache.get(trigger);
                if (r === undefined) {
                    r = regex.exec(logObj.convertedLine) ?? false;
                    lineCache.set(trigger, r);
                }
                if (r === false)
                    continue;
                const resolver = this.currentResolver = new Resolver({
                    initialData: EmulatorCommon.cloneData(this.data),
                    suppressed: false,
                    executed: false,
                });
                this.OnTrigger(trigger, r, logObj.timestamp);
                resolver.setFinal(() => {
                    const currentLine = getCurrentLogLine();
                    resolver.status.finalData = EmulatorCommon.cloneData(this.data);
                    delete resolver.triggerHelper?.resolver;
                    if (this.callback)
                        this.callback(currentLine, resolver.triggerHelper, resolver.status, this.data);
                });
                const isResolved = await resolver.isResolved(logObj);
                if (!isResolved)
                    this.triggerResolvers.push(resolver);
            }
            for (const trigger of this.netTriggers) {
                const regex = trigger.localNetRegex;
                if (!regex)
                    continue;
                let r = lineCache.get(trigger);
                if (r === undefined) {
                    r = regex.exec(logObj.networkLine) ?? false;
                    lineCache.set(trigger, r);
                }
                if (r !== false) {
                    const resolver = this.currentResolver = new Resolver({
                        initialData: EmulatorCommon.cloneData(this.data),
                        suppressed: false,
                        executed: false,
                    });
                    const matches = r.groups ?? {};
                    this._onTriggerInternalGetHelper(trigger, matches, logObj.timestamp);
                    this.OnTrigger(trigger, r, logObj.timestamp);
                    resolver.setFinal(() => {
                        const currentLine = getCurrentLogLine();
                        resolver.status.finalData = EmulatorCommon.cloneData(this.data);
                        delete resolver.triggerHelper?.resolver;
                        if (this.callback)
                            this.callback(currentLine, resolver.triggerHelper, resolver.status, this.data);
                    });
                    const isResolved = await resolver.isResolved(logObj);
                    if (!isResolved)
                        this.triggerResolvers.push(resolver);
                }
            }
            await this.checkResolved(logObj);
        }
    }
    OnNetLog(_e) {
        throw new UnreachableCode();
    }
    async checkResolved(logObj) {
        const unresolved = [];
        for (const res of this.triggerResolvers) {
            if (!await res.isResolved(logObj))
                unresolved.push(res);
        }
        this.triggerResolvers = unresolved;
    }
    _onTriggerInternalCondition(triggerHelper) {
        const ret = super._onTriggerInternalCondition(triggerHelper);
        if (triggerHelper.resolver)
            triggerHelper.resolver.status.condition = ret;
        return ret;
    }
    _onTriggerInternalDelaySeconds(triggerHelper) {
        // Can't inherit the default logic for delay since we don't
        // want to delay for mass processing of the timeline
        const delay = 'delaySeconds' in triggerHelper.trigger
            ? triggerHelper.valueOrFunction(triggerHelper.trigger.delaySeconds)
            : 0;
        if (typeof delay === 'number') {
            if (triggerHelper.resolver)
                triggerHelper.resolver.status.delay = delay;
            if (!delay || delay <= 0)
                return;
            return triggerHelper.resolver?.setDelay(triggerHelper.now + delay * 1000);
        }
    }
    _onTriggerInternalPromise(triggerHelper) {
        const ret = super._onTriggerInternalPromise(triggerHelper);
        if (triggerHelper.resolver)
            triggerHelper.resolver.status.promise = ret;
        if (!ret)
            return ret;
        if (triggerHelper.resolver)
            triggerHelper.resolver.setPromise(ret);
        return ret;
    }
    _onTriggerInternalTTS(triggerHelper) {
        super._onTriggerInternalTTS(triggerHelper);
        if (triggerHelper.ttsText !== undefined &&
            triggerHelper.resolver &&
            triggerHelper.resolver.status.responseType === undefined) {
            triggerHelper.resolver.status.responseType = 'tts';
            triggerHelper.resolver.status.responseLabel = triggerHelper.ttsText;
        }
    }
    _onTriggerInternalRun(triggerHelper) {
        triggerHelper.resolver?.setRun(() => {
            if (triggerHelper.resolver)
                triggerHelper.resolver.status.executed = true;
            super._onTriggerInternalRun(triggerHelper);
        });
    }
    _makeTextElement(triggerHelper, text, _className) {
        if (triggerHelper.resolver)
            triggerHelper.resolver.status.result ??= text;
        return document.createElement('div');
    }
    _createTextFor(triggerHelper, text, textType, _lowerTextKey, _duration) {
        // No-op for functionality, but store off this info for feedback
        if (triggerHelper.resolver) {
            triggerHelper.resolver.status.responseType = textType;
            triggerHelper.resolver.status.responseLabel = text;
        }
    }
    _playAudioFile(triggerHelper, url, _volume) {
        // No-op for functionality, but store off this info for feedback
        if (triggerHelper.resolver) {
            // If we already have text and this is a default alert sound, don't override that info
            if (triggerHelper.resolver.status.responseType !== undefined) {
                if (['info', 'alert', 'alarm'].includes(triggerHelper.resolver.status.responseType) &&
                    [this.options.InfoSound, this.options.AlertSound, this.options.AlarmSound].includes(url))
                    return;
            }
            triggerHelper.resolver.status.responseType = 'audiofile';
            triggerHelper.resolver.status.responseLabel = url;
        }
    }
    _onTriggerInternalGetHelper(trigger, matches, now) {
        const ret = {
            ...super._onTriggerInternalGetHelper(trigger, matches, now),
        };
        ret.resolver = this.currentResolver;
        ret.resolver?.setHelper(ret);
        return ret;
    }
}
//# sourceMappingURL=PopupTextAnalysis.js.map