import DTFuncs from '../../../../../resources/datetime';
import logDefinitions from '../../../../../resources/netlog_defs';
import SFuncs from '../../../../../resources/stringhandlers';
const fields = {
    event: 0,
    timestamp: 1,
};
const unknownLogMessagePrefix = 'Unknown';
const logMessagePrefix = {};
const logDefsGeneric = logDefinitions;
for (const def of Object.values(logDefsGeneric)) {
    if (def.messageType !== undefined)
        logMessagePrefix[def.type] = def.messageType;
}
/**
 * Generic class to track an FFXIV log line
 */
export default class LineEvent {
    networkLine;
    offset = 0;
    convertedLine;
    invalid = false;
    index = 0;
    decEventStr;
    decEvent;
    hexEvent;
    timestamp;
    checksum;
    tzOffsetMillis;
    constructor(repo, networkLine, parts) {
        this.networkLine = networkLine;
        const timestampString = parts[fields.timestamp] ?? '0';
        this.tzOffsetMillis = DTFuncs.getTimezoneOffsetMillis(timestampString);
        this.decEventStr = parts[fields.event] ?? '00';
        this.decEvent = parseInt(this.decEventStr);
        this.hexEvent = SFuncs.zeroPad(this.decEvent.toString(16).toUpperCase());
        this.timestamp = new Date(timestampString).getTime();
        this.checksum = parts.slice(-1)[0] ?? '';
        repo.updateTimestamp(this.timestamp);
        this.convertedLine = this.prefix() + parts.slice(2, -1).join(':').replace('|', ':');
    }
    prefix() {
        const timeString = DTFuncs.timeToTimeString(this.timestamp, this.tzOffsetMillis, true);
        // TODO: should raidemulator not convert lines that don't come from the ffxiv plugin?
        const logMessageName = logMessagePrefix[this.decEventStr] ?? unknownLogMessagePrefix;
        return `[${timeString}] ${logMessageName} ${this.hexEvent}:`;
    }
    static isDamageHallowed(damage) {
        return (parseInt(damage, 16) & parseInt('1000', 16)) > 0;
    }
    static isDamageBig(damage) {
        return (parseInt(damage, 16) & parseInt('4000', 16)) > 0;
    }
    static calculateDamage(damage) {
        if (LineEvent.isDamageHallowed(damage))
            return 0;
        damage = SFuncs.zeroPad(damage, 8);
        const parts = [
            damage.slice(0, 2),
            damage.slice(2, 4),
            damage.slice(4, 6),
            damage.slice(6, 8),
        ];
        if (!LineEvent.isDamageBig(damage))
            return parseInt(parts.slice(0, 2).reverse().join(''), 16);
        return parseInt(parts[3] + parts[0] +
            (parseInt(parts[1], 16) - parseInt(parts[3], 16)).toString(16), 16);
    }
}
export const isLineEventSource = (line) => {
    return 'isSource' in line;
};
export const isLineEventTarget = (line) => {
    return 'isTarget' in line;
};
export const isLineEventJobLevel = (line) => {
    return 'isJobLevel' in line;
};
export const isLineEventAbility = (line) => {
    return 'isAbility' in line;
};
export const isLineEvent0x03 = (line) => {
    return line.decEvent === 3;
};
export const isLineEvent0x105 = (event) => {
    return event.decEvent === 261;
};
//# sourceMappingURL=LineEvent.js.map