import { setOverlayHandlerOverride } from '../../../../resources/overlay_plugin_api';
export default class RaidEmulatorOverlayApiHook {
    emulator;
    currentLogTime = 0;
    connected = false;
    constructor(emulator) {
        this.emulator = emulator;
        setOverlayHandlerOverride('getCombatants', this._getCombatantsOverride.bind(this));
        emulator.on('tick', (currentLogTime) => {
            this.currentLogTime = currentLogTime;
        });
        emulator.on('preSeek', () => {
            this.currentLogTime = 0;
        });
        emulator.on('preCurrentEncounterChanged', (encounter) => {
            this.currentLogTime = 0;
            encounter.on('analyzeLine', (log) => {
                this.currentLogTime = log.timestamp;
            });
        });
    }
    _getCombatantsOverride(msg) {
        return new Promise((res) => {
            const curEnc = this.emulator.currentEncounter;
            const tracker = curEnc?.encounter.combatantTracker;
            if (!curEnc || !tracker) {
                res({ combatants: [] });
                return;
            }
            const timestamp = this.currentLogTime;
            const combatants = [];
            const ids = msg.ids ?? [];
            const names = msg.names ?? [];
            const hasIds = ids.length > 0;
            const hasNames = names.length > 0;
            for (const [id, combatant] of Object.entries(tracker.combatants)) {
                // If this combatant didn't exist at this point, skip them
                const firstStateStamp = combatant.firstStateTimestamp;
                const lastStateStamp = combatant.lastStateTimestamp;
                if (!firstStateStamp || !lastStateStamp)
                    continue;
                if (firstStateStamp > timestamp || lastStateStamp < timestamp)
                    continue;
                const idNum = parseInt(id, 16);
                // nextSignificantState is a bit inefficient but given that this isn't run every tick
                // we can afford to be a bit inefficient for readability's sake
                const combatantState = combatant.nextState(timestamp).fullClone();
                if (!hasIds && !hasNames)
                    combatants.push(combatantState);
                else if (hasIds && ids.includes(idNum))
                    combatants.push(combatantState);
                else if (hasNames && names.includes(combatantState.Name ?? 'never'))
                    combatants.push(combatantState);
            }
            res({
                combatants: combatants,
            });
        });
    }
}
//# sourceMappingURL=RaidEmulatorOverlayApiHook.js.map