import { Timeline } from '../../timeline';
export default class RaidEmulatorTimeline extends Timeline {
    emulatedStatus = 'pause';
    emulator;
    constructor(text, replacements, triggers, styles, options, zoneId) {
        super(text, replacements, triggers, styles, options, zoneId);
    }
    bindTo(emulator) {
        this.emulator = emulator;
        emulator.on('play', () => {
            this.emulatedStatus = 'play';
        });
        emulator.on('pause', () => {
            this.emulatedStatus = 'pause';
        });
    }
    emulatedSync(currentLogTime) {
        if (!currentLogTime)
            return;
        // This is a bit complicated due to jumps in timelines. If we've already got a timebase,
        // fightNow needs to be calculated based off of that instead of initialOffset
        // timebase = 0 when not set
        const baseTimestamp = this.timebase ||
            this.emulator?.currentEncounter?.encounter?.initialTimestamp ||
            currentLogTime;
        const fightNow = (currentLogTime - baseTimestamp) / 1000;
        this.SyncTo(fightNow, currentLogTime);
        this._OnUpdateTimer(currentLogTime);
    }
    _OnUpdateTimer(currentTime) {
        // The base `Timeline` class's `_RemoveExpiredTimers` has a hardcoded `Date.now()` reference
        // for keepalive timers.
        // There's not really a good way to handle this logic otherwise due to not having any other
        // time base to reference against.
        // So we treat any `currentTime` value greater than the last log line of the current encounter
        // as if it was the current timestamp
        const lastLogTimestamp = this.emulator?.currentEncounter?.encounter
            .logLines.slice(-1)[0]?.timestamp;
        if (lastLogTimestamp && currentTime > lastLogTimestamp)
            currentTime = this.emulator?.currentLogTime ?? currentTime;
        super._OnUpdateTimer(currentTime);
    }
    _ScheduleUpdate(_fightNow) {
        // Override
    }
}
//# sourceMappingURL=RaidEmulatorTimeline.js.map