import { UnreachableCode } from '../../../../resources/not_reached';
import { TimelineController } from '../../timeline';
import RaidEmulatorTimeline from './RaidEmulatorTimeline';
export default class RaidEmulatorTimelineController extends TimelineController {
    emulator;
    activeTimeline = null;
    bindTo(emulator) {
        this.emulator = emulator;
        if (this.activeTimeline)
            this.activeTimeline.bindTo(emulator);
    }
    // Override
    SetActiveTimeline(timelineFiles, timelines, replacements, triggers, styles, zoneId) {
        this.activeTimeline = null;
        let text = '';
        // Get the text from each file in |timelineFiles|.
        for (const timelineFile of timelineFiles) {
            const name = this.timelines[timelineFile];
            if (name !== undefined)
                text = `${text}\n${name}`;
            else
                console.log(`Timeline file not found: ${timelineFile}`);
        }
        // Append text from each block in |timelines|.
        for (const timeline of timelines)
            text = `${text}\n${timeline}`;
        if (text) {
            this.activeTimeline = new RaidEmulatorTimeline(text, replacements, triggers, styles, this.options, zoneId);
            if (this.emulator)
                this.activeTimeline.bindTo(this.emulator);
        }
        this.ui.SetTimeline(this.activeTimeline);
    }
    // Override
    OnLogEvent(_e) {
        throw new UnreachableCode();
    }
    OnNetLog(_e) {
        throw new UnreachableCode();
    }
    onEmulatorLogEvent(logs) {
        if (!this.activeTimeline)
            return;
        for (const line of logs) {
            this.activeTimeline.OnLogLine(line.convertedLine, line.timestamp);
            this.activeTimeline.OnNetLogLine(line.networkLine, line.timestamp);
            // Only call _OnUpdateTimer if we have a timebase from the previous call to OnLogLine
            // This avoids spamming the console with a ton of messages
            if (this.activeTimeline.timebase)
                this.activeTimeline._OnUpdateTimer(line.timestamp);
        }
    }
}
//# sourceMappingURL=RaidEmulatorTimelineController.js.map