import Util from '../../../../resources/util';
export default class RaidEmulatorWatchCombatantsOverride {
    emulator;
    overlayHook;
    watches = [];
    constructor(emulator, overlayHook) {
        this.emulator = emulator;
        this.overlayHook = overlayHook;
        const func = (params, callback) => {
            const promise = new Promise((res, rej) => {
                const watch = {
                    lastCheck: 0,
                    params: params,
                    cancel: false,
                    start: 0,
                    func: callback,
                    msg: {
                        call: 'getCombatants',
                        ...params,
                    },
                    res: res,
                    rej: rej,
                };
                this.watches.push(watch);
            });
            return promise;
        };
        Util.setWatchCombatantOverride(func, this.clear.bind(this));
        this.emulator.on('tick', () => {
            const timestamp = this.emulator.currentLogTime;
            if (timestamp === undefined)
                return;
            this.tick(timestamp);
        });
    }
    tick(timestamp) {
        for (const watch of this.watches) {
            if (watch.cancel)
                continue;
            if (watch.lastCheck + (watch.params.delay ?? 1000) > timestamp)
                continue;
            watch.lastCheck = timestamp;
            void this.overlayHook._getCombatantsOverride(watch.msg).then((e) => {
                if (watch.func(e)) {
                    watch.res();
                    watch.cancel = true;
                }
            });
        }
        this.watches = this.watches.filter((w) => !w.cancel);
    }
    clear() {
        for (const watch of this.watches) {
            watch.rej();
            watch.cancel = true;
        }
        this.watches = [];
    }
}
//# sourceMappingURL=RaidEmulatorWatchCombatantsOverride.js.map