import { UnreachableCode } from '../../../../resources/not_reached';
const hideEvents = [
    'mouseleave',
    'blur',
];
const validDirections = [
    'top',
    'right',
    'bottom',
    'left',
];
const showEvents = [
    'mouseenter',
    'focus',
];
const toPx = (px) => `${px}px`;
export default class Tooltip {
    target;
    direction;
    offset = {
        x: 0,
        y: 0,
    };
    tooltip;
    inner;
    arrow;
    static templates = {
        top: Tooltip.getTemplate('top'),
        right: Tooltip.getTemplate('right'),
        bottom: Tooltip.getTemplate('bottom'),
        left: Tooltip.getTemplate('left'),
    };
    constructor(target, direction, text, autoShow = true, autoHide = true) {
        this.target = target;
        this.direction = direction;
        if (!(target instanceof HTMLElement)) {
            const msg = 'Invalid element passed to Tooltip';
            console.error(msg);
            throw new Error(msg);
        }
        this.tooltip = Tooltip.cloneTemplate(direction);
        const innerElem = this.tooltip.querySelector('.tooltip-inner');
        if (!(innerElem instanceof HTMLElement))
            throw new UnreachableCode();
        this.inner = innerElem;
        const arrowElem = this.tooltip.querySelector('.arrow');
        if (!(arrowElem instanceof HTMLElement))
            throw new UnreachableCode();
        this.arrow = arrowElem;
        this.setText(text);
        document.body.append(this.tooltip);
        if (autoShow) {
            showEvents.forEach((e) => {
                this.target.addEventListener(e, () => {
                    this.show();
                });
            });
        }
        if (autoHide) {
            hideEvents.forEach((e) => {
                this.target.addEventListener(e, () => {
                    this.hide();
                });
            });
        }
    }
    setText(text) {
        this.inner.textContent = text;
    }
    show() {
        const targetRect = this.target.getBoundingClientRect();
        const targetMiddle = {
            x: targetRect.x + targetRect.width / 2,
            y: targetRect.y + targetRect.height / 2,
        };
        const tooltipRect = this.tooltip.getBoundingClientRect();
        // Middle of tooltip - half of arrow height
        const lrArrowHeight = tooltipRect.height / 2 -
            this.arrow.getBoundingClientRect().height / 2;
        switch (this.direction) {
            case 'top':
                this.tooltip.style.left = toPx(targetMiddle.x - tooltipRect.width / 2 + this.offset.x);
                this.tooltip.style.bottom = toPx(targetRect.y - tooltipRect.height + this.offset.y);
                break;
            case 'right':
                this.tooltip.style.left = toPx(targetRect.right + this.offset.x);
                this.tooltip.style.top = toPx(targetMiddle.y - tooltipRect.height / 2 + this.offset.y);
                this.arrow.style.top = toPx(lrArrowHeight);
                break;
            case 'bottom':
                this.tooltip.style.left = toPx(targetMiddle.x - tooltipRect.width / 2 + this.offset.x);
                this.tooltip.style.top = toPx(targetRect.bottom + this.offset.y);
                break;
            case 'left':
                this.tooltip.style.left = toPx(targetRect.left - tooltipRect.width + this.offset.x);
                this.tooltip.style.top = toPx(targetMiddle.y - tooltipRect.height / 2 + this.offset.y);
                this.arrow.style.top = toPx(lrArrowHeight);
                break;
        }
        this.tooltip.classList.add('show');
        this.tooltip.setAttribute('data-show', '');
    }
    hide() {
        this.tooltip.classList.remove('show');
        this.tooltip.removeAttribute('data-show');
    }
    delete() {
        this.tooltip.remove();
    }
    static getTemplate(dir) {
        const elemName = `${dir}TooltipTemplate`;
        const ret = document.getElementById(elemName);
        if (ret instanceof HTMLElement)
            return ret;
        throw new UnreachableCode();
    }
    static cloneTemplate(direction) {
        const template = Tooltip.templates[direction];
        const node = template.content.querySelector('.tooltip')?.cloneNode(true);
        if (node instanceof HTMLElement)
            return node;
        throw new UnreachableCode();
    }
}
//# sourceMappingURL=Tooltip.js.map