import { ConfigValue } from '../../resources/user_config';
import { BaseOptions, RaidbossData } from '../../types/data';
import { Matches } from '../../types/net_matches';
import { PartyTrackerOptions } from '../../types/party';
import { LooseTriggerSet, TriggerAutoConfig, TriggerField, TriggerOutput, TriggerSetAutoConfig } from '../../types/trigger';
export type PerTriggerOption = Partial<{
    TextAlert: boolean;
    SoundAlert: boolean;
    SpeechAlert: boolean;
    GroupSpeechAlert: boolean;
    SoundOverride: string;
    VolumeOverride: number;
    Condition: TriggerField<RaidbossData, Matches, boolean>;
    InfoText: TriggerOutput<RaidbossData, Matches>;
    AlertText: TriggerOutput<RaidbossData, Matches>;
    AlarmText: TriggerOutput<RaidbossData, Matches>;
    TTSText: TriggerOutput<RaidbossData, Matches>;
}>;
export type TimelineConfig = Partial<{
    Ignore: string[];
    Rename: {
        [text: string]: string;
    };
    Add: {
        time: number;
        text: string;
        duration?: number;
    }[];
}>;
export type PerTriggerAutoConfig = {
    [triggerId: string]: TriggerAutoConfig;
};
export type PerTriggerSetAutoConfig = {
    [triggerSetId: string]: TriggerSetAutoConfig;
};
export type PerTriggerOptions = {
    [triggerId: string]: PerTriggerOption;
};
export type DisabledTriggers = {
    [triggerId: string]: boolean;
};
export type PerZoneTimelineConfig = {
    [zoneId: number]: TimelineConfig;
};
export type TriggerSetConfig = {
    [triggerSetId: string]: {
        [key: string]: ConfigValue;
    };
};
type RaidbossNonConfigOptions = {
    PlayerNicks: {
        [gameName: string]: string;
    };
    InfoSound: string;
    AlertSound: string;
    AlarmSound: string;
    LongSound: string;
    PullSound: string;
    AudioAllowed: boolean;
    DisabledTriggers: DisabledTriggers;
    PerTriggerAutoConfig: PerTriggerAutoConfig;
    PerTriggerSetAutoConfig: PerTriggerSetAutoConfig;
    PerTriggerOptions: PerTriggerOptions;
    PerZoneTimelineConfig: PerZoneTimelineConfig;
    TriggerSetConfig: TriggerSetConfig;
    Triggers: LooseTriggerSet[];
    PlayerNameOverride?: string;
    IsRemoteRaidboss: boolean;
    TransformTts: (text: string) => string;
};
declare const defaultRaidbossConfigOptions: {
    DefaultAlertOutput: string;
    AlertsLanguage: "en" | "de" | "fr" | "ja" | "cn" | "ko" | undefined;
    TimelineLanguage: "en" | "de" | "fr" | "ja" | "cn" | "ko" | undefined;
    TimelineEnabled: boolean;
    AlertsEnabled: boolean;
    DefaultPlayerLabel: keyof import("../../types/party").BasePartyMemberParamObject;
    ShowTimerBarsAtSeconds: number;
    KeepExpiredTimerBarsForSeconds: number;
    BarExpiresSoonSeconds: number;
    MaxNumberOfTimerBars: number;
    ReverseTimeline: boolean;
    DisplayAlarmTextForSeconds: number;
    DisplayAlertTextForSeconds: number;
    DisplayInfoTextForSeconds: number;
    AlarmSoundVolume: number;
    AlertSoundVolume: number;
    InfoSoundVolume: number;
    LongSoundVolume: number;
    PullSoundVolume: number;
    RumbleEnabled: boolean;
    InfoRumbleDuration: number;
    InfoRumbleWeak: number;
    InfoRumbleStrong: number;
    AlertRumbleDuration: number;
    AlertRumbleWeak: number;
    AlertRumbleStrong: number;
    AlarmRumbleDuration: number;
    AlarmRumbleWeak: number;
    AlarmRumbleStrong: number;
};
type RaidbossConfigOptions = typeof defaultRaidbossConfigOptions;
export interface RaidbossOptions extends BaseOptions, RaidbossNonConfigOptions, RaidbossConfigOptions, PartyTrackerOptions {
}
declare const Options: RaidbossOptions;
export default Options;
