export const logLevels = [
    ['alert', 'ALERTS: issues that probably require action (RECOMMENDED)'],
    ['info', 'INFO: more routine/known issues that may not require action'],
    ['debug', 'DEBUG: detailed output for troubleshooting'],
    ['silent', 'SILENT: success & fatal errors only (not recommended)'],
];
const logLevelDefault = 'alert';
export class ConsoleLogger {
    static logLevelDefault = 'alert';
    // assign numerical values to log levels so we can do a quick compare
    // in deciding whether a user wants to see that type of log output
    logLevelMap = {
        silent: 0,
        alert: 1,
        info: 2,
        debug: 3,
    };
    myLogLevel;
    setLogLevel(logLevel) {
        // class is initialized in scripts outside of all constructs,
        // so it doesn't need to be passed to every function
        // this happens before the default function is called
        // with the user's log level choice.
        if (logLevel === undefined)
            return;
        if (!Object.keys(this.logLevelMap).includes(logLevel))
            this.fatalError(`Invalid log level (${logLevel}) is set.`);
        this.myLogLevel = this.logLevelMap[logLevel];
        this.debug(`Log level set: ${logLevel}`);
    }
    constructor(userLogLevelKey) {
        this.myLogLevel = this.logLevelMap[logLevelDefault]; // needs to be initialized first
        this.setLogLevel(userLogLevelKey);
    }
    alert(msg) {
        if (this.myLogLevel >= this.logLevelMap.alert)
            console.log(`Alert: ${msg}`);
    }
    info(msg) {
        if (this.myLogLevel >= this.logLevelMap.info)
            console.log(`Info: ${msg}`);
    }
    debug(msg) {
        if (this.myLogLevel >= this.logLevelMap.debug)
            console.log(`Debug: ${msg}`);
    }
    successDone(msg) {
        console.log(`Success: ${msg}`);
    }
    nonFatalError(msg) {
        console.log(`ERROR: ${msg}`);
    }
    fatalError(msg) {
        console.log(`ERROR: ${msg} Exiting...`);
        process.exit(1);
    }
    printNoHeader(msg) {
        console.log(`${msg}`);
    }
}
//# sourceMappingURL=console_logger.js.map