import { Namespace } from 'argparse';
import inquirer from 'inquirer';
import { isLang, languages } from '../resources/languages';
import { UnreachableCode } from '../resources/not_reached';
import { findMissingTranslations } from './find_missing_translations';
class FindMissingTranslationsNamespace extends Namespace {
    'filter';
    'locale';
}
const printErrorFunc = (file, line, type, _locale, message) => {
    let str = file;
    if (line)
        str += `:${line}`;
    str += ` [${type}]`;
    if (message)
        str += ` ${message}`;
    console.log(str);
};
const findMissingTranslationsFunc = (args) => {
    if (!(args instanceof FindMissingTranslationsNamespace))
        throw new UnreachableCode();
    const questions = [
        {
            type: 'fuzzypath',
            name: 'filter',
            message: 'Input a valid trigger JavaScript filename: ',
            rootPath: 'ui',
            suggestOnly: true,
            default: args.filter ?? '',
            when: () => typeof args.filter !== 'string',
        },
        {
            type: 'list',
            name: 'locale',
            message: 'Select a locale: ',
            choices: languages,
            default: args.locale,
            when: () => typeof args.locale !== 'string',
        },
    ];
    return inquirer.prompt(questions)
        .then((answers) => {
        const filter = answers.filter ?? args.filter;
        const locale = answers.locale ?? args.locale;
        if (typeof filter === 'string' && typeof locale === 'string' && isLang(locale))
            return findMissingTranslations(filter, [locale], printErrorFunc);
    });
};
export const registerFindMissingTranslations = (actionChoices, subparsers) => {
    actionChoices.findTranslations = {
        name: 'Find missing translations',
        callback: findMissingTranslationsFunc,
        namespace: FindMissingTranslationsNamespace,
    };
    const findParser = subparsers.addParser('findTranslations', {
        description: actionChoices.findTranslations.name,
    });
    findParser.addArgument(['-l', '--locale'], {
        help: 'The locale to find missing translations for, e.g. de',
    });
    findParser.addArgument(['-f', '--filter'], {
        nargs: '?',
        type: 'string',
        help: 'Limits the results to only match specific files/path',
    });
};
//# sourceMappingURL=find_missing_translations_action.js.map