export type FFLogsEventEntry = {
    timestamp: number;
    type: string;
    sourceID?: number;
    source?: {
        name: string;
        id: number;
        guid: number;
        type: string;
    };
    sourceInstance?: number;
    sourceIsFriendly: boolean;
    targetID: number;
    targetIsFriendly: boolean;
    ability: {
        name: string;
        guid: number;
        type: number;
    };
    fight: number;
};
export type FFLogsFightListEntry = {
    id: number;
    boss: number;
    start_time: number;
    end_time: number;
    name: string;
    zoneID: number;
    zoneName: string;
    size: number;
    difficulty: number;
    kill: boolean;
    partial: number;
    inProgress: boolean;
    standardComposition: boolean;
    hasEcho: boolean;
    bossPercentage: number;
    fightPercentage: number;
    lastPhaseAsAbsoluteIndex: number;
    lastPhaseForPercentageDisplay: number;
    maps: {
        mapID: number;
        mapName: string;
    };
};
export type FFLogsEventResponse = {
    count: number;
    events: FFLogsEventEntry[];
    nextPageTimestamp?: number;
};
export type FFLogsFightResponse = {
    lang: 'en' | 'fr' | 'ja' | 'de' | 'cn';
    start: number;
    end: number;
    fights: FFLogsFightListEntry[];
    title: string;
    zone: number;
    enemies: FFLogsEnemy[];
    nextPageTimestamp?: number;
};
export type FFLogsEnemy = {
    guid: number;
    icon: string;
    id: number;
    name: string;
    type: string;
};
export type FFLogsParsedEntry = {
    timestamp: number;
    combatant: string;
    abilityId: string;
    abilityName: string;
    type: string;
};
declare class FFLogs {
    static callFFLogs: (fightsOrEvents: 'fights' | 'events', reportId: string, prefix: 'www' | 'fr' | 'ja' | 'de' | 'cn', options: URLSearchParams) => Promise<FFLogsEventResponse | FFLogsFightResponse>;
    static getFightInfo: (reportId: string, key: string) => Promise<FFLogsFightResponse>;
    static extractEnemiesFromReport: (fightData: FFLogsFightResponse) => {
        [index: string]: string;
    };
    static getEventData: (reportId: string, key: string, startTime: number, endTime: number, filter?: string, translate?: boolean) => Promise<FFLogsEventEntry[]>;
    static parseFFLogsEvent: (event: FFLogsEventEntry, enemies: {
        [index: string]: string;
    }, startTime: number) => FFLogsParsedEntry;
    static parseReport: (reportId: string, fightIndex: number, apiKey: string) => Promise<FFLogsParsedEntry[]>;
}
export default FFLogs;
