import fs from 'fs';
import path from 'path';
import process from 'process';
import * as url from 'url';
// TODO: throw some warnings if id lines aren't translated
// TODO: consider doing this at runtime instead of via regex
const __filename = url.fileURLToPath(new URL('.', import.meta.url));
const __dirname = path.basename(__filename);
const root = path.join(__dirname, '../');
const scriptName = 'npm run sync-files';
const zoneReplace = [
    {
        // Sildihn Criterion
        fileMap: {
            'ui/raidboss/data/06-ew/dungeon/another_sildihn_subterrane.ts': 'ui/raidboss/data/06-ew/dungeon/another_sildihn_subterrane-savage.ts',
            'ui/oopsyraidsy/data/06-ew/dungeon/another_sildihn_subterrane.ts': 'ui/oopsyraidsy/data/06-ew/dungeon/another_sildihn_subterrane-savage.ts',
            'ui/raidboss/data/06-ew/dungeon/another_sildihn_subterrane.txt': 'ui/raidboss/data/06-ew/dungeon/another_sildihn_subterrane-savage.txt',
        },
        prefix: { 'ASS': 'ASSS' },
        other: {
            'AnotherSildihnSubterrane': 'AnotherSildihnSubterraneSavage',
            'another_sildihn_subterrane.txt': 'another_sildihn_subterrane-savage.txt',
            '# Another Sil\'dihn Subterrane': '# Another Sil\'dihn Subterrane (Savage)',
        },
        id: {
            '7490': '76BB',
            '7499': '76BC',
            '749C': '76BD',
            '749E': '76BE',
            '74A1': '76BF',
            '74A6': '76C1',
            '74AD': '76C4',
            '74AF': '76C5',
            '74B1': '76C6',
            '74B2': '76C7',
            '74B4': '76C8',
            '74B5': '76C9',
            '74B7': '76CA',
            '74B9': '76CC',
            '74BB': '76CD',
            '7658': '779A',
            '7659': '779B',
            '765A': '779C',
            '765B': '779D',
            '765C': '779E',
            '765D': '779F',
            '765E': '77A0',
            '765F': '77A1',
            '7660': '77A2',
            '7661': '77A3',
            '7662': '77A4',
            '7663': '77A5',
            '7664': '77A6',
            '7666': '77A8',
            '7667': '77A9',
            '7668': '77AA',
            '7669': '77AB',
            '766A': '77AC',
            '766B': '77AD',
            '766C': '77AE',
            '766E': '77B0',
            '766F': '77B1',
            '7670': '77B2',
            '7671': '77B3',
            '7672': '77B4',
            '7673': '77B5',
            '7674': '77B6',
            '7675': '77B7',
            '7676': '77B8',
            '7677': '77B9',
            '7678': '77BA',
            '7679': '77BB',
            '768C': '77BC',
            '768D': '77BE',
            '774F': '7772',
            '7750': '7773',
            '7751': '7774',
            '7752': '7775',
            '7753': '7776',
            '7754': '7777',
            '7755': '7778',
            '7756': '7779',
            '7757': '777A',
            '7758': '777B',
            '7759': '777C',
            '775A': '777D',
            '775D': '7780',
            '775E': '7781',
            '7760': '7783',
            '7761': '7784',
            '7762': '7785',
            '7763': '7786',
            '7764': '7787',
            '7765': '7788',
            '7766': '7789',
            '7767': '778A',
            '7768': '778B',
            '7769': '778C',
            '776A': '778D',
            '776C': '778F',
            '776D': '7790',
            '776E': '7791',
            '776F': '7792',
            '7770': '7793',
            '7771': '7794',
            '77EA': '77EC',
            '7957': '796F',
            '7958': '7970',
            '7959': '7971',
            '795A': '7972',
            '795B': '7973',
            '795C': '7974',
            '795D': '7975',
            '795F': '7977',
            '7960': '7978',
            '7961': '7979',
            '7962': '797A',
            '7963': '797B',
            '7964': '797C',
            '7965': '797D',
            '7966': '797E',
            '7968': '7980',
            '7969': '7981',
            '796A': '7982',
            '796B': '7983',
            '796C': '7984',
            '79E0': '79E1',
            '79F3': '79F4',
            // Unchanged abilities, Criterion.
            '6854': '6854',
            '77AE': '77AE',
            '7491': '7491',
            '74B0': '74B0', // firesteel strike (self-targeted)
        },
    },
    {
        // Sophia
        fileMap: {
            'ui/raidboss/data/03-hw/trial/sophia-ex.ts': 'ui/raidboss/data/06-ew/trial/sophia-un.ts',
            'ui/raidboss/data/03-hw/trial/sophia-ex.txt': 'ui/raidboss/data/06-ew/trial/sophia-un.txt',
            'ui/oopsyraidsy/data/03-hw/trial/sophia-ex.ts': 'ui/oopsyraidsy/data/06-ew/trial/sophia-un.ts',
        },
        prefix: {
            'SophiaEX': 'SophiaUN',
            'SophiaEx': 'SophiaUn',
        },
        other: {
            'ContainmentBayP1T6Extreme': 'ContainmentBayP1T6Unreal',
            'sophia-ex.txt': 'sophia-un.txt',
            '(Extreme)': '(Unreal)',
            ' Extreme': ' Unreal',
        },
        id: {
            '1981': '7D9C',
            '1983': '7D9D',
            '1984': '7D9E',
            '1988': '7D9F',
            '1989': '7DA0',
            '196E': '7D9B',
            '19A7': '7DA1',
            '19A8': '7DA2',
            '19A9': '7DA3',
            '19AA': '7DA4',
            '19AB': '7DA5',
            '19AC': '7DA6',
            '19AD': '7DA7',
            '19AE': '7DA8',
            '19AF': '7DA9',
            '19B0': '7DAA',
            '19B1': '7DAB',
            '19B3': '7DAD',
            '19B5': '7DAF',
            '19B6': '7DB0',
            '19B8': '7DB2',
            '19B9': '7DB3',
            '19BA': '7DB4',
            '19BB': '7DB5',
            '19BC': '7DB6',
            '19BD': '7DB7',
            '19BE': '7DB8',
            '19BF': '7DB9',
            '19C0': '7DBA',
            '19C1': '7DBB',
            '19C2': '7DBC',
            '19C3': '7DBD',
            '19C4': '7DBE',
            '19C5': '7DBF',
            '1A4C': '7E46',
            '1A87': '7E81',
            '1ABE': '7EB8',
            '1ABF': '7EB9',
            '1AE0': '7DC5',
            '1AE1': '7DC6', // Scales of Wisdom 2
        },
    },
    {
        // Zurvan
        fileMap: {
            'ui/raidboss/data/03-hw/trial/zurvan-ex.ts': 'ui/raidboss/data/06-ew/trial/zurvan-un.ts',
            'ui/raidboss/data/03-hw/trial/zurvan-ex.txt': 'ui/raidboss/data/06-ew/trial/zurvan-un.txt',
            'ui/oopsyraidsy/data/03-hw/trial/zurvan-ex.ts': 'ui/oopsyraidsy/data/06-ew/trial/zurvan-un.ts',
        },
        prefix: { 'ZurvanEX': 'ZurvanUN' },
        other: {
            'ContainmentBayZ1T9Extreme': 'ContainmentBayZ1T9Unreal',
            'zurvan-ex.txt': 'zurvan-un.txt',
            '(Extreme)': '(Unreal)',
            ' Extreme': ' Unreal',
            'Sarva': 'Eidos',
        },
        id: {
            '1E3F': '857F',
            '1C4E': '8557',
            '1C4F': '8558',
            '1C50': '8559',
            '1C51': '855A',
            '1C52': '855B',
            '1C53': '855C',
            '1C54': '855D',
            '1C55': '855E',
            '1C56': '855F',
            '1C57': '8560',
            '1C58': '8561',
            '1C59': '8562',
            '1C5A': '8563',
            '1C5B': '8564',
            '1C5C': '8565',
            '1C5D': '8566',
            '1C5E': '8567',
            '1C5F': '8568',
            '1C60': '8569',
            '1C63': '856C',
            '1C64': '856D',
            '1C67': '8570',
            '1C68': '8571',
            '1C6B': '8572',
            '1C6C': '8573',
            '1C6D': '8576',
            '1C6E': '8577',
            '1C6F': '8578',
            '1C70': '8579',
            '1C71': '857A',
            '1C72': '857B',
            '1C73': '857C',
            '1DC7': '857D',
            '1E09': '857E',
            '1E31': '856A',
            '1E32': '856B',
            '1E35': '856E',
            '1E36': '856F',
            '1E58': '8591',
            '1E59': '8592',
            '1E64': '859D',
            '1E65': '859E', // The North Star (ignored)
        },
    },
    {
        // Mount Rokkon Criterion
        fileMap: {
            'ui/raidboss/data/06-ew/dungeon/another_mount_rokkon.ts': 'ui/raidboss/data/06-ew/dungeon/another_mount_rokkon-savage.ts',
            'ui/oopsyraidsy/data/06-ew/dungeon/another_mount_rokkon.ts': 'ui/oopsyraidsy/data/06-ew/dungeon/another_mount_rokkon-savage.ts',
            'ui/raidboss/data/06-ew/dungeon/another_mount_rokkon.txt': 'ui/raidboss/data/06-ew/dungeon/another_mount_rokkon-savage.txt',
        },
        prefix: { 'AMR': 'AMRS' },
        other: {
            'AnotherMountRokkon': 'AnotherMountRokkonSavage',
            'another_mount_rokkon.txt': 'another_mount_rokkon-savage.txt',
            '# Another Mount Rokkon': '# Another Mount Rokkon (Savage)',
        },
        // eslint-disable-next-line max-len
        // grep "^# [A-F0-9]\{4\} " ui/raidboss/data/06-ew/dungeon/another_mount_rokkon.txt | sort | sed "s/^..//" | sed "s/^\(....\) \(.*\)$/    '\1': 'TODO', \/\/ \2/"
        id: {
            '7A56': '7A56',
            '7A58': '7A58',
            '83F8': '841F',
            '83F9': '8420',
            '83FA': '8421',
            '83FB': '8422',
            '83FC': '8423',
            '83FD': '8424',
            '83FE': '8425',
            '83FF': '8426',
            '8400': '8427',
            '8401': '8428',
            '8402': '8429',
            '8403': '842A',
            '8404': '842B',
            '8405': '824C',
            '8406': '824D',
            '8407': '842E',
            '8408': '842F',
            '8409': '8430',
            '840A': '8431',
            '840B': '8432',
            '840C': '8433',
            '840D': '8434',
            '840E': '8435',
            '840F': '8436',
            '8410': '8437',
            '8411': '8438',
            '8412': '8439',
            '8413': '843A',
            '8414': '843B',
            '8415': '843C',
            '8416': '843D',
            '8417': '843E',
            '8418': '843F',
            '8419': '8440',
            '841A': '8441',
            '841B': '8442',
            '841C': '8443',
            '841D': '8444',
            '841E': '841E',
            '84D3': '84D3',
            '8502': '8502',
            '8503': '8503',
            '8504': '8504',
            '8505': '8539',
            '8506': '853A',
            '8507': '8507',
            '8508': '8508',
            '8509': '8509',
            '850A': '850A',
            '850B': '853C',
            '850C': '853D',
            '850D': '8550',
            '850E': '853F',
            '850F': '8540',
            '8510': '8510',
            '8511': '8541',
            '8512': '8512',
            '8513': '8584',
            '8514': '8514',
            '8515': '8585',
            '8518': '8518',
            '8519': '8544',
            '851A': '8545',
            '851B': '8546',
            '851C': '8547',
            '851D': '851D',
            '851E': '851E',
            '851F': '8548',
            '8520': '8520',
            '8521': '8521',
            '8522': '8549',
            '8523': '854A',
            '8524': '8502',
            '8525': '854B',
            '8526': '8526',
            '8527': '854C',
            '8528': '8628',
            '8529': '854D',
            '852A': '854E',
            '852B': '852B',
            '852C': '854F',
            '852D': '853E',
            '852F': '852F',
            '8530': '8552',
            '8531': '8553',
            '8532': '8532',
            '8533': '8554',
            '8534': '8534',
            '8535': '8555',
            '8536': '8536',
            '8537': '8537',
            '8538': '8538',
            '8593': '8593',
            '8599': '8599',
            '859D': '859D',
            '85AF': '85AF',
            '85B0': '85E4',
            '85B1': '85E5',
            '85B2': '85E6',
            '85B3': '85E7',
            '85B4': '85E8',
            '85B5': '85E9',
            '85B6': '85EA',
            '85B7': '85EB',
            '85B8': '85EC',
            '85B9': '85ED',
            '85BA': '85EE',
            '85BB': '85EF',
            '85BC': '85F0',
            '85BD': '85F1',
            '85BE': '85F2',
            '85BF': '85F3',
            '85C0': '85F4',
            '85C1': '85F5',
            '85C2': '85C2',
            '85C3': '85C3',
            '85C4': '85F6',
            '85C5': '85F7',
            '85C6': '85F8',
            '85C7': '85C7',
            '85C8': '85C8',
            '85C9': '85C9',
            '85CA': '85F9',
            // TODO: 85CE is an unseen guess; it might be unchanged, or most likely 85E2 or 85FD
            // as these are the only "recent" Kenki Release ability ids that are unknown.
            // However, Kenki Release / Iron Rain / Iron Storm are sequential so is likely correct.
            '85CE': '85FD',
            '85CF': '85FE',
            '85D0': '85FF',
            '85D1': '8600',
            '85D2': '8601',
            '85D3': '8602',
            '85D4': '8603',
            '85D5': '8604',
            '85D6': '8605',
            '85D7': '8606',
            '85D8': '85D8',
            '85D9': '85D9',
            '85DA': '8607',
            '85DB': '85BD',
            '85DC': '8608',
            '85DD': '8609',
            '85DE': '860A',
            '85DF': '860B',
            '85E0': '860C',
            // TODO: 85E1 is an unseen guess; it might be unchanged, or most likely 85E2 or 85FD
            // as these are the only "recent" Kenki Release ability ids that are unknown.
            // See note above about 85CE, so 85E2 is the only other unused ability here.
            '85E1': '85E2',
            '85E3': '860D',
            '8653': '8665',
            '8654': '8666',
            '8655': '8667',
            '8656': '8668',
            '8657': '8669',
            '8658': '866A',
            '8659': '866B',
            '865A': '866C',
            '865B': '866D',
            '865C': '866E',
            '865D': '866F',
            '865E': '8670',
            '865F': '8671',
            '8660': '8672',
            '8661': '8673',
            '8662': '8674',
            '8663': '8675',
            '8664': '8676',
            '867D': '867E',
            '8685': '8688',
            '8686': '8689',
            '8687': '868A',
            '86C4': '86CC',
            '86C5': '86CD',
            '86C6': '86CE',
            '86DF': '86E0',
            '871F': '871F',
            '8720': '8720',
            '87A7': '87A9',
            '87A8': '87AA',
            '8C21': '8C22',
            '8C27': '8C28', // Clearout damage from Oni's Claw large circles hit 2
        },
    },
    {
        // Thordan
        fileMap: {
            'ui/raidboss/data/03-hw/trial/thordan-ex.ts': 'ui/raidboss/data/06-ew/trial/thordan-un.ts',
            'ui/raidboss/data/03-hw/trial/thordan-ex.txt': 'ui/raidboss/data/06-ew/trial/thordan-un.txt',
            'ui/oopsyraidsy/data/03-hw/trial/thordan-ex.ts': 'ui/oopsyraidsy/data/06-ew/trial/thordan-un.ts',
        },
        prefix: { 'ThordanEX': 'ThordanUN' },
        other: {
            'TheMinstrelsBalladThordansReign': 'TheSingularityReactorUnreal',
            'THE MINSTREL\'S BALLAD: THORDAN\'S REIGN': 'THE SINGULARITY REACTOR (UNREAL)',
            'thordan-ex.txt': 'thordan-un.txt',
        },
        id: {
            '1018': '89B7',
            '1019': '89B8',
            '1059': '89B9',
            '105A': '89BA',
            '105B': '89BB',
            '147D': '89BC',
            '147E': '89BD',
            '147F': '89BE',
            '1480': '89BF',
            '1481': '89C0',
            '1482': '89C1',
            '1483': '89C2',
            '1484': '89C3',
            '1485': '89C4',
            '1486': '89C5',
            '1487': '89C6',
            '1488': '89C7',
            '1489': '89C8',
            '148A': '89C9',
            '148B': '89CA',
            '148C': '89CB',
            '148D': '89CC',
            '148E': '89CD',
            '148F': '89CE',
            '1490': '89CF',
            '1491': '89D0',
            '1492': '89D1',
            '1493': '89D2',
            '1494': '89D3',
            '1495': '89D4',
            '1496': '89D5',
            '1497': '89D6',
            '1499': '89D8',
            '149A': '89D9',
            '149B': '89DA',
            '149C': '89DB',
            '149D': '89DC',
            '149E': '89DD',
            '149F': '89DE',
            '14A0': '89DF',
            '14A1': '89E0',
            '14A2': '89E1',
            '14A3': '89E2',
            '14A4': '89E3',
            '14A5': '89E4',
            '14A6': '89E5',
            '14A7': '89E6',
            '14A9': '89E8',
            '14AA': '89E9',
            '14AB': '89EA',
            '14AC': '89EB',
            '14AD': '89EC',
            '14AE': '89ED',
            '14AF': '89EE',
            '14B0': '89EF',
            '14B1': '89F0',
            '14B2': '89F1',
            '14B3': '89F2',
            '14B4': '89F3',
            '14B5': '89F4', // Comet
        },
    },
    {
        // Aloalo Criterion
        fileMap: {
            'ui/raidboss/data/06-ew/dungeon/another_aloalo_island.ts': 'ui/raidboss/data/06-ew/dungeon/another_aloalo_island-savage.ts',
            'ui/oopsyraidsy/data/06-ew/dungeon/another_aloalo_island.ts': 'ui/oopsyraidsy/data/06-ew/dungeon/another_aloalo_island-savage.ts',
            'ui/raidboss/data/06-ew/dungeon/another_aloalo_island.txt': 'ui/raidboss/data/06-ew/dungeon/another_aloalo_island-savage.txt',
        },
        prefix: { 'AAI': 'AAIS' },
        other: {
            'AnotherAloaloIsland': 'AnotherAloaloIslandSavage',
            'another_aloalo_island.txt': 'another_aloalo_island-savage.txt',
            '# Another Aloalo Island': '# Another Aloalo Island (Savage)',
            '\(\'AAI ': '\(\'AAIS ',
        },
        // eslint-disable-next-line max-len
        // grep "^# [A-F0-9]\{4\} " ui/raidboss/data/06-ew/dungeon/another_aloalo_island.txt | sort | sed "s/^..//" | sed "s/^\(....\) \(.*\)$/    '\1': 'TODO', \/\/ \2/"
        // TODO: missing various enrages (both listed and likely unlisted)
        id: {
            '7A56': '7A56',
            '7A58': '7A58',
            '8874': '8874',
            '8889': '8BE0',
            '888B': '8BE2',
            '888C': '8BE3',
            '888D': '8BE4',
            '888E': '8BE5',
            '888F': '8BE6',
            '8890': '8BE7',
            '8891': '8BE8',
            '8892': '8BE9',
            '8893': '8BEA',
            '8894': '8BEB',
            '8895': '8BEC',
            '8898': '8BEF',
            '8899': '8BF0',
            '889A': '8BF1',
            '889B': '8BF2',
            '889C': '8BF3',
            '889D': '8BF4',
            '889E': '8BF5',
            '889F': '8BF6',
            '88A0': '8BF7',
            '88A1': '8BF8',
            '88A2': '8BF9',
            '88A3': '8BFA',
            '88A4': '8BFB',
            '88A5': '8BFC',
            '88A6': '8BFD',
            '88A7': '8BFE',
            '88A8': '8BFF',
            '88A9': '8C00',
            '88AD': '8C04',
            '88AE': '8C05',
            '8925': '8925',
            '8926': '8926',
            '8927': '8927',
            '8947': '8964',
            '8948': '8965',
            '8949': '8966',
            '894A': '8967',
            '894B': '8968',
            '894C': '8969',
            '894D': '8927',
            '894E': '896B',
            '894F': '896C',
            '8954': '8971',
            '8955': '8972',
            '8956': '8973',
            '8957': '8974',
            '8958': '8975',
            '8959': '8976',
            '895A': '8977',
            '895B': '8978',
            '895C': '8979',
            '895D': '897A',
            '895E': '897B',
            '895F': '897C',
            '8960': '897D',
            '8963': '8980',
            '8982': '896F',
            '8987': '8988',
            '89F9': '89FB',
            '8A6A': '8A6A',
            '8A77': '8A77',
            '8A82': '8A82',
            '8A83': '8A83',
            '8AA7': '8AA7',
            '8AA8': '8AA8',
            '8AA9': '8AD9',
            '8AAA': '8ADA',
            '8AAB': '8ADB',
            '8AAC': '8ADC',
            '8AAD': '8AAD',
            '8AAE': '8ADD',
            '8AAF': '8AAF',
            '8AB0': '8AB0',
            '8AB1': '8AB1',
            '8AB2': '8AB2',
            '8AB3': '8AB3',
            '8AB4': '8AB4',
            '8AB5': '8AB5',
            '8AB6': '8AB6',
            '8AB7': '8ADE',
            '8AB8': '8AB8',
            '8AB9': '8AB9',
            '8ABA': '8ADF',
            '8ABB': '8ABB',
            '8ABC': '8AE0',
            '8ABD': '8ABD',
            '8ABE': '8ABE',
            '8ABF': '8ABF',
            '8AC0': '8AC0',
            '8AC1': '8AE1',
            '8AC2': '8AE2',
            '8AC3': '8AE3',
            '8AC4': '8AC4',
            '8AC5': '8AC5',
            '8AC6': '8AE4',
            '8AC7': '8AC7',
            '8AC8': '8AC8',
            '8AC9': '8AE5',
            '8ACA': '8ACA',
            '8ACB': '8AE6',
            '8ACC': '8AE7',
            '8ACD': '8AE8',
            '8ACE': '8AE9',
            '8ACF': '8AEA',
            '8AD0': '8AD0',
            '8AD1': '8AEB',
            '8AD4': '8AD4',
            '8AD5': '8AED',
            '8AD6': 'TODO',
            '8BB8': '8BC9',
            '8BB9': '8BCA',
            '8BBA': '8BCB',
            '8BBB': '8C4F',
            '8BBD': '8C4B',
            '8BBE': '8BCD',
            '8BBF': '8BCE',
            '8BC0': '8BCF',
            '8BC1': '8BD4',
            '8BC5': '8C3A',
            '8C23': 'TODO',
            '8C24': 'TODO',
            '8C25': 'TODO',
            '8C2F': 'TODO',
            '8C4C': '8BD2',
            '8C4D': '8BD3',
            '8C4E': '8C39',
            '8C53': '8BC4',
            '8C62': '8BC6',
            '8C63': '8BC8',
            '8C64': '8BCC',
            '8C65': '8BD1',
            '8C6D': '8C6D',
            '8C6E': '8BC7',
            '8C6F': '8C3C',
            '8CBC': '8CBF',
            '8CBD': '8CC0',
            '8CBE': '8CC1',
            '8CC2': '8CC3',
            '8CDE': '8CE0',
            '8CDF': '8CE1',
            '8D1A': '8D1C',
            '8D1F': '8D20',
            '8D2E': '8D2F', // Angular Addition self-targeted ability to give boss V
        },
    },
    {
        fileMap: {
            'ui/raidboss/data/04-sb/trial/byakko-ex.ts': 'ui/raidboss/data/07-dt/trial/byakko-un.ts',
            'ui/raidboss/data/04-sb/trial/byakko-ex.txt': 'ui/raidboss/data/07-dt/trial/byakko-un.txt',
            'ui/oopsyraidsy/data/04-sb/trial/byakko-ex.ts': 'ui/oopsyraidsy/data/07-dt/trial/byakko-un.ts',
        },
        prefix: { 'ByakkoEx': 'ByakkoUn' },
        other: {
            'TheJadeStoaExtreme': 'TheJadeStoaUnreal',
            'Byakko Extreme': 'Byakko Unreal',
            'byakko-ex.txt': 'byakko-un.txt',
        },
        id: {
            '25D1': '9BF4',
            '265E': '9BF7',
            '2756': '9BF8',
            '2757': '9BF9',
            '27D9': '9BFA',
            '27DA': '9BFB',
            '27DB': '9BFC',
            '27DC': '9BFD',
            '27DD': '9BFE',
            '27DE': '9BFF',
            '27DF': '9C00',
            '27E0': '9C01',
            '27E1': '9C02',
            '27E2': '9C03',
            '27E3': '9C04',
            '27E4': '9C05',
            '27E5': '9C06',
            '27E6': '9C07',
            '27E7': '9C08',
            '27E8': '9C09',
            '27E9': '9C0A',
            '27EB': '9C0C',
            '27EC': '9C0D',
            '27ED': '9C0E',
            '27EE': '9C0F',
            '27F1': '9C12',
            '27F3': '9C14',
            '27F4': '9C15',
            '27F6': '9C16',
            '27F7': '9C17',
            '27F9': '9C19',
            '27FA': '9C1A',
            '27FB': '9C1B',
            '29E4': '9C1F',
            '29E5': '9C20',
            '2A09': '9C21',
            '2A2A': '9C22', // [Phase 3 opener]
        },
    },
    {
        fileMap: {
            'ui/raidboss/data/04-sb/trial/suzaku-ex.ts': 'ui/raidboss/data/07-dt/trial/suzaku-un.ts',
            'ui/raidboss/data/04-sb/trial/suzaku-ex.txt': 'ui/raidboss/data/07-dt/trial/suzaku-un.txt',
            'ui/oopsyraidsy/data/04-sb/trial/suzaku-ex.ts': 'ui/oopsyraidsy/data/07-dt/trial/suzaku-un.ts',
        },
        prefix: { 'SuzakuEx': 'SuzakuUn' },
        other: {
            'HellsKierExtreme': 'HellsKierUnreal',
            'Suzaku Extreme': 'Suzaku Unreal',
            'suzaku-ex.txt': 'suzaku-un.txt',
        },
        id: {
            '32D2': 'A7FC',
            '32F0': 'A813',
            '32E0': 'A808',
            '32D3': 'A7FD',
            '32D0': 'A7FA',
            '32D1': 'A7FB',
            '3224': 'A7F0',
            '32D4': 'A7FE',
            '3244': 'A76E',
            '3222': 'A7EF',
            '3226': 'A7F1',
            '3485': 'A814',
            '3486': 'A815',
            '32D9': 'A801',
            '32DF': 'A807',
            '322E': 'A7F2',
            '32DA': 'A802',
            '32E1': 'A809',
            '3243': 'A7F8',
            '32DC': 'A804',
            '32DD': 'A805',
            '32DE': 'A806',
            '3237': 'A7F3',
            '32E2': 'A80A',
            '323A': 'A7F5',
            '32DB': 'A803',
            '32E4': 'A80B',
            '32E5': 'A80F',
            '323C': 'A7F6',
            '32E6': 'A80D',
            '32ED': 'A817', // Hotspot enrage
        },
    },
];
const processFile = (filename, zone, inputText) => {
    const output = [];
    const blockCommentByExtension = {
        '.ts': [
            `// This file was autogenerated from running ${scriptName}.`,
            '// DO NOT EDIT THIS FILE DIRECTLY.',
            '// Edit the source file below and then run `npm run sync-files`',
            `// Source: ${filename}`,
            '',
        ],
        '.txt': [
            `# This file was autogenerated from running ${scriptName}.`,
            '# DO NOT EDIT THIS FILE DIRECTLY.',
            '# Edit the source file below and then run `npm run sync-files`',
            `# Source: ${filename}`,
            '',
        ],
    };
    for (const [extension, comment] of Object.entries(blockCommentByExtension)) {
        if (filename.endsWith(extension)) {
            output.push(...comment);
            break;
        }
    }
    const lines = inputText.split('\r\n');
    const prefixes = Object.entries(zone.prefix);
    const others = Object.entries(zone.other);
    const ids = Object.entries(zone.id);
    for (const inputLine of lines) {
        let line = inputLine;
        // TODO: consider matching: /^\s*id: '/ or /^\s* '/
        for (const [inputId, outputId] of prefixes)
            line = line.replace(` '${inputId} `, ` '${outputId} `);
        for (const [input, output] of others)
            line = line.replace(input, output);
        for (const [inputId, outputId] of ids)
            line = line.replace(`${inputId}`, `${outputId}`);
        output.push(line);
    }
    return output.join('\r\n');
};
const processAllFiles = async (root) => {
    for (const zone of zoneReplace) {
        for (const [input, output] of Object.entries(zone.fileMap)) {
            try {
                const inputFile = await fs.promises.readFile(path.join(root, input));
                const outputText = processFile(input, zone, inputFile.toString());
                await fs.promises.writeFile(output, outputText);
            }
            catch (e) {
                console.error(e);
            }
        }
    }
    process.exit(0);
};
void processAllFiles(root);
//# sourceMappingURL=sync_files.js.map